@@ -20,6 +20,8 @@
 import datetime
 import os
 import re
+from typing import ClassVar
+from typing import Sequence
 
 import dateutil.tz
 from twisted.internet import defer
@@ -91,7 +93,7 @@ class P4Source(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
     """This source will poll a perforce repository for changes and submit
     them to the change master."""
 
-    compare_attrs = (
+    compare_attrs: ClassVar[Sequence[str]] = (
         "p4port",
         "p4user",
         "p4passwd",
@@ -247,7 +249,7 @@ class P4Source(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
         env = {e: os.environ.get(e) for e in self.env_vars if os.environ.get(e)}
         res, out = yield runprocess.run_process(
             self.master.reactor,
-            [self.p4bin] + args,
+            [self.p4bin, *args],
             env=env,
             collect_stderr=False,
             stderr_is_error=True,
@@ -299,7 +301,7 @@ class P4Source(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
         try:
             result = bytes2unicode(result, self.encoding)
         except UnicodeError as ex:
-            log.msg(f"{ex}: cannot fully decode {repr(result)} in {self.encoding}")
+            log.msg(f"{ex}: cannot fully decode {result!r} in {self.encoding}")
             result = bytes2unicode(result, encoding=self.encoding, errors="replace")
 
         last_change = self.last_change
@@ -310,7 +312,7 @@ class P4Source(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
                 continue
             m = self.changes_line_re.match(line)
             if not m:
-                raise P4PollerError(f"Unexpected 'p4 changes' output: {repr(result)}")
+                raise P4PollerError(f"Unexpected 'p4 changes' output: {result!r}")
             num = int(m.group('num'))
             if last_change is None:
                 # first time through, the poller just gets a "baseline" for where to
@@ -349,7 +351,7 @@ class P4Source(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
             lines[0] = lines[0].rstrip()
             m = self.describe_header_re.match(lines[0])
             if not m:
-                raise P4PollerError(f"Unexpected 'p4 describe -s' result: {repr(result)}")
+                raise P4PollerError(f"Unexpected 'p4 describe -s' result: {result!r}")
             who = self.resolvewho_callable(m.group('who'))
             when = datetime.datetime.strptime(m.group('when'), self.datefmt)
             if self.server_tz:
@@ -375,7 +377,7 @@ class P4Source(base.ReconfigurablePollingChangeSource, util.ComparableMixin):
                     continue
                 m = self.file_re.match(line)
                 if not m:
-                    raise P4PollerError(f"Invalid file line: {repr(line)}")
+                    raise P4PollerError(f"Invalid file line: {line!r}")
                 path = m.group('path')
                 if path.startswith(self.p4base):
                     branch, file = self.split_file(path[len(self.p4base) :])
