@@ -13,20 +13,23 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
 
 import asyncio
 import functools
-import sys
 import textwrap
+from types import ModuleType
 
 from buildbot.asyncio import AsyncIOLoopWithTwisted
 from buildbot.asyncio import as_deferred
 from buildbot.asyncio import as_future
+from buildbot.data import connector
 from buildbot.data import resultspec
 from buildbot.data.base import EndpointKind
 from buildbot.data.types import Entity
 from buildbot.util import service
 
+graphql: ModuleType | None = None
 try:
     import graphql
     from graphql.execution.execute import default_field_resolver
@@ -50,12 +53,13 @@ class GraphQLConnector(service.AsyncService):
     be transformed with as_deferred, and they should themselves transform normal data api results
     with as_future()
     """
-    data = None
-    asyncio_loop = None
+
+    data: connector.DataConnector | None = None
+    asyncio_loop: AsyncIOLoopWithTwisted | None = None
 
     # asyncio will create an event loop if none exists yet in get_event_loop(). We need to set it
     # back via set_event_loop() if we want it to be properly closed.
-    _saved_event_loop = None
+    _saved_event_loop: asyncio.AbstractEventLoop | None = None
 
     def reconfigServiceWithBuildbotConfig(self, new_config):
         if self.data is None:
@@ -87,10 +91,7 @@ class GraphQLConnector(service.AsyncService):
                 # policy, so this concern does not matter in practice.
                 #
                 # Note that asyncio.get_event_loop() is deprecated in favor of get_running_loop()
-                if sys.version_info[:2] >= (3, 7):
-                    loop = asyncio.get_running_loop()
-                else:
-                    loop = asyncio.get_event_loop()
+                loop = asyncio.get_running_loop()
         except RuntimeError:
             # get_running_loop throws if there's no current loop.
             # get_event_loop throws is there's no current loop and we're not on main thread.
@@ -116,18 +117,16 @@ class GraphQLConnector(service.AsyncService):
 
         return super().stopService()
 
-    @functools.lru_cache(1)
+    @functools.lru_cache(1)  # noqa: B019
     def get_schema(self):
         """Return the graphQL Schema of the buildbot data model"""
         types = {}
-        schema = textwrap.dedent(
-            """
+        schema = textwrap.dedent("""
         # custom scalar types for buildbot data model
         scalar Date   # stored as utc unix timestamp
         scalar Binary # arbitrary data stored as base85
         scalar JSON  # arbitrary json stored as string, mainly used for properties values
-        """
-        )
+        """)
 
         # type dependencies must be added recursively
         def add_dependent_types(ent):
@@ -174,8 +173,7 @@ class GraphQLConnector(service.AsyncService):
                 for op in sorted(operators):
                     if op in ["in", "notin"]:
                         if field_type_graphql in ["String", "Int"]:
-                            query_fields.append(
-                                f"{field}__{op}: [{field_type_graphql}]")
+                            query_fields.append(f"{field}__{op}: [{field_type_graphql}]")
                     else:
                         query_fields.append(f"{field}__{op}: {field_type_graphql}")
 
@@ -198,9 +196,7 @@ class GraphQLConnector(service.AsyncService):
             field_type_graphql = field_type.toGraphQLTypeName()
             keyfields.append(f"{field}: {field_type_graphql}")
 
-            queries_schema += (
-                f"  {rtype.name}{format_query_fields(keyfields)}: {typename}\n"
-            )
+            queries_schema += f"  {rtype.name}{format_query_fields(keyfields)}: {typename}\n"
             return queries_schema
 
         operators = set(resultspec.Filter.singular_operators)
