@@ -13,6 +13,9 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from twisted.internet import defer
 from twisted.python import log
@@ -23,17 +26,20 @@ from buildbot.data import types
 from buildbot.process.results import RETRY
 from buildbot.util import epoch2datetime
 
+if TYPE_CHECKING:
+    from buildbot.db.masters import MasterModel
+
 # time, in minutes, after which a master that hasn't checked in will be
 # marked as inactive
 EXPIRE_MINUTES = 10
 
 
-def _db2data(master):
+def _db2data(model: MasterModel):
     return {
-        "masterid": master['id'],
-        "name": master['name'],
-        "active": master['active'],
-        "last_active": master['last_active'],
+        "masterid": model.id,
+        "name": model.name,
+        "active": model.active,
+        "last_active": model.last_active,
     }
 
 
@@ -50,7 +56,7 @@ class MasterEndpoint(base.Endpoint):
         # this builder
         if 'builderid' in kwargs:
             builder = yield self.master.db.builders.getBuilder(builderid=kwargs['builderid'])
-            if not builder or kwargs['masterid'] not in builder['masterids']:
+            if not builder or kwargs['masterid'] not in builder.masterids:
                 return None
         m = yield self.master.db.masters.getMaster(kwargs['masterid'])
         return _db2data(m) if m else None
@@ -70,8 +76,8 @@ class MastersEndpoint(base.Endpoint):
         if 'builderid' in kwargs:
             builder = yield self.master.db.builders.getBuilder(builderid=kwargs['builderid'])
             if builder:
-                masterids = set(builder['masterids'])
-                masterlist = [m for m in masterlist if m['id'] in masterids]
+                masterids = set(builder.masterids)
+                masterlist = [m for m in masterlist if m.id in masterids]
             else:
                 masterlist = []
         return [_db2data(m) for m in masterlist]
@@ -108,17 +114,15 @@ class Master(base.ResourceType):
         too_old = epoch2datetime(self.master.reactor.seconds() - 60 * EXPIRE_MINUTES)
         masters = yield self.master.db.masters.getMasters()
         for m in masters:
-            if m['last_active'] is not None and m['last_active'] >= too_old:
+            if m.last_active is not None and m.last_active >= too_old:
                 continue
 
             # mark the master inactive, and send a message on its behalf
-            deactivated = yield self.master.db.masters.setMasterState(
-                masterid=m['id'], active=False
-            )
+            deactivated = yield self.master.db.masters.setMasterState(masterid=m.id, active=False)
             if deactivated:
-                yield self._masterDeactivated(m['id'], m['name'])
+                yield self._masterDeactivated(m.id, m.name)
             elif forceHouseKeeping:
-                yield self._masterDeactivatedHousekeeping(m['id'], m['name'])
+                yield self._masterDeactivatedHousekeeping(m.id, m.name)
 
     @base.updateMethod
     @defer.inlineCallbacks
@@ -170,7 +174,7 @@ class Master(base.ResourceType):
             complete=False, claimed=masterid
         )
         yield self.master.db.buildrequests.unclaimBuildRequests(
-            brids=[br['buildrequestid'] for br in buildrequests]
+            brids=[br.buildrequestid for br in buildrequests]
         )
 
     @defer.inlineCallbacks
