@@ -14,6 +14,8 @@
 # Copyright Buildbot Team Members
 
 
+from __future__ import annotations
+
 from buildbot.data import base
 from buildbot.data import types
 
@@ -21,10 +23,9 @@ from buildbot.data import types
 
 
 class Patch(base.ResourceType):
-
     name = "patch"
     plural = "patches"
-    endpoints = []
+    endpoints: list[type[base.Endpoint]] = []
     keyField = 'patchid'
 
     class EntityType(types.Entity):
@@ -34,4 +35,5 @@ class Patch(base.ResourceType):
         subdir = types.String()
         author = types.String()
         comment = types.String()
+
     entityType = EntityType(name, 'Patch')
