@@ -21,7 +21,7 @@ from buildbot.data import types
 
 
 class RootEndpoint(base.Endpoint):
-    isCollection = True
+    kind = base.EndpointKind.COLLECTION
     pathPatterns = "/"
 
     def get(self, resultSpec, kwargs):
@@ -35,11 +35,12 @@ class Root(base.ResourceType):
 
     class EntityType(types.Entity):
         name = types.String()
+
     entityType = EntityType(name, 'Rootlink')
 
 
 class SpecEndpoint(base.Endpoint):
-    isCollection = True
+    kind = base.EndpointKind.COLLECTION
     pathPatterns = "/application.spec"
 
     def get(self, resultSpec, kwargs):
@@ -56,4 +57,5 @@ class Spec(base.ResourceType):
         type = types.String()
         plural = types.String()
         type_spec = types.JsonObject()
+
     entityType = EntityType(name, 'Spec')
