@@ -13,6 +13,9 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from twisted.internet import defer
 
@@ -21,27 +24,27 @@ from buildbot.data import masters
 from buildbot.data import types
 from buildbot.db.schedulers import SchedulerAlreadyClaimedError
 
+if TYPE_CHECKING:
+    from buildbot.db.schedulers import SchedulerModel
+
 
 class Db2DataMixin:
-
     @defer.inlineCallbacks
-    def db2data(self, dbdict):
+    def db2data(self, dbdict: SchedulerModel):
         master = None
-        if dbdict['masterid'] is not None:
-            master = yield self.master.data.get(
-                ('masters', dbdict['masterid']))
+        if dbdict.masterid is not None and hasattr(self, 'master'):
+            master = yield self.master.data.get(('masters', dbdict.masterid))
         data = {
-            'schedulerid': dbdict['id'],
-            'name': dbdict['name'],
-            'enabled': dbdict['enabled'],
+            'schedulerid': dbdict.id,
+            'name': dbdict.name,
+            'enabled': dbdict.enabled,
             'master': master,
         }
         return data
 
 
 class SchedulerEndpoint(Db2DataMixin, base.Endpoint):
-
-    isCollection = False
+    kind = base.EndpointKind.SINGLE
     pathPatterns = """
         /schedulers/n:schedulerid
         /masters/n:masterid/schedulers/n:schedulerid
@@ -49,10 +52,9 @@ class SchedulerEndpoint(Db2DataMixin, base.Endpoint):
 
     @defer.inlineCallbacks
     def get(self, resultSpec, kwargs):
-        dbdict = yield self.master.db.schedulers.getScheduler(
-            kwargs['schedulerid'])
+        dbdict = yield self.master.db.schedulers.getScheduler(kwargs['schedulerid'])
         if 'masterid' in kwargs:
-            if dbdict['masterid'] != kwargs['masterid']:
+            if dbdict.masterid != kwargs['masterid']:
                 return None
         return (yield self.db2data(dbdict)) if dbdict else None
 
@@ -66,8 +68,7 @@ class SchedulerEndpoint(Db2DataMixin, base.Endpoint):
 
 
 class SchedulersEndpoint(Db2DataMixin, base.Endpoint):
-
-    isCollection = True
+    kind = base.EndpointKind.COLLECTION
     pathPatterns = """
         /schedulers
         /masters/n:masterid/schedulers
@@ -76,20 +77,20 @@ class SchedulersEndpoint(Db2DataMixin, base.Endpoint):
 
     @defer.inlineCallbacks
     def get(self, resultSpec, kwargs):
-        schedulers = yield self.master.db.schedulers.getSchedulers(
-            masterid=kwargs.get('masterid'))
+        schedulers = yield self.master.db.schedulers.getSchedulers(masterid=kwargs.get('masterid'))
         schdicts = yield defer.DeferredList(
             [self.db2data(schdict) for schdict in schedulers],
-            consumeErrors=True, fireOnOneErrback=True)
+            consumeErrors=True,
+            fireOnOneErrback=True,
+        )
         return [r for (s, r) in schdicts]
 
 
 class Scheduler(base.ResourceType):
-
     name = "scheduler"
     plural = "schedulers"
     endpoints = [SchedulerEndpoint, SchedulersEndpoint]
-    keyFields = ['schedulerid']
+    keyField = 'schedulerid'
     eventPathPatterns = """
         /schedulers/:schedulerid
     """
@@ -99,7 +100,8 @@ class Scheduler(base.ResourceType):
         name = types.String()
         enabled = types.Boolean()
         master = types.NoneOk(masters.Master.entityType)
-    entityType = EntityType(name)
+
+    entityType = EntityType(name, 'Scheduler')
 
     @defer.inlineCallbacks
     def generateEvent(self, schedulerid, event):
@@ -119,8 +121,7 @@ class Scheduler(base.ResourceType):
 
     @base.updateMethod
     def trySetSchedulerMaster(self, schedulerid, masterid):
-        d = self.master.db.schedulers.setSchedulerMaster(
-            schedulerid, masterid)
+        d = self.master.db.schedulers.setSchedulerMaster(schedulerid, masterid)
 
         # set is successful: deferred result is True
         d.addCallback(lambda _: True)
@@ -138,7 +139,6 @@ class Scheduler(base.ResourceType):
 
     @defer.inlineCallbacks
     def _masterDeactivated(self, masterid):
-        schedulers = yield self.master.db.schedulers.getSchedulers(
-            masterid=masterid)
+        schedulers = yield self.master.db.schedulers.getSchedulers(masterid=masterid)
         for sch in schedulers:
-            yield self.master.db.schedulers.setSchedulerMaster(sch['id'], None)
+            yield self.master.db.schedulers.setSchedulerMaster(sch.id, None)
