@@ -13,8 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 from twisted.internet import defer
 from twisted.python import util
@@ -25,6 +23,7 @@ def patch_noargs_decorator(decorator):
         wrapper = decorator(func)
         wrapper.__wrapped__ = func
         return wrapper
+
     util.mergeFunctionMetadata(decorator, new_decorator)
     return new_decorator
 
