@@ -13,6 +13,10 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from twisted.internet import defer
 from twisted.python import log
 
@@ -25,8 +29,13 @@ from buildbot.process.buildrequestdistributor import BuildRequestDistributor
 from buildbot.process.results import CANCELLED
 from buildbot.process.results import RETRY
 from buildbot.process.workerforbuilder import States
+from buildbot.util import debounce
 from buildbot.util import service
 from buildbot.util.render_description import render_description
+from buildbot.worker.latent import AbstractLatentWorker
+
+if TYPE_CHECKING:
+    from buildbot.worker import AbstractWorker
 
 
 class LockRetrieverMixin:
@@ -69,9 +78,10 @@ class LockRetrieverMixin:
     @defer.inlineCallbacks
     def getLockFromLockAccesses(self, accesses, config_version):
         # converts locks to their real forms
-        locks = yield defer.gatherResults([
-            self.getLockFromLockAccess(access, config_version) for access in accesses
-        ])
+        locks = yield defer.gatherResults(
+            [self.getLockFromLockAccess(access, config_version) for access in accesses],
+            consumeErrors=True,
+        )
         return zip(locks, accesses)
 
 
@@ -81,17 +91,18 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
     them."""
 
     debug = 0
-    name = "botmaster"
+    name: str | None = "botmaster"  # type: ignore[assignment]
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
 
-        self.builders = {}
-        self.builderNames = []
+        self.builders: dict[str, Builder] = {}
+        self.builderNames: list[str] = []
         # builders maps Builder names to instances of bb.p.builder.Builder,
         # which is the master-side object that defines and controls a build.
 
-        self.watchers = {}
+        # Unused?
+        self.watchers: dict[object, object] = {}
 
         self.shuttingDown = False
 
@@ -103,10 +114,11 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
         # a distributor for incoming build requests; see below
         self.brd = BuildRequestDistributor(self)
         self.brd.setServiceParent(self)
+        self._pending_builderids = set()
 
         # Dictionary of build request ID to False or cancellation reason string in case cancellation
         # has been requested.
-        self._starting_brid_to_cancel = {}
+        self._starting_brid_to_cancel: dict[int, bool | str] = {}
 
     @defer.inlineCallbacks
     def cleanShutdown(self, quickMode=False, stopReactor=True):
@@ -120,7 +132,13 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
         self.shuttingDown = True
         # first, stop the distributor; this will finish any ongoing scheduling
         # operations before firing
-        yield self.brd.disownServiceParent()
+        if quickMode:
+            # if quick mode, builds will be cancelled, so stop scheduling altogether
+            yield self.brd.disownServiceParent()
+        else:
+            # if not quick, still schedule waited child builds
+            # other parent will never finish
+            self.brd.distribute_only_waited_childs = True
 
         # Double check that we're still supposed to be shutting down
         # The shutdown may have been cancelled!
@@ -136,7 +154,10 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
                             results = CANCELLED
                         else:
                             results = RETRY
-                        is_building = build.workerforbuilder.state == States.BUILDING
+                        is_building = (
+                            build.workerforbuilder is not None
+                            and build.workerforbuilder.state == States.BUILDING
+                        )
 
                         # Master should not wait build.stopBuild for ages to complete if worker
                         # does not send any message about shutting the builds down quick enough.
@@ -157,7 +178,11 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
                         if not is_building:
                             # if it is not building, then it must be a latent worker
                             # which is substantiating. Cancel it.
-                            build.workerforbuilder.worker.insubstantiate()
+                            if build.workerforbuilder is not None and isinstance(
+                                build.workerforbuilder.worker,
+                                AbstractLatentWorker,
+                            ):
+                                build.workerforbuilder.worker.insubstantiate()
             # then wait for all builds to finish
             dl = []
             for builder in self.builders.values():
@@ -172,7 +197,7 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
                 log.msg("No running jobs, starting shutdown immediately")
             else:
                 log.msg(f"Waiting for {len(dl)} build(s) to finish")
-                yield defer.DeferredList(dl)
+                yield defer.DeferredList(dl, consumeErrors=True)
 
             # Check that there really aren't any running builds
             n = 0
@@ -186,13 +211,20 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
                 log.msg("Trying shutdown sequence again")
                 yield util.asyncSleep(1)
             else:
-                if stopReactor and self.shuttingDown:
-                    log.msg("Stopping reactor")
-                    self.master.reactor.stop()
                 break
 
+        # shutdown was cancelled
         if not self.shuttingDown:
-            yield self.brd.setServiceParent(self)
+            if quickMode:
+                yield self.brd.setServiceParent(self)
+            else:
+                self.brd.distribute_only_waited_childs = False
+
+            return
+
+        if stopReactor:
+            log.msg("Stopping reactor")
+            self.master.reactor.stop()
 
     def cancelCleanShutdown(self):
         """Cancel a clean shutdown that is already in progress, if any"""
@@ -202,15 +234,19 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
         self.shuttingDown = False
 
     @metrics.countMethod('BotMaster.workerLost()')
-    def workerLost(self, bot):
+    def workerLost(self, bot: AbstractWorker):
         metrics.MetricCountEvent.log("BotMaster.attached_workers", -1)
         for b in self.builders.values():
-            if bot.workername in b.config.workernames:
+            if b.config is not None and bot.workername in b.config.workernames:
                 b.detached(bot)
 
     @metrics.countMethod('BotMaster.getBuildersForWorker()')
-    def getBuildersForWorker(self, workername):
-        return [b for b in self.builders.values() if workername in b.config.workernames]
+    def getBuildersForWorker(self, workername: str):
+        return [
+            b
+            for b in self.builders.values()
+            if b.config is not None and workername in b.config.workernames
+        ]
 
     def getBuildernames(self):
         return self.builderNames
@@ -218,29 +254,38 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
     def getBuilders(self):
         return list(self.builders.values())
 
-    @defer.inlineCallbacks
+    def _buildrequest_added(self, key, msg):
+        self._pending_builderids.add(msg['builderid'])
+        self._flush_pending_builders()
+
+    # flush pending builders needs to be debounced, as per design the
+    # buildrequests events will arrive in burst.
+    # We debounce them to let the brd manage them as a whole
+    # without having to debounce the brd itself
+    @debounce.method(wait=0.1, until_idle=True)
+    def _flush_pending_builders(self):
+        if not self._pending_builderids:
+            return
+        buildernames = []
+        for builderid in self._pending_builderids:
+            builder = self.getBuilderById(builderid)
+            if builder:
+                buildernames.append(builder.name)
+        self._pending_builderids.clear()
+        self.brd.maybeStartBuildsOn(buildernames)
+
     def getBuilderById(self, builderid):
-        for builder in self.getBuilders():
-            if builderid == (yield builder.getBuilderId()):
-                return builder
-        return None
+        return self._builders_byid.get(builderid)
 
     @defer.inlineCallbacks
     def startService(self):
-        @defer.inlineCallbacks
-        def buildRequestAdded(key, msg):
-            builderid = msg['builderid']
-            builder = yield self.getBuilderById(builderid)
-            if builder is not None:
-                self.maybeStartBuildsForBuilder(builder.name)
-
-        # consume both 'new' and 'unclaimed' build requests
+        # consume both 'new' and 'unclaimed' build requests events
         startConsuming = self.master.mq.startConsuming
         self.buildrequest_consumer_new = yield startConsuming(
-            buildRequestAdded, ('buildrequests', None, "new")
+            self._buildrequest_added, ('buildrequests', None, "new")
         )
         self.buildrequest_consumer_unclaimed = yield startConsuming(
-            buildRequestAdded, ('buildrequests', None, 'unclaimed')
+            self._buildrequest_added, ('buildrequests', None, 'unclaimed')
         )
         self.buildrequest_consumer_cancel = yield startConsuming(
             self._buildrequest_canceled, ('control', 'buildrequests', None, 'cancel')
@@ -346,6 +391,9 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
                 yield builder.setServiceParent(self)
 
         self.builderNames = list(self.builders)
+        self._builders_byid = {}
+        for builder in self.builders.values():
+            self._builders_byid[(yield builder.getBuilderId())] = builder
 
         yield self.master.data.updates.updateBuilderList(
             self.master.masterid, [util.bytes2unicode(n) for n in self.builderNames]
@@ -365,6 +413,8 @@ class BotMaster(service.ReconfigurableServiceMixin, service.AsyncMultiService, L
         if self.buildrequest_consumer_cancel:
             self.buildrequest_consumer_cancel.stopConsuming()
             self.buildrequest_consumer_cancel = None
+        self._pending_builderids.clear()
+        self._flush_pending_builders.stop()
         return super().stopService()
 
     # Used to track buildrequests that are in progress of being started on this master.
