@@ -13,15 +13,19 @@
 #
 # Copyright Buildbot Team Members
 
+from typing import TYPE_CHECKING
 
 from zope.interface import implementer
 
 from buildbot import interfaces
 
+if TYPE_CHECKING:
+    from buildbot.process.build import Build
+    from buildbot.process.log import Log
+
 
 @implementer(interfaces.ILogObserver)
-class LogObserver(object):
-
+class LogObserver:
     def setStep(self, step):
         self.step = step
 
@@ -50,6 +54,11 @@ class LogObserver(object):
     def headerReceived(self, data):
         pass
 
+    def logChunk(
+        self, build: "Build", step: interfaces.IBuildStep, log: "Log", channel: str, text: str
+    ) -> None:
+        pass
+
 
 class LogLineObserver(LogObserver):
     stdoutDelimiter = "\n"
@@ -57,6 +66,7 @@ class LogLineObserver(LogObserver):
     headerDelimiter = "\n"
 
     def __init__(self):
+        super().__init__()
         self.max_length = 16384
 
     def setMaxLineLength(self, max_length):
@@ -85,23 +95,19 @@ class LogLineObserver(LogObserver):
     def outLineReceived(self, line):
         """This will be called with complete stdout lines (not including the
         delimiter). Override this in your observer."""
-        pass
 
     def errLineReceived(self, line):
         """This will be called with complete lines of stderr (not including
         the delimiter). Override this in your observer."""
-        pass
 
     def headerLineReceived(self, line):
         """This will be called with complete lines of stderr (not including
         the delimiter). Override this in your observer."""
-        pass
 
 
 class LineConsumerLogObserver(LogLineObserver):
-
     def __init__(self, consumerFunction):
-        LogLineObserver.__init__(self)
+        super().__init__()
         self.generator = None
         self.consumerFunction = consumerFunction
 
@@ -142,9 +148,8 @@ class OutputProgressObserver(LogObserver):
 
 
 class BufferLogObserver(LogObserver):
-
     def __init__(self, wantStdout=True, wantStderr=False):
-        LogObserver.__init__(self)
+        super().__init__()
         self.stdout = [] if wantStdout else None
         self.stderr = [] if wantStderr else None
 
