@@ -12,12 +12,12 @@
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # Copyright Buildbot Team Members
+from __future__ import annotations
+
 from typing import ClassVar
-from typing import Dict
 from typing import Sequence
 
 from twisted.internet import defer
-from twisted.python import failure
 from twisted.python import log
 from zope.interface import implementer
 
@@ -31,7 +31,7 @@ from buildbot.util.state import StateMixin
 
 @implementer(interfaces.IScheduler)
 class BaseScheduler(ClusteredBuildbotService, StateMixin):
-    DEFAULT_CODEBASES: Dict[str, Dict[str, str]] = {'': {}}
+    DEFAULT_CODEBASES: dict[str, dict[str, str]] = {'': {}}
 
     compare_attrs: ClassVar[Sequence[str]] = (
         *ClusteredBuildbotService.compare_attrs,
@@ -227,8 +227,8 @@ class BaseScheduler(ClusteredBuildbotService, StateMixin):
                 important = fileIsImportant(change)
                 if not important and onlyImportant:
                     return
-            except Exception:
-                log.err(failure.Failure(), f'in fileIsImportant check for {change}')
+            except Exception as e:
+                log.err(e, f'in fileIsImportant check for {change}')
                 return
         else:
             important = True
