@@ -13,8 +13,11 @@
 #
 # Copyright Buildbot Team Members
 
+import base64
 import json
 import os
+from typing import ClassVar
+from typing import Sequence
 
 from twisted.internet import defer
 from twisted.protocols import basic
@@ -26,11 +29,11 @@ from buildbot.process.properties import Properties
 from buildbot.schedulers import base
 from buildbot.util import bytes2unicode
 from buildbot.util import netstrings
+from buildbot.util import unicode2bytes
 from buildbot.util.maildir import MaildirService
 
 
 class TryBase(base.BaseScheduler):
-
     def filterBuilderList(self, builderNames):
         """
         Make sure that C{builderNames} is a subset of the configured
@@ -47,8 +50,8 @@ class TryBase(base.BaseScheduler):
         if builderNames:
             for b in builderNames:
                 if b not in self.builderNames:
-                    log.msg("{} got with builder {}".format(self, b))
-                    log.msg(" but that wasn't in our list: {}".format(self.builderNames))
+                    log.msg(f"{self} got with builder {b}")
+                    log.msg(f" but that wasn't in our list: {self.builderNames}")
                     return []
         else:
             builderNames = self.builderNames
@@ -76,8 +79,7 @@ class JobdirService(MaildirService):
 
 
 class Try_Jobdir(TryBase):
-
-    compare_attrs = ('jobdir',)
+    compare_attrs: ClassVar[Sequence[str]] = ('jobdir',)
 
     def __init__(self, name, builderNames, jobdir, **kwargs):
         super().__init__(name, builderNames, **kwargs)
@@ -135,11 +137,13 @@ class Try_Jobdir(TryBase):
         #  "4" introduces comment
         #  "5" introduces properties and JSON serialization of values after
         #      version
+        #  "6" sends patch_body as base64-encoded string in the patch_body_base64 attribute
         #  jobid: arbitrary string, used to find the buildSet later
         #  branch: branch name, "" for default-branch
         #  baserev: revision, "" for HEAD
         #  patch_level: usually "1"
-        #  patch_body: patch to be applied for build
+        #  patch_body: patch to be applied for build (as string)
+        #  patch_body_base64: patch to be applied for build (as base64-encoded bytes)
         #  repository
         #  project
         #  who: user requesting build
@@ -149,8 +153,10 @@ class Try_Jobdir(TryBase):
         p = netstrings.NetstringParser()
         f.seek(0, 2)
         if f.tell() > basic.NetstringReceiver.MAX_LENGTH:
-            raise BadJobfile("The patch size is greater that NetStringReceiver.MAX_LENGTH. "
-                             "Please Set this higher in the master.cfg")
+            raise BadJobfile(
+                "The patch size is greater that NetStringReceiver.MAX_LENGTH. "
+                "Please Set this higher in the master.cfg"
+            )
         f.seek(0, 0)
         try:
             p.feed(f.read())
@@ -161,9 +167,9 @@ class Try_Jobdir(TryBase):
         ver = bytes2unicode(p.strings.pop(0))
 
         v1_keys = ['jobid', 'branch', 'baserev', 'patch_level', 'patch_body']
-        v2_keys = v1_keys + ['repository', 'project']
-        v3_keys = v2_keys + ['who']
-        v4_keys = v3_keys + ['comment']
+        v2_keys = [*v1_keys, "repository", "project"]
+        v3_keys = [*v2_keys, "who"]
+        v4_keys = [*v3_keys, "comment"]
         keys = [v1_keys, v2_keys, v3_keys, v4_keys]
         # v5 introduces properties and uses JSON serialization
 
@@ -171,7 +177,10 @@ class Try_Jobdir(TryBase):
 
         def extract_netstrings(p, keys):
             for i, key in enumerate(keys):
-                parsed_job[key] = bytes2unicode(p.strings[i])
+                if key == 'patch_body':
+                    parsed_job[key] = p.strings[i]
+                else:
+                    parsed_job[key] = bytes2unicode(p.strings[i])
 
         def postprocess_parsed_job():
             # apply defaults and handle type casting
@@ -185,18 +194,27 @@ class Try_Jobdir(TryBase):
         if ver <= "4":
             i = int(ver) - 1
             extract_netstrings(p, keys[i])
-            parsed_job['builderNames'] = [bytes2unicode(s)
-                                          for s in p.strings[len(keys[i]):]]
+            parsed_job['builderNames'] = [bytes2unicode(s) for s in p.strings[len(keys[i]) :]]
             postprocess_parsed_job()
         elif ver == "5":
             try:
                 data = bytes2unicode(p.strings[0])
                 parsed_job = json.loads(data)
+                parsed_job['patch_body'] = unicode2bytes(parsed_job['patch_body'])
+            except ValueError as e:
+                raise BadJobfile("unable to parse JSON") from e
+            postprocess_parsed_job()
+        elif ver == "6":
+            try:
+                data = bytes2unicode(p.strings[0])
+                parsed_job = json.loads(data)
+                parsed_job['patch_body'] = base64.b64decode(parsed_job['patch_body_base64'])
+                del parsed_job['patch_body_base64']
             except ValueError as e:
                 raise BadJobfile("unable to parse JSON") from e
             postprocess_parsed_job()
         else:
-            raise BadJobfile("unknown version '{}'".format(ver))
+            raise BadJobfile(f"unknown version '{ver}'")
         return parsed_job
 
     def handleJobFile(self, filename, f):
@@ -204,15 +222,14 @@ class Try_Jobdir(TryBase):
             parsed_job = self.parseJob(f)
             builderNames = parsed_job['builderNames']
         except BadJobfile:
-            log.msg("{} reports a bad jobfile in {}".format(self, filename))
+            log.msg(f"{self} reports a bad jobfile in {filename}")
             log.err()
             return defer.succeed(None)
 
         # Validate/fixup the builder names.
         builderNames = self.filterBuilderList(builderNames)
         if not builderNames:
-            log.msg(
-                "incoming Try job did not specify any allowed builder names")
+            log.msg("incoming Try job did not specify any allowed builder names")
             return defer.succeed(None)
 
         who = ""
@@ -223,20 +240,22 @@ class Try_Jobdir(TryBase):
         if parsed_job['comment']:
             comment = parsed_job['comment']
 
-        sourcestamp = dict(branch=parsed_job['branch'],
-                           codebase='',
-                           revision=parsed_job['baserev'],
-                           patch_body=parsed_job['patch_body'],
-                           patch_level=parsed_job['patch_level'],
-                           patch_author=who,
-                           patch_comment=comment,
-                           # TODO: can't set this remotely - #1769
-                           patch_subdir='',
-                           project=parsed_job['project'],
-                           repository=parsed_job['repository'])
+        sourcestamp = {
+            "branch": parsed_job['branch'],
+            "codebase": '',
+            "revision": parsed_job['baserev'],
+            "patch_body": parsed_job['patch_body'],
+            "patch_level": parsed_job['patch_level'],
+            "patch_author": who,
+            "patch_comment": comment,
+            # TODO: can't set this remotely - #1769
+            "patch_subdir": '',
+            "project": parsed_job['project'],
+            "repository": parsed_job['repository'],
+        }
         reason = "'try' job"
         if parsed_job['who']:
-            reason += " by user {}".format(bytes2unicode(parsed_job['who']))
+            reason += f" by user {bytes2unicode(parsed_job['who'])}"
         properties = parsed_job['properties']
         requested_props = Properties()
         requested_props.update(properties, "try build")
@@ -246,11 +265,12 @@ class Try_Jobdir(TryBase):
             reason=reason,
             external_idstring=bytes2unicode(parsed_job['jobid']),
             builderNames=builderNames,
-            properties=requested_props)
+            priority=self.priority,
+            properties=requested_props,
+        )
 
 
 class RemoteBuildSetStatus(pb.Referenceable):
-
     def __init__(self, master, bsid, brids):
         self.master = master
         self.bsid = bsid
@@ -258,16 +278,14 @@ class RemoteBuildSetStatus(pb.Referenceable):
 
     @defer.inlineCallbacks
     def remote_getBuildRequests(self):
-        brids = dict()
+        brids = {}
         for builderid, brid in self.brids.items():
             builderDict = yield self.master.data.get(('builders', builderid))
             brids[builderDict['name']] = brid
-        return [(n, RemoteBuildRequest(self.master, n, brid))
-            for n, brid in brids.items()]
+        return [(n, RemoteBuildRequest(self.master, n, brid)) for n, brid in brids.items()]
 
 
 class RemoteBuildRequest(pb.Referenceable):
-
     def __init__(self, master, builderName, brid):
         self.master = master
         self.builderName = builderName
@@ -290,14 +308,14 @@ class RemoteBuildRequest(pb.Referenceable):
             if msg['buildid'] in reportedBuilds:
                 return None
             reportedBuilds.add(msg['buildid'])
-            return subscriber.callRemote('newbuild',
-                                         RemoteBuild(
-                                             self.master, msg, self.builderName),
-                                         self.builderName)
+            return subscriber.callRemote(
+                'newbuild', RemoteBuild(self.master, msg, self.builderName), self.builderName
+            )
+
         self.consumer = yield self.master.mq.startConsuming(
-            gotBuild, ('builders', str(builderId), 'builds', None, None))
-        subscriber.notifyOnDisconnect(lambda _:
-                                      self.remote_unsubscribe(subscriber))
+            gotBuild, ('builders', str(builderId), 'builds', None, None)
+        )
+        subscriber.notifyOnDisconnect(lambda _: self.remote_unsubscribe(subscriber))
 
         # and get any existing builds
         builds = yield self.master.data.get(('buildrequests', self.brid, 'builds'))
@@ -305,10 +323,9 @@ class RemoteBuildRequest(pb.Referenceable):
             if build['buildid'] in reportedBuilds:
                 continue
             reportedBuilds.add(build['buildid'])
-            yield subscriber.callRemote('newbuild',
-                                        RemoteBuild(
-                                            self.master, build, self.builderName),
-                                        self.builderName)
+            yield subscriber.callRemote(
+                'newbuild', RemoteBuild(self.master, build, self.builderName), self.builderName
+            )
 
     def remote_unsubscribe(self, subscriber):
         if self.consumer:
@@ -317,7 +334,6 @@ class RemoteBuildRequest(pb.Referenceable):
 
 
 class RemoteBuild(pb.Referenceable):
-
     def __init__(self, master, builddict, builderName):
         self.master = master
         self.builddict = builddict
@@ -328,19 +344,20 @@ class RemoteBuild(pb.Referenceable):
     def remote_subscribe(self, subscriber, interval):
         # subscribe to any new steps..
         def stepChanged(key, msg):
-            log.msg("SC")
             if key[-1] == 'started':
-                return subscriber.callRemote('stepStarted',
-                                             self.builderName, self, msg['name'], None)
+                return subscriber.callRemote(
+                    'stepStarted', self.builderName, self, msg['name'], None
+                )
             elif key[-1] == 'finished':
-                return subscriber.callRemote('stepFinished', self.builderName, self, msg['name'],
-                                             None, msg['results'])
+                return subscriber.callRemote(
+                    'stepFinished', self.builderName, self, msg['name'], None, msg['results']
+                )
             return None
+
         self.consumer = yield self.master.mq.startConsuming(
-            stepChanged,
-            ('builds', str(self.builddict['buildid']), 'steps', None, None))
-        subscriber.notifyOnDisconnect(lambda _:
-                                      self.remote_unsubscribe(subscriber))
+            stepChanged, ('builds', str(self.builddict['buildid']), 'steps', None, None)
+        )
+        subscriber.notifyOnDisconnect(lambda _: self.remote_unsubscribe(subscriber))
 
     def remote_unsubscribe(self, subscriber):
         if self.consumer:
@@ -352,14 +369,16 @@ class RemoteBuild(pb.Referenceable):
         d = defer.Deferred()
 
         def buildEvent(key, msg):
-            log.msg("BE")
             if key[-1] == 'finished':
                 d.callback(None)
-        consumer = yield self.master.mq.startConsuming(
-            buildEvent,
-            ('builds', str(self.builddict['buildid']), None))
 
-        yield d  # wait for event
+        buildid = self.builddict['buildid']
+        consumer = yield self.master.mq.startConsuming(buildEvent, ('builds', str(buildid), None))
+        builddict = yield self.master.data.get(('builds', buildid))
+        # build might have finished before we called startConsuming
+        if not builddict.get('complete', False):
+            yield d  # wait for event
+
         consumer.stopConsuming()
         return self  # callers expect result=self
 
@@ -377,15 +396,24 @@ class RemoteBuild(pb.Referenceable):
 
 
 class Try_Userpass_Perspective(pbutil.NewCredPerspective):
-
     def __init__(self, scheduler, username):
         self.scheduler = scheduler
         self.username = username
 
     @defer.inlineCallbacks
-    def perspective_try(self, branch, revision, patch, repository, project,
-                        builderNames, who="", comment="", properties=None):
-        log.msg("user {} requesting build on builders {}".format(self.username, builderNames))
+    def perspective_try(
+        self,
+        branch,
+        revision,
+        patch,
+        repository,
+        project,
+        builderNames,
+        who="",
+        comment="",
+        properties=None,
+    ):
+        log.msg(f"user {self.username} requesting build on builders {builderNames}")
         if properties is None:
             properties = {}
         # build the intersection of the request and our configured list
@@ -395,7 +423,8 @@ class Try_Userpass_Perspective(pbutil.NewCredPerspective):
 
         branch = bytes2unicode(branch)
         revision = bytes2unicode(revision)
-        patch = patch[0], bytes2unicode(patch[1])
+        patch_level = patch[0]
+        patch_body = unicode2bytes(patch[1])
         repository = bytes2unicode(repository)
         project = bytes2unicode(project)
         who = bytes2unicode(who)
@@ -404,23 +433,32 @@ class Try_Userpass_Perspective(pbutil.NewCredPerspective):
         reason = "'try' job"
 
         if who:
-            reason += " by user {}".format(bytes2unicode(who))
+            reason += f" by user {bytes2unicode(who)}"
 
         if comment:
-            reason += " ({})".format(bytes2unicode(comment))
+            reason += f" ({bytes2unicode(comment)})"
 
-        sourcestamp = dict(
-            branch=branch, revision=revision, repository=repository,
-            project=project, patch_level=patch[0], patch_body=patch[1],
-            patch_subdir='', patch_author=who or '',
-            patch_comment=comment or '', codebase='',
-        )           # note: no way to specify patch subdir - #1769
+        sourcestamp = {
+            "branch": branch,
+            "revision": revision,
+            "repository": repository,
+            "project": project,
+            "patch_level": patch_level,
+            "patch_body": patch_body,
+            "patch_subdir": '',
+            "patch_author": who or '',
+            "patch_comment": comment or '',
+            "codebase": '',
+        }  # note: no way to specify patch subdir - #1769
 
         requested_props = Properties()
         requested_props.update(properties, "try build")
         (bsid, brids) = yield self.scheduler.addBuildsetForSourceStamps(
-            sourcestamps=[sourcestamp], reason=reason,
-            properties=requested_props, builderNames=builderNames)
+            sourcestamps=[sourcestamp],
+            reason=reason,
+            properties=requested_props,
+            builderNames=builderNames,
+        )
 
         # return a remotely-usable BuildSetStatus object
         bss = RemoteBuildSetStatus(self.scheduler.master, bsid, brids)
@@ -435,7 +473,13 @@ class Try_Userpass_Perspective(pbutil.NewCredPerspective):
 
 
 class Try_Userpass(TryBase):
-    compare_attrs = ('name', 'builderNames', 'port', 'userpass', 'properties')
+    compare_attrs: ClassVar[Sequence[str]] = (
+        'name',
+        'builderNames',
+        'port',
+        'userpass',
+        'properties',
+    )
 
     def __init__(self, name, builderNames, port, userpass, **kwargs):
         super().__init__(name, builderNames, **kwargs)
@@ -453,6 +497,7 @@ class Try_Userpass(TryBase):
         # register each user/passwd with the pbmanager
         def factory(mind, username):
             return Try_Userpass_Perspective(self, username)
+
         for user, passwd in self.userpass:
             reg = yield self.master.pbmanager.register(self.port, user, passwd, factory)
             self.registrations.append(reg)
@@ -465,4 +510,5 @@ class Try_Userpass(TryBase):
             return
 
         yield defer.gatherResults(
-            [reg.unregister() for reg in self.registrations])
+            [reg.unregister() for reg in self.registrations], consumeErrors=True
+        )
