@@ -13,6 +13,8 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
+
 import copy
 import errno
 import os
@@ -24,7 +26,8 @@ from contextlib import contextmanager
 from twisted.python import runtime
 from twisted.python import usage
 
-from buildbot import config as config_module
+from buildbot.config.errors import ConfigErrors
+from buildbot.config.master import FileLoader
 
 
 @contextmanager
@@ -35,6 +38,7 @@ def captureErrors(errors, msg):
         print(msg)
         print(e)
         return 1
+    return None
 
 
 class BusyError(RuntimeError):
@@ -42,28 +46,29 @@ class BusyError(RuntimeError):
 
 
 def checkPidFile(pidfile):
-    """ mostly comes from _twistd_unix.py which is not twisted public API :-/
+    """mostly comes from _twistd_unix.py which is not twisted public API :-/
 
-        except it returns an exception instead of exiting
+    except it returns an exception instead of exiting
     """
     if os.path.exists(pidfile):
         try:
-            with open(pidfile) as f:
+            with open(pidfile, encoding='utf-8') as f:
                 pid = int(f.read())
-        except ValueError:
-            raise ValueError('Pidfile {} contains non-numeric value'.format(pidfile))
+        except ValueError as e:
+            raise ValueError(f'Pidfile {pidfile} contains non-numeric value') from e
         try:
             os.kill(pid, 0)
         except OSError as why:
             if why.errno == errno.ESRCH:
                 # The pid doesn't exist.
-                print('Removing stale pidfile {}'.format(pidfile))
+                print(f'Removing stale pidfile {pidfile}')
                 os.remove(pidfile)
             else:
-                raise OSError("Can't check status of PID {} from pidfile {}: {}".format(
-                    pid, pidfile, why))
+                raise OSError(
+                    f"Can't check status of PID {pid} from pidfile {pidfile}: {why}"
+                ) from why
         else:
-            raise BusyError("'{}' exists - is this master still running?".format(pidfile))
+            raise BusyError(f"'{pidfile}' exists - is this master still running?")
 
 
 def checkBasedir(config):
@@ -89,14 +94,12 @@ def checkBasedir(config):
         if isinstance(tac.get('rotateLength', 0), str):
             print("ERROR: rotateLength is a string, it should be a number")
             print("ERROR: Please, edit your buildbot.tac file and run again")
-            print(
-                "ERROR: See http://trac.buildbot.net/ticket/2588 for more details")
+            print("ERROR: See http://trac.buildbot.net/ticket/2588 for more details")
             return False
         if isinstance(tac.get('maxRotatedFiles', 0), str):
             print("ERROR: maxRotatedFiles is a string, it should be a number")
             print("ERROR: Please, edit your buildbot.tac file and run again")
-            print(
-                "ERROR: See http://trac.buildbot.net/ticket/2588 for more details")
+            print("ERROR: See http://trac.buildbot.net/ticket/2588 for more details")
             return False
 
     return True
@@ -104,40 +107,38 @@ def checkBasedir(config):
 
 def loadConfig(config, configFileName='master.cfg'):
     if not config['quiet']:
-        print("checking %s" % configFileName)
+        print(f"checking {configFileName}")
 
     try:
-        master_cfg = config_module.FileLoader(
-            config['basedir'], configFileName).loadConfig()
-    except config_module.ConfigErrors as e:
+        master_cfg = FileLoader(config['basedir'], configFileName).loadConfig()
+    except ConfigErrors as e:
         print("Errors loading configuration:")
 
         for msg in e.errors:
             print("  " + msg)
-        return
+        return None
     except Exception:
         print("Errors loading configuration:")
         traceback.print_exc(file=sys.stdout)
-        return
+        return None
 
     return master_cfg
 
 
 def isBuildmasterDir(dir):
     def print_error(error_message):
-        print("%s\ninvalid buildmaster directory '%s'" % (error_message, dir))
+        print(f"{error_message}\ninvalid buildmaster directory '{dir}'")
 
     buildbot_tac = os.path.join(dir, "buildbot.tac")
     try:
-        with open(buildbot_tac) as f:
+        with open(buildbot_tac, encoding='utf-8') as f:
             contents = f.read()
-    except IOError as exception:
-        print_error("error reading '%s': %s" %
-                    (buildbot_tac, exception.strerror))
+    except OSError as exception:
+        print_error(f"error reading '{buildbot_tac}': {exception.strerror}")
         return False
 
     if "Application('buildmaster')" not in contents:
-        print_error("unexpected content in '%s'" % buildbot_tac)
+        print_error(f"unexpected content in '{buildbot_tac}'")
         return False
 
     return True
@@ -150,8 +151,8 @@ def getConfigFromTac(basedir, quiet=False):
         # relocatable buildmasters
         tacGlobals = {'__file__': tacFile}
         try:
-            with open(tacFile) as f:
-                exec(f.read(), tacGlobals)
+            with open(tacFile, encoding='utf-8') as f:
+                exec(f.read(), tacGlobals)  # pylint: disable=exec-used
         except Exception:
             if not quiet:
                 traceback.print_exc()
@@ -173,10 +174,10 @@ class SubcommandOptions(usage.Options):
     # .buildbot/options file.  Note that this *only* works with optParameters,
     # not optFlags.  Example:
     # buildbotOptions = [ [ 'optfile-name', 'parameter-name' ], .. ]
-    buildbotOptions = None
+    buildbotOptions: list[list[str]] | None = None
 
     # set this to options that must have non-None values
-    requiredOptions = []
+    requiredOptions: list[str] = []
 
     def __init__(self, *args):
         # for options in self.buildbotOptions, optParameters, and the options
@@ -194,11 +195,10 @@ class SubcommandOptions(usage.Options):
                 # pylint: disable=not-an-iterable
                 for optfile_name, option_name in self.buildbotOptions:
                     for i, val in enumerate(op):
-                        if (op[i][0] == option_name and
-                                optfile_name in optfile):
-                            op[i] = list(op[i])
+                        if val[0] == option_name and optfile_name in optfile:
+                            op[i] = list(val)
                             op[i][2] = optfile[optfile_name]
-        usage.Options.__init__(self, *args)
+        super().__init__(*args)
         if hasattr(cls, 'optParameters'):
             cls.optParameters = old_optParameters
 
@@ -217,7 +217,9 @@ class SubcommandOptions(usage.Options):
 
         if runtime.platformType == 'win32':
             # never trust env-vars, use the proper API
-            from win32com.shell import shellcon, shell
+            from win32com.shell import shell
+            from win32com.shell import shellcon
+
             appdata = shell.SHGetFolderPath(0, shellcon.CSIDL_APPDATA, 0, 0)
             home = os.path.join(appdata, "buildbot")
         else:
@@ -233,8 +235,7 @@ class SubcommandOptions(usage.Options):
             here = next
             toomany -= 1  # just in case
             if toomany == 0:
-                print("I seem to have wandered up into the infinite glories "
-                      "of the heavens. Oops.")
+                print("I seem to have wandered up into the infinite glories of the heavens. Oops.")
                 break
 
         searchpath.append(home)
@@ -245,16 +246,16 @@ class SubcommandOptions(usage.Options):
             if os.path.isdir(d):
                 if runtime.platformType != 'win32':
                     if os.stat(d)[stat.ST_UID] != os.getuid():
-                        print("skipping %s because you don't own it" % d)
+                        print(f"skipping {d} because you don't own it")
                         continue  # security, skip other people's directories
                 optfile = os.path.join(d, "options")
                 if os.path.exists(optfile):
                     try:
-                        with open(optfile, "r") as f:
+                        with open(optfile, encoding='utf-8') as f:
                             options = f.read()
-                        exec(options, localDict)
+                        exec(options, localDict)  # pylint: disable=exec-used
                     except Exception:
-                        print("error while reading %s" % optfile)
+                        print(f"error while reading {optfile}")
                         raise
                     break
 
@@ -273,8 +274,7 @@ class SubcommandOptions(usage.Options):
             raise usage.UsageError(msg)
 
 
-class BasedirMixin(object):
-
+class BasedirMixin:
     """SubcommandOptions Mixin to handle subcommands that take a basedir
     argument"""
 
@@ -283,7 +283,8 @@ class BasedirMixin(object):
         # only set completion suggestion if running with
         # twisted version (>=11.1.0) that supports it
         compData = usage.Completions(
-            extraActions=[usage.CompleteDirs(descr="buildbot base directory")])
+            extraActions=[usage.CompleteDirs(descr="buildbot base directory")]
+        )
 
     def parseArgs(self, *args):
         if args:
