@@ -106,8 +106,7 @@ CHILDCAPTURE_MAX_BLOCKS = 200
 class BBService(win32serviceutil.ServiceFramework):
     _svc_name_ = 'BuildBot'
     _svc_display_name_ = _svc_name_
-    _svc_description_ = 'Manages local buildbot workers and masters - ' \
-                        'see http://buildbot.net'
+    _svc_description_ = 'Manages local buildbot workers and masters - see http://buildbot.net'
 
     def __init__(self, args):
         super().__init__(args)
@@ -130,8 +129,7 @@ class BBService(win32serviceutil.ServiceFramework):
         # (We use the py2exe option that magically bundles the .pyd files
         # into the .zip file - so servicemanager.pyd doesn't exist.)
         if is_frozen and servicemanager.RunningAsService():
-            msg_file = os.path.join(os.path.dirname(sys.executable),
-                                    "buildbot.msg")
+            msg_file = os.path.join(os.path.dirname(sys.executable), "buildbot.msg")
             if os.path.isfile(msg_file):
                 servicemanager.Initialize("BuildBot", msg_file)
             else:
@@ -178,13 +176,14 @@ class BBService(win32serviceutil.ServiceFramework):
             dir_string = os.pathsep.join(self.args[1:])
             save_dirs = True
         else:
-            dir_string = win32serviceutil.GetServiceCustomOption(self,
-                                                                 "directories")
+            dir_string = win32serviceutil.GetServiceCustomOption(self, "directories")
             save_dirs = False
 
         if not dir_string:
-            self.error("You must specify the buildbot directories as "
-                       "parameters to the service.\nStopping the service.")
+            self.error(
+                "You must specify the buildbot directories as "
+                "parameters to the service.\nStopping the service."
+            )
             return False
 
         dirs = dir_string.split(os.pathsep)
@@ -197,13 +196,11 @@ class BBService(win32serviceutil.ServiceFramework):
                 msg = f"Directory '{d}' is not a buildbot dir - ignoring"
                 self.warning(msg)
         if not self.dirs:
-            self.error("No valid buildbot directories were specified.\n"
-                       "Stopping the service.")
+            self.error("No valid buildbot directories were specified.\nStopping the service.")
             return False
         if save_dirs:
             dir_string = os.pathsep.join(self.dirs)
-            win32serviceutil.SetServiceCustomOption(self, "directories",
-                                                    dir_string)
+            win32serviceutil.SetServiceCustomOption(self, "directories", dir_string)
         return True
 
     def SvcStop(self):
@@ -238,32 +235,35 @@ class BBService(win32serviceutil.ServiceFramework):
         while child_infos:
             handles = [self.hWaitStop] + [i[1] for i in child_infos]
 
-            rc = win32event.WaitForMultipleObjects(handles,
-                                                   0,  # bWaitAll
-                                                   win32event.INFINITE)
+            rc = win32event.WaitForMultipleObjects(
+                handles,
+                0,  # bWaitAll
+                win32event.INFINITE,
+            )
             if rc == win32event.WAIT_OBJECT_0:
                 # user sent a stop service request
                 break
             # A child process died.  For now, just log the output
             # and forget the process.
             index = rc - win32event.WAIT_OBJECT_0 - 1
-            bbdir, dead_handle, _, output_blocks = \
-                child_infos[index]
+            bbdir, dead_handle, _, output_blocks = child_infos[index]
             status = win32process.GetExitCodeProcess(dead_handle)
             output = "".join(output_blocks)
             if not output:
-                output = ("The child process generated no output. "
-                          "Please check the twistd.log file in the "
-                          "indicated directory.")
+                output = (
+                    "The child process generated no output. "
+                    "Please check the twistd.log file in the "
+                    "indicated directory."
+                )
 
-            self.warning(f"BuildBot for directory {repr(bbdir)} terminated with "
-                         f"exit code {status}.\n{output}")
+            self.warning(
+                f"BuildBot for directory {bbdir!r} terminated with exit code {status}.\n{output}"
+            )
 
             del child_infos[index]
 
             if not child_infos:
-                self.warning("All BuildBot child processes have "
-                             "terminated.  Service stopping.")
+                self.warning("All BuildBot child processes have terminated.  Service stopping.")
 
         # Either no child processes left, or stop event set.
         self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
@@ -283,8 +283,7 @@ class BBService(win32serviceutil.ServiceFramework):
             self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
             # If necessary, kill it
             if win32process.GetExitCodeProcess(h) == win32con.STILL_ACTIVE:
-                self.warning(f"BuildBot process at {repr(bbdir)} failed to terminate - "
-                             "killing it")
+                self.warning(f"BuildBot process at {bbdir!r} failed to terminate - killing it")
                 win32api.TerminateProcess(h, 3)
             self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
 
@@ -310,16 +309,17 @@ class BBService(win32serviceutil.ServiceFramework):
     def logmsg(self, event):
         # log a service event using servicemanager.LogMsg
         try:
-            servicemanager.LogMsg(servicemanager.EVENTLOG_INFORMATION_TYPE,
-                                  event,
-                                  (self._svc_name_,
-                                   f" ({self._svc_display_name_})"))
+            servicemanager.LogMsg(
+                servicemanager.EVENTLOG_INFORMATION_TYPE,
+                event,
+                (self._svc_name_, f" ({self._svc_display_name_})"),
+            )
         except win32api.error as details:
             # Failed to write a log entry - most likely problem is
             # that the event log is full.  We don't want this to kill us
             try:
                 print("FAILED to write INFO event", event, ":", details)
-            except IOError:
+            except OSError:
                 # No valid stdout!  Ignore it.
                 pass
 
@@ -332,7 +332,7 @@ class BBService(win32serviceutil.ServiceFramework):
             try:
                 print("FAILED to write event log entry:", details)
                 print(msg)
-            except IOError:
+            except OSError:
                 pass
 
     def info(self, s):
@@ -353,8 +353,9 @@ class BBService(win32serviceutil.ServiceFramework):
         hOutReadTemp, hOutWrite = self.newPipe()
         pid = win32api.GetCurrentProcess()
         # This one is duplicated as inheritable.
-        hErrWrite = win32api.DuplicateHandle(pid, hOutWrite, pid, 0, 1,
-                                             win32con.DUPLICATE_SAME_ACCESS)
+        hErrWrite = win32api.DuplicateHandle(
+            pid, hOutWrite, pid, 0, 1, win32con.DUPLICATE_SAME_ACCESS
+        )
 
         # These are non-inheritable duplicates.
         hOutRead = self.dup(hOutReadTemp)
@@ -365,8 +366,7 @@ class BBService(win32serviceutil.ServiceFramework):
         si.hStdInput = hInputRead
         si.hStdOutput = hOutWrite
         si.hStdError = hErrWrite
-        si.dwFlags = win32process.STARTF_USESTDHANDLES | \
-            win32process.STARTF_USESHOWWINDOW
+        si.dwFlags = win32process.STARTF_USESTDHANDLES | win32process.STARTF_USESHOWWINDOW
         si.wShowWindow = win32con.SW_HIDE
 
         # pass True to allow handles to be inherited.  Inheritance is
@@ -374,8 +374,7 @@ class BBService(win32serviceutil.ServiceFramework):
         # circumstances of a service process.
         create_flags = win32process.CREATE_NEW_CONSOLE
         # info is (hProcess, hThread, pid, tid)
-        info = win32process.CreateProcess(None, cmd, None, None, True,
-                                          create_flags, None, None, si)
+        info = win32process.CreateProcess(None, cmd, None, None, True, create_flags, None, None, si)
         # (NOTE: these really aren't necessary for Python - they are closed
         # as soon as they are collected)
         hOutWrite.Close()
@@ -386,8 +385,7 @@ class BBService(win32serviceutil.ServiceFramework):
 
         # start a thread collecting output
         blocks = []
-        t = threading.Thread(target=self.redirectCaptureThread,
-                             args=(hOutRead, blocks))
+        t = threading.Thread(target=self.redirectCaptureThread, args=(hOutRead, blocks))
         t.start()
         return info[0], t, blocks
 
@@ -421,8 +419,7 @@ class BBService(win32serviceutil.ServiceFramework):
         # it can be closed in the parent.  close the original pipe in
         # the process.
         pid = win32api.GetCurrentProcess()
-        dup = win32api.DuplicateHandle(pid, pipe, pid, 0, 0,
-                                       win32con.DUPLICATE_SAME_ACCESS)
+        dup = win32api.DuplicateHandle(pid, pipe, pid, 0, 0, win32con.DUPLICATE_SAME_ACCESS)
         pipe.Close()
         return dup
 
@@ -469,6 +466,7 @@ def RegisterWithFirewall(exe_name, description):
 def CustomInstall(opts):
     # Register this process with the Windows Firewall
     import pythoncom
+
     try:
         RegisterWithFirewall(sys.executable, "BuildBot")
     except pythoncom.com_error as why:
@@ -484,9 +482,7 @@ def CustomInstall(opts):
 def _RunChild(runfn):
     del sys.argv[1]  # The --spawn arg.
     # Create a new thread that just waits for the event to be signalled.
-    t = threading.Thread(target=_WaitForShutdown,
-                         args=(int(sys.argv[1]), )
-                         )
+    t = threading.Thread(target=_WaitForShutdown, args=(int(sys.argv[1]),))
     del sys.argv[1]  # The stop handle
     # This child process will be sent a console handler notification as
     # users log off, or as the system shuts down.  We want to ignore these
@@ -497,6 +493,7 @@ def _RunChild(runfn):
         # process is never attached to a console the user can press the
         # key in!
         return True
+
     win32api.SetConsoleCtrlHandler(ConsoleHandler, True)
     t.setDaemon(True)  # we don't want to wait for this to stop!
     t.start()
@@ -514,24 +511,27 @@ def _WaitForShutdown(h):
     print("Shutdown requested")
 
     from twisted.internet import reactor
+
     reactor.callLater(0, reactor.stop)
 
 
 def DetermineRunner(bbdir):
-    '''Checks if the given directory is a worker or a master and returns the
-    appropriate run function.'''
+    """Checks if the given directory is a worker or a master and returns the
+    appropriate run function."""
     tacfile = os.path.join(bbdir, 'buildbot.tac')
     if not os.path.exists(tacfile):
         # No tac-file - use master runner by default.
         import buildbot.scripts.runner
+
         return buildbot.scripts.runner.run
 
-    with open(tacfile, 'r', encoding='utf-8') as f:
+    with open(tacfile, encoding='utf-8') as f:
         contents = f.read()
 
     try:
         if 'import Worker' in contents:
             import buildbot_worker.scripts.runner
+
             return buildbot_worker.scripts.runner.run
 
     except ImportError:
@@ -540,7 +540,8 @@ def DetermineRunner(bbdir):
 
     try:
         if 'import BuildSlave' in contents:
-            import buildslave.scripts.runner
+            import buildslave.scripts.runner  # type: ignore[import-not-found]
+
             return buildslave.scripts.runner.run
 
     except ImportError:
@@ -549,8 +550,10 @@ def DetermineRunner(bbdir):
 
     # Treat as master by default.
     import buildbot.scripts.runner
+
     return buildbot.scripts.runner.run
 
+
 # This function is also called by the py2exe startup code.
 
 
@@ -562,8 +565,7 @@ def HandleCommandLine():
         # Fourth arg is the config directory to use for the buildbot/worker
         _RunChild(DetermineRunner(sys.argv[5]))
     else:
-        win32serviceutil.HandleCommandLine(BBService,
-                                           customOptionHandler=CustomInstall)
+        win32serviceutil.HandleCommandLine(BBService, customOptionHandler=CustomInstall)
 
 
 if __name__ == '__main__':
