@@ -13,15 +13,19 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
 
+import os
+import shutil
 import weakref
 from unittest import mock
 
 from twisted.internet import defer
 from twisted.internet import reactor
 
-from buildbot import config
+from buildbot.config.master import MasterConfig
 from buildbot.data.graphql import GraphQLConnector
+from buildbot.secrets.manager import SecretManager
 from buildbot.test import fakedb
 from buildbot.test.fake import bworkermanager
 from buildbot.test.fake import endpoint
@@ -31,11 +35,13 @@ from buildbot.test.fake import msgmanager
 from buildbot.test.fake import pbmanager
 from buildbot.test.fake.botmaster import FakeBotMaster
 from buildbot.test.fake.machine import FakeMachineManager
+from buildbot.test.fake.secrets import FakeSecretStorage
+from buildbot.test.util.db import resolve_test_db_url
 from buildbot.util import service
+from buildbot.util.twisted import async_to_deferred
 
 
 class FakeCache:
-
     """Emulate an L{AsyncLRUCache}, but without any real caching.  This
     I{does} do the weakref part, to catch un-weakref-able objects."""
 
@@ -51,6 +57,7 @@ class FakeCache:
             if x is not None:
                 weakref.ref(x)
             return x
+
         return d
 
     def put(self, key, val):
@@ -58,13 +65,11 @@ class FakeCache:
 
 
 class FakeCaches:
-
     def get_cache(self, name, miss_fn):
         return FakeCache(name, miss_fn)
 
 
 class FakeBuilder:
-
     def __init__(self, master=None, buildername="Builder"):
         if master:
             self.master = master
@@ -78,7 +83,6 @@ class FakeLogRotation:
 
 
 class FakeMaster(service.MasterService):
-
     """
     Create a fake Master instance: a Mock with some convenience
     implementations:
@@ -86,20 +90,27 @@ class FakeMaster(service.MasterService):
     - Non-caching implementation for C{self.caches}
     """
 
-    def __init__(self, reactor,
-                 master_id=fakedb.FakeBuildRequestsComponent.MASTER_ID):
+    buildbotURL: str
+    mq: fakemq.FakeMQConnector
+    data: fakedata.FakeDataConnector
+    graphql: GraphQLConnector
+    _test_want_db: bool = False
+    _test_did_shutdown: bool = False
+
+    def __init__(self, reactor, basedir='basedir', master_id=fakedb.FakeDBConnector.MASTER_ID):
         super().__init__()
         self._master_id = master_id
         self.reactor = reactor
         self.objectids = {}
-        self.config = config.master.MasterConfig()
+        self.config = MasterConfig()
         self.caches = FakeCaches()
         self.pbmanager = pbmanager.FakePBManager()
         self.initLock = defer.DeferredLock()
-        self.basedir = 'basedir'
+        self.basedir = basedir
         self.botmaster = FakeBotMaster()
         self.botmaster.setServiceParent(self)
         self.name = 'fake:/master'
+        self.httpservice = None
         self.masterid = master_id
         self.msgmanager = msgmanager.FakeMsgManager()
         self.workers = bworkermanager.FakeWorkerManager()
@@ -119,6 +130,7 @@ class FakeMaster(service.MasterService):
                 rv = self.objectids[k] = self.next_objectid
                 self.next_objectid += 1
             return defer.succeed(rv)
+
         self.db.state.getObjectId = getObjectId
 
     def getObjectId(self):
@@ -127,11 +139,43 @@ class FakeMaster(service.MasterService):
     def subscribeToBuildRequests(self, callback):
         pass
 
+    @defer.inlineCallbacks
+    def stopService(self):
+        yield super().stopService()
+        yield self.test_shutdown()
+
+    @defer.inlineCallbacks
+    def test_shutdown(self):
+        if self._test_did_shutdown:
+            return
+        self._test_did_shutdown = True
+        if self._test_want_db:
+            yield self.db._shutdown()
+        if os.path.isdir(self.basedir):
+            shutil.rmtree(self.basedir)
+
+
 # Leave this alias, in case we want to add more behavior later
 
 
-def make_master(testcase, wantMq=False, wantDb=False, wantData=False,
-                wantRealReactor=False, wantGraphql=False, url=None, **kwargs):
+@async_to_deferred
+async def make_master(
+    testcase,
+    wantMq=False,
+    wantDb=False,
+    wantData=False,
+    wantRealReactor=False,
+    wantGraphql=False,
+    with_secrets: dict | None = None,
+    url=None,
+    db_url=None,
+    sqlite_memory=True,
+    auto_upgrade=True,
+    auto_shutdown=True,
+    check_version=True,
+    auto_clean=True,
+    **kwargs,
+) -> FakeMaster:
     if wantRealReactor:
         _reactor = reactor
     else:
@@ -147,16 +191,34 @@ def make_master(testcase, wantMq=False, wantDb=False, wantData=False,
     if wantMq:
         assert testcase is not None, "need testcase for wantMq"
         master.mq = fakemq.FakeMQConnector(testcase)
-        master.mq.setServiceParent(master)
+        await master.mq.setServiceParent(master)
     if wantDb:
         assert testcase is not None, "need testcase for wantDb"
-        master.db = fakedb.FakeDBConnector(testcase)
-        master.db.setServiceParent(master)
+        master.db = fakedb.FakeDBConnector(
+            master.basedir,
+            testcase,
+            auto_upgrade=auto_upgrade,
+            check_version=check_version,
+            auto_clean=auto_clean,
+        )
+        master._test_want_db = True
+
+        if auto_shutdown:
+            # Add before setup so that failed database setup would still be closed and wouldn't
+            # affect further tests
+            testcase.addCleanup(master.test_shutdown)
+
+        master.db.configured_url = resolve_test_db_url(db_url, sqlite_memory)
+        if not os.path.exists(master.basedir):
+            os.makedirs(master.basedir)
+        await master.db.set_master(master)
+        await master.db.setup()
+
     if wantData:
         master.data = fakedata.FakeDataConnector(master, testcase)
     if wantGraphql:
         master.graphql = GraphQLConnector()
-        master.graphql.setServiceParent(master)
+        await master.graphql.setServiceParent(master)
         master.graphql.data = master.data.realConnector
         master.data._scanModule(endpoint)
         master.config.www = {'graphql': {"debug": True}}
@@ -164,4 +226,10 @@ def make_master(testcase, wantMq=False, wantDb=False, wantData=False,
             master.graphql.reconfigServiceWithBuildbotConfig(master.config)
         except ImportError:
             pass
+    if with_secrets is not None:
+        secret_service = SecretManager()
+        secret_service.services = [FakeSecretStorage(secretdict=with_secrets)]
+        # This should be awaited, but no other call to `setServiceParent` are awaited here
+        await secret_service.setServiceParent(master)
+
     return master
