@@ -19,7 +19,11 @@
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+from __future__ import annotations
 
+from typing import Any
+from typing import Callable
+from typing import Sequence
 
 from twisted.internet import defer
 from twisted.internet import reactor
@@ -32,6 +36,8 @@ from twisted.python import log
 from twisted.python.failure import Failure
 from zope.interface import implementer
 
+from buildbot.util.twisted import async_to_deferred
+
 # The code here is based on the implementations in
 # https://twistedmatrix.com/trac/ticket/8295
 # https://twistedmatrix.com/trac/ticket/8296
@@ -47,9 +53,11 @@ class CoreReactor:
         super().__init__()
         self._triggers = {}
 
-    def addSystemEventTrigger(self, phase, eventType, f, *args, **kw):
+    def addSystemEventTrigger(
+        self, phase: str, eventType: str, callable: Callable[..., Any], *args, **kw
+    ):
         event = self._triggers.setdefault(eventType, _ThreePhaseEvent())
-        return eventType, event.addTrigger(phase, f, *args, **kw)
+        return eventType, event.addTrigger(phase, callable, *args, **kw)
 
     def removeSystemEventTrigger(self, triggerID):
         eventType, handle = triggerID
@@ -61,8 +69,31 @@ class CoreReactor:
         if event is not None:
             event.fireEvent()
 
-    def callWhenRunning(self, f, *args, **kwargs):
-        f(*args, **kwargs)
+    def callWhenRunning(self, callable: Callable[..., Any], *args, **kwargs):
+        callable(*args, **kwargs)
+
+    def resolve(self, name: str, timeout: Sequence[int]) -> defer.Deferred[str]:  # type: ignore
+        # Twisted 24.11 changed the default value of timeout, thus to support
+        # both versions typing is disabled
+        raise NotImplementedError("resolve() is not implemented in this reactor")
+
+    def stop(self) -> None:
+        raise NotImplementedError("stop() is not implemented in this reactor")
+
+    def running(self) -> bool:
+        raise NotImplementedError("running() is not implemented in this reactor")
+
+    def crash(self):
+        raise NotImplementedError("crash() is not implemented in this reactor")
+
+    def iterate(self, delay=None):
+        raise NotImplementedError("iterate() is not implemented in this reactor")
+
+    def run(self):
+        raise NotImplementedError("run() is not implemented in this reactor")
+
+    def runUntilCurrent(self):
+        raise NotImplementedError("runUntilCurrent() is not implemented in this reactor")
 
 
 class NonThreadPool:
@@ -86,7 +117,7 @@ class NonThreadPool:
         self.calls += 1
         try:
             result = func(*args, **kw)
-        except:  # noqa pylint: disable=bare-except
+        except:  # noqa: E722
             # We catch *everything* here, since normally this code would be
             # running in a thread, where there is nothing that will catch
             # error.
@@ -108,8 +139,14 @@ class NonReactor:
     the execution model defined by ``NonThreadPool``.
     """
 
-    def callFromThread(self, f, *args, **kwargs):
-        f(*args, **kwargs)
+    def suggestThreadPoolSize(self, size: int) -> None:
+        pass
+
+    def callInThread(self, callable: Callable, *args, **kwargs) -> None:
+        callable(*args, **kwargs)
+
+    def callFromThread(self, callable: Callable, *args: object, **kwargs: object) -> None:  # type: ignore[override]
+        callable(*args, **kwargs)
 
     def getThreadPool(self):
         return NonThreadPool()
@@ -258,12 +295,10 @@ class TestReactor(ProcessReactor, NonReactor, CoreReactor, Clock):
 
         self._pendingCurrentCalls = False
 
-    @defer.inlineCallbacks
-    def _catchPrintExceptions(self, what, *a, **kw):
+    @async_to_deferred
+    async def _catchPrintExceptions(self, what, *a, **kw) -> None:
         try:
-            r = what(*a, **kw)
-            if isinstance(r, defer.Deferred):
-                yield r
+            await defer.maybeDeferred(what, *a, **kw)
         except Exception as e:
             log.msg('Unhandled exception from deferred when doing TestReactor.advance()', e)
             raise
