@@ -20,8 +20,7 @@ from buildbot.process.buildstep import BuildStep
 from buildbot.process.results import CANCELLED
 
 
-class BuildStepController(object):
-
+class BuildStepController:
     """
     A controller for ``ControllableBuildStep``.
 
@@ -32,11 +31,13 @@ class BuildStepController(object):
         self.step = ControllableBuildStep(self, **kwargs)
         self.running = False
         self.auto_finish_results = None
+        self._run_deferred = None
 
     def finish_step(self, result):
         assert self.running
         self.running = False
-        d, self._run_deferred = self._run_deferred, None
+        d = self._run_deferred
+        self._run_deferred = None
         d.callback(result)
 
     def auto_finish_step(self, result):
@@ -46,14 +47,14 @@ class BuildStepController(object):
 
 
 class ControllableBuildStep(BuildStep):
-
     """
     A latent worker that can be controlled by tests.
     """
+
     name = "controllableStep"
 
-    def __init__(self, controller):
-        BuildStep.__init__(self)
+    def __init__(self, controller, **kwargs):
+        super().__init__(**kwargs)
         self._controller = controller
 
     def run(self):
