@@ -16,7 +16,6 @@
 import os
 
 from parameterized import parameterized
-
 from twisted.internet import defer
 
 from buildbot.process.properties import Interpolate
@@ -32,6 +31,46 @@ class FakeSecretReporter(HttpStatusPush):
 
 
 class SecretsConfig(RunMasterBase):
+    @defer.inlineCallbacks
+    def setup_config(self, use_interpolation):
+        c = {}
+        from buildbot.config import BuilderConfig
+        from buildbot.plugins import schedulers
+        from buildbot.plugins import steps
+        from buildbot.plugins import util
+        from buildbot.process.factory import BuildFactory
+
+        fake_reporter = FakeSecretReporter(
+            'http://example.com/hook', auth=('user', Interpolate('%(secret:httppasswd)s'))
+        )
+
+        c['services'] = [fake_reporter]
+        c['schedulers'] = [schedulers.ForceScheduler(name="force", builderNames=["testy"])]
+
+        c['secretsProviders'] = [
+            FakeSecretStorage(
+                secretdict={"foo": "secretvalue", "something": "more", 'httppasswd': 'myhttppasswd'}
+            )
+        ]
+        f = BuildFactory()
+
+        if use_interpolation:
+            if os.name == "posix":
+                # on posix we can also check whether the password was passed to the command
+                command = Interpolate(
+                    'echo %(secret:foo)s | ' + 'sed "s/secretvalue/The password was there/"'
+                )
+            else:
+                command = Interpolate('echo %(secret:foo)s')
+        else:
+            command = ['echo', util.Secret('foo')]
+
+        f.addStep(steps.ShellCommand(command=command))
+
+        c['builders'] = [BuilderConfig(name="testy", workernames=["local1"], factory=f)]
+        yield self.setup_master(c)
+
+        return fake_reporter
 
     # Note that the secret name must be long enough so that it does not crash with random directory
     # or file names in the build dictionary.
@@ -41,8 +80,7 @@ class SecretsConfig(RunMasterBase):
     ])
     @defer.inlineCallbacks
     def test_secret(self, name, use_interpolation):
-        c = masterConfig(use_interpolation)
-        yield self.setupConfig(c)
+        fake_reporter = yield self.setup_config(use_interpolation)
         build = yield self.doForceBuild(wantSteps=True, wantLogs=True)
         self.assertEqual(build['buildid'], 1)
 
@@ -60,7 +98,7 @@ class SecretsConfig(RunMasterBase):
         # at this point, build contains all the log and steps info that is in the db
         # we check that our secret is not in there!
         self.assertNotIn("secretvalue", repr(build))
-        self.assertTrue(c['services'][0].reported)
+        self.assertTrue(fake_reporter.reported)
 
     @parameterized.expand([
         ('with_interpolation', True),
@@ -68,10 +106,11 @@ class SecretsConfig(RunMasterBase):
     ])
     @defer.inlineCallbacks
     def test_secretReconfig(self, name, use_interpolation):
-        c = masterConfig(use_interpolation)
-        yield self.setupConfig(c)
-        c['secretsProviders'] = [FakeSecretStorage(
-            secretdict={"foo": "different_value", "something": "more"})]
+        yield self.setup_config(use_interpolation)
+        self.master_config_dict['secretsProviders'] = [
+            FakeSecretStorage(secretdict={"foo": "different_value", "something": "more"})
+        ]
+
         yield self.master.reconfig()
         build = yield self.doForceBuild(wantSteps=True, wantLogs=True)
         self.assertEqual(build['buildid'], 1)
@@ -88,41 +127,3 @@ class SecretsConfigPB(SecretsConfig):
 
 class SecretsConfigMsgPack(SecretsConfig):
     proto = "msgpack"
-
-
-# master configuration
-def masterConfig(use_interpolation):
-    c = {}
-    from buildbot.config import BuilderConfig
-    from buildbot.process.factory import BuildFactory
-    from buildbot.plugins import schedulers, steps, util
-
-    c['services'] = [FakeSecretReporter('http://example.com/hook',
-                                        auth=('user', Interpolate('%(secret:httppasswd)s')))]
-    c['schedulers'] = [
-        schedulers.ForceScheduler(
-            name="force",
-            builderNames=["testy"])]
-
-    c['secretsProviders'] = [FakeSecretStorage(secretdict={"foo": "secretvalue",
-                                                           "something": "more",
-                                                           'httppasswd': 'myhttppasswd'})]
-    f = BuildFactory()
-
-    if use_interpolation:
-        if os.name == "posix":
-            # on posix we can also check whether the password was passed to the command
-            command = Interpolate('echo %(secret:foo)s | ' +
-                                  'sed "s/secretvalue/The password was there/"')
-        else:
-            command = Interpolate('echo %(secret:foo)s')
-    else:
-        command = ['echo', util.Secret('foo')]
-
-    f.addStep(steps.ShellCommand(command=command))
-
-    c['builders'] = [
-        BuilderConfig(name="testy",
-                      workernames=["local1"],
-                      factory=f)]
-    return c
