@@ -36,17 +36,13 @@ class TryClientE2E(RunMasterBase):
         from buildbot.process.factory import BuildFactory
 
         c['schedulers'] = [
-            schedulers.Try_Userpass(name="try",
-                                    builderNames=["testy"],
-                                    port='tcp:0',
-                                    userpass=[("alice", "pw1")])
+            schedulers.Try_Userpass(
+                name="try", builderNames=["testy"], port='tcp:0', userpass=[("alice", "pw1")]
+            )
         ]
         f = BuildFactory()
         f.addStep(steps.ShellCommand(command='echo hello'))
-        c['builders'] = [
-            BuilderConfig(name="testy",
-                          workernames=["local1"],
-                          factory=f)]
+        c['builders'] = [BuilderConfig(name="testy", workernames=["local1"], factory=f)]
         yield self.setup_master(c)
 
     @flaky(bugNumber=7084)
@@ -58,10 +54,14 @@ class TryClientE2E(RunMasterBase):
             port = self.master.pbmanager.dispatchers['tcp:0'].port.getHost().port
 
             def thd():
-                os.system(f"buildbot try --connect=pb --master=127.0.0.1:{port} -b testy "
-                          "--property=foo:bar --username=alice --passwd=pw1 --vc=none")
+                os.system(
+                    f"buildbot try --connect=pb --master=127.0.0.1:{port} -b testy "
+                    "--property=foo:bar --username=alice --passwd=pw1 --vc=none"
+                )
+
             reactor.callInThread(thd)
 
-        build = yield self.doForceBuild(wantSteps=True, triggerCallback=trigger_callback,
-                                        wantLogs=True, wantProperties=True)
+        build = yield self.doForceBuild(
+            wantSteps=True, triggerCallback=trigger_callback, wantLogs=True, wantProperties=True
+        )
         self.assertEqual(build['buildid'], 1)
