@@ -13,8 +13,11 @@
 #
 # Copyright Buildbot Team Members
 
+from __future__ import annotations
 
 import json
+import zlib
+from typing import TYPE_CHECKING
 from unittest import mock
 
 from twisted.internet import defer
@@ -22,20 +25,21 @@ from twisted.internet import protocol
 from twisted.internet import reactor
 from twisted.trial import unittest
 from twisted.web import client
+from twisted.web.http_headers import Headers
 
-from buildbot.data import connector as dataconnector
-from buildbot.db import connector as dbconnector
-from buildbot.mq import connector as mqconnector
 from buildbot.test import fakedb
 from buildbot.test.fake import fakemaster
-from buildbot.test.util import db
 from buildbot.test.util import www
 from buildbot.util import bytes2unicode
 from buildbot.util import unicode2bytes
+from buildbot.util.twisted import async_to_deferred
 from buildbot.www import auth
 from buildbot.www import authz
 from buildbot.www import service as wwwservice
 
+if TYPE_CHECKING:
+    from typing import Callable
+
 SOMETIME = 1348971992
 OTHERTIME = 1008971992
 
@@ -58,31 +62,21 @@ class BodyReader(protocol.Protocol):
             self.finishedDeferred.errback(reason)
 
 
-class Www(db.RealDatabaseMixin, www.RequiresWwwMixin, unittest.TestCase):
+class Www(www.RequiresWwwMixin, unittest.TestCase):
     master = None
 
     @defer.inlineCallbacks
     def setUp(self):
         # set up a full master serving HTTP
-        yield self.setUpRealDatabase(
-            table_names=['masters', 'objects', 'object_state'], sqlite_memory=False
+        master = yield fakemaster.make_master(
+            self,
+            wantRealReactor=True,
+            wantDb=True,
+            wantData=True,
+            sqlite_memory=False,
+            auto_shutdown=False,
         )
 
-        master = fakemaster.FakeMaster(reactor)
-
-        master.config.db = {"db_url": self.db_url}
-        master.db = dbconnector.DBConnector('basedir')
-        yield master.db.setServiceParent(master)
-        yield master.db.setup(check_version=False)
-
-        master.config.mq = {"type": 'simple'}
-        master.mq = mqconnector.MQConnector()
-        yield master.mq.setServiceParent(master)
-        yield master.mq.setup()
-
-        master.data = dataconnector.DataConnector()
-        yield master.data.setServiceParent(master)
-
         master.config.www = {
             "port": 'tcp:0:interface=127.0.0.1',
             "debug": True,
@@ -109,23 +103,19 @@ class Www(db.RealDatabaseMixin, www.RequiresWwwMixin, unittest.TestCase):
 
         self.master = master
 
+        self.addCleanup(self.master.test_shutdown)
+        self.addCleanup(self.master.www.stopService)
+
         # build an HTTP agent, using an explicit connection pool if Twisted
         # supports it (Twisted 13.0.0 and up)
         if hasattr(client, 'HTTPConnectionPool'):
             self.pool = client.HTTPConnectionPool(reactor)
             self.agent = client.Agent(reactor, pool=self.pool)
+            self.addCleanup(self.pool.closeCachedConnections)
         else:
             self.pool = None
             self.agent = client.Agent(reactor)
 
-    @defer.inlineCallbacks
-    def tearDown(self):
-        if self.pool:
-            yield self.pool.closeCachedConnections()
-        if self.master:
-            yield self.master.www.stopService()
-        yield self.tearDownRealDatabase()
-
     @defer.inlineCallbacks
     def apiGet(self, url, expect200=True):
         pg = yield self.agent.request(b'GET', url)
@@ -154,9 +144,9 @@ class Www(db.RealDatabaseMixin, www.RequiresWwwMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_masters(self):
-        yield self.insert_test_data([
-            fakedb.Master(id=7, name='some:master', active=0, last_active=SOMETIME),
-            fakedb.Master(id=8, name='other:master', active=1, last_active=OTHERTIME),
+        yield self.master.db.insert_test_data([
+            fakedb.Master(id=7, active=0, last_active=SOMETIME),
+            fakedb.Master(id=8, active=1, last_active=OTHERTIME),
         ])
 
         res = yield self.apiGet(self.link(b'masters'))
@@ -167,13 +157,13 @@ class Www(db.RealDatabaseMixin, www.RequiresWwwMixin, unittest.TestCase):
                     {
                         'active': False,
                         'masterid': 7,
-                        'name': 'some:master',
+                        'name': 'master-7',
                         'last_active': SOMETIME,
                     },
                     {
                         'active': True,
                         'masterid': 8,
-                        'name': 'other:master',
+                        'name': 'master-8',
                         'last_active': OTHERTIME,
                     },
                 ],
@@ -191,10 +181,84 @@ class Www(db.RealDatabaseMixin, www.RequiresWwwMixin, unittest.TestCase):
                     {
                         'active': False,
                         'masterid': 7,
-                        'name': 'some:master',
+                        'name': 'master-7',
                         'last_active': SOMETIME,
                     },
                 ],
                 'meta': {},
             },
         )
+
+    async def _test_compression(
+        self,
+        encoding: bytes,
+        decompress_fn: Callable[[bytes], bytes],
+    ) -> None:
+        await self.master.db.insert_test_data([
+            fakedb.Master(id=7, active=0, last_active=SOMETIME),
+        ])
+
+        pg = await self.agent.request(
+            b'GET',
+            self.link(b'masters/7'),
+            headers=Headers({b'accept-encoding': [encoding]}),
+        )
+
+        # this is kind of obscene, but protocols are like that
+        d: defer.Deferred[bytes] = defer.Deferred()
+        bodyReader = BodyReader(d)
+        pg.deliverBody(bodyReader)
+        body = await d
+
+        self.assertEqual(pg.headers.getRawHeaders(b'content-encoding'), [encoding])
+
+        response = json.loads(bytes2unicode(decompress_fn(body)))
+        self.assertEqual(
+            response,
+            {
+                'masters': [
+                    {
+                        'active': False,
+                        'masterid': 7,
+                        'name': 'master-7',
+                        'last_active': SOMETIME,
+                    },
+                ],
+                'meta': {},
+            },
+        )
+
+    @async_to_deferred
+    async def test_gzip_compression(self):
+        await self._test_compression(
+            b'gzip',
+            decompress_fn=lambda body: zlib.decompress(
+                body,
+                # use largest wbits possible as twisted customize it
+                # see: https://docs.python.org/3/library/zlib.html#zlib.decompress
+                wbits=47,
+            ),
+        )
+
+    @async_to_deferred
+    async def test_brotli_compression(self):
+        try:
+            import brotli
+        except ImportError as e:
+            raise unittest.SkipTest("brotli not installed, skip the test") from e
+        await self._test_compression(b'br', decompress_fn=brotli.decompress)
+
+    @async_to_deferred
+    async def test_zstandard_compression(self):
+        try:
+            import zstandard
+        except ImportError as e:
+            raise unittest.SkipTest("zstandard not installed, skip the test") from e
+
+        def _decompress(data):
+            # zstd cannot decompress data compressed with stream api with a non stream api
+            decompressor = zstandard.ZstdDecompressor()
+            decompressobj = decompressor.decompressobj()
+            return decompressobj.decompress(data) + decompressobj.flush()
+
+        await self._test_compression(b'zstd', decompress_fn=_decompress)
