@@ -35,9 +35,6 @@ class TestChangeSource(changesource.ChangeSourceMixin, TestReactorMixin, unittes
         self.setup_test_reactor()
         yield self.setUpChangeSource()
 
-    def tearDown(self):
-        return self.tearDownChangeSource()
-
     @defer.inlineCallbacks
     def test_activation(self):
         cs = self.Subclass(name="DummyCS")
@@ -88,9 +85,6 @@ class TestReconfigurablePollingChangeSource(
 
         yield self.attachChangeSource(self.Subclass(name="DummyCS"))
 
-    def tearDown(self):
-        return self.tearDownChangeSource()
-
     @defer.inlineCallbacks
     def runClockFor(self, secs):
         yield self.reactor.pump([0] + [1.0] * secs)
