@@ -304,9 +304,6 @@ class TestBitbucketPullrequestPoller(
 
         return self.setUpChangeSource()
 
-    def tearDown(self):
-        return self.tearDownChangeSource()
-
     def _fakeGetPage(self, result):
         # Install a fake getPage that puts the requested URL in self.getPage_got_url
         # and return result
