@@ -28,6 +28,7 @@ from buildbot.test.reactor import TestReactorMixin
 
 class Change(unittest.TestCase, TestReactorMixin):
     change23_rows = [
+        fakedb.SourceStamp(id=92),
         fakedb.Change(
             changeid=23,
             author="dustin",
@@ -47,12 +48,14 @@ class Change(unittest.TestCase, TestReactorMixin):
         fakedb.ChangeProperty(
             changeid=23, property_name='notest', property_value='["no","Change"]'
         ),
+        fakedb.User(uid=27),
         fakedb.ChangeUser(changeid=23, uid=27),
     ]
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantDb=True)
+        self.master = yield fakemaster.make_master(self, wantDb=True)
         self.change23 = changes.Change(**{  # using **dict(..) forces kwargs
             "category": 'devel',
             "repository": 'git://warner',
