@@ -113,9 +113,6 @@ class TestP4Poller(
         self.setup_master_run_process()
         yield self.setUpChangeSource()
 
-    def tearDown(self):
-        return self.tearDownChangeSource()
-
     def add_p4_describe_result(self, number, result):
         self.expect_commands(
             ExpectMasterShell(['p4', 'describe', '-s', str(number)]).stdout(result)
