@@ -33,9 +33,10 @@ class BuildEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     endpointClass = builds.BuildEndpoint
     resourceTypeClass = builds.Build
 
+    @defer.inlineCallbacks
     def setUp(self):
-        self.setUpEndpoint()
-        self.db.insert_test_data([
+        yield self.setUpEndpoint()
+        yield self.db.insert_test_data([
             fakedb.Builder(id=77, name='builder77'),
             fakedb.Master(id=88),
             fakedb.Worker(id=13, name='wrk'),
@@ -55,9 +56,6 @@ class BuildEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             ),
         ])
 
-    def tearDown(self):
-        self.tearDownEndpoint()
-
     @defer.inlineCallbacks
     def test_get_existing(self):
         build = yield self.callGet(('builds', 14))
@@ -137,16 +135,20 @@ class BuildsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     endpointClass = builds.BuildsEndpoint
     resourceTypeClass = builds.Build
 
+    @defer.inlineCallbacks
     def setUp(self):
-        self.setUpEndpoint()
-        self.db.insert_test_data([
+        yield self.setUpEndpoint()
+        yield self.db.insert_test_data([
             fakedb.Builder(id=77, name='builder77'),
             fakedb.Builder(id=78, name='builder78'),
             fakedb.Builder(id=79, name='builder79'),
             fakedb.Master(id=88),
-            fakedb.Worker(id=13, name='wrk'),
+            fakedb.Worker(id=12, name='wrk'),
+            fakedb.Worker(id=13, name='wrk2'),
             fakedb.Buildset(id=8822),
-            fakedb.BuildRequest(id=82, buildsetid=8822),
+            fakedb.BuildRequest(id=82, builderid=77, buildsetid=8822),
+            fakedb.BuildRequest(id=83, builderid=77, buildsetid=8822),
+            fakedb.BuildRequest(id=84, builderid=77, buildsetid=8822),
             fakedb.Build(
                 id=13, builderid=77, masterid=88, workerid=13, buildrequestid=82, number=3
             ),
@@ -176,9 +178,6 @@ class BuildsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             ),
         ])
 
-    def tearDown(self):
-        self.tearDownEndpoint()
-
     @defer.inlineCallbacks
     def test_get_all(self):
         builds = yield self.callGet(('builds',))
@@ -329,18 +328,31 @@ class Build(interfaces.InterfaceTests, TestReactorMixin, unittest.TestCase):
         'complete_at': None,
         "locks_duration_s": 0,
         'masterid': 824,
-        'number': 1,
+        'number': 43,
         'results': None,
         'started_at': epoch2datetime(1),
         'state_string': 'created',
         'properties': {},
     }
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantMq=True, wantDb=True, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantMq=True, wantDb=True, wantData=True)
         self.rtype = builds.Build(self.master)
 
+        yield self.master.db.insert_test_data([
+            fakedb.Builder(id=10),
+            fakedb.Master(id=824),
+            fakedb.Worker(id=20, name='wrk'),
+            fakedb.Buildset(id=999),
+            fakedb.BuildRequest(id=499, buildsetid=999, builderid=10),
+            fakedb.BuildRequest(id=13, buildsetid=999, builderid=10),
+            fakedb.Build(
+                id=99, builderid=10, masterid=824, workerid=20, buildrequestid=499, number=42
+            ),
+        ])
+
     @defer.inlineCallbacks
     def do_test_callthrough(
         self,
@@ -403,7 +415,7 @@ class Build(interfaces.InterfaceTests, TestReactorMixin, unittest.TestCase):
             buildrequestid=13,
             workerid=20,
             exp_events=[
-                (('builders', '10', 'builds', '1', 'new'), self.new_build_event),
+                (('builders', '10', 'builds', '43', 'new'), self.new_build_event),
                 (('builds', '100', 'new'), self.new_build_event),
                 (('workers', '20', 'builds', '100', 'new'), self.new_build_event),
             ],
