@@ -21,6 +21,7 @@ from twisted.trial import unittest
 
 from buildbot.data import changes
 from buildbot.data import resultspec
+from buildbot.db.changes import ChangeModel
 from buildbot.process.users import users
 from buildbot.test import fakedb
 from buildbot.test.fake import fakemaster
@@ -34,9 +35,10 @@ class ChangeEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     endpointClass = changes.ChangeEndpoint
     resourceTypeClass = changes.Change
 
+    @defer.inlineCallbacks
     def setUp(self):
-        self.setUpEndpoint()
-        self.db.insert_test_data([
+        yield self.setUpEndpoint()
+        yield self.db.insert_test_data([
             fakedb.SourceStamp(id=234),
             fakedb.Change(
                 changeid=13,
@@ -49,9 +51,6 @@ class ChangeEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             ),
         ])
 
-    def tearDown(self):
-        self.tearDownEndpoint()
-
     @defer.inlineCallbacks
     def test_get_existing(self):
         change = yield self.callGet(('changes', '13'))
@@ -70,9 +69,12 @@ class ChangesEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     endpointClass = changes.ChangesEndpoint
     resourceTypeClass = changes.Change
 
+    @defer.inlineCallbacks
     def setUp(self):
-        self.setUpEndpoint()
-        self.db.insert_test_data([
+        yield self.setUpEndpoint()
+        yield self.db.insert_test_data([
+            fakedb.Master(id=1),
+            fakedb.Worker(id=1, name='wrk'),
             fakedb.SourceStamp(id=133),
             fakedb.Change(
                 changeid=13,
@@ -82,6 +84,7 @@ class ChangesEndpoint(endpoint.EndpointMixin, unittest.TestCase):
                 codebase='cbsvn',
                 project='world-domination',
                 sourcestampid=133,
+                when_timestamp=1000000,
             ),
             fakedb.SourceStamp(id=144),
             fakedb.Change(
@@ -92,17 +95,18 @@ class ChangesEndpoint(endpoint.EndpointMixin, unittest.TestCase):
                 codebase='cbsvn',
                 project='world-domination',
                 sourcestampid=144,
+                when_timestamp=1000001,
             ),
             fakedb.Builder(id=1, name='builder'),
+            fakedb.Buildset(id=8822),
+            fakedb.BuildRequest(id=1, builderid=1, buildsetid=8822),
             fakedb.Build(buildrequestid=1, masterid=1, workerid=1, builderid=1, number=1),
         ])
 
-    def tearDown(self):
-        self.tearDownEndpoint()
-
     @defer.inlineCallbacks
     def test_get(self):
         changes = yield self.callGet(('changes',))
+        changes = sorted(changes, key=lambda ch: ch['changeid'])
 
         self.validateData(changes[0])
         self.assertEqual(changes[0]['changeid'], 13)
@@ -111,7 +115,7 @@ class ChangesEndpoint(endpoint.EndpointMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_getChanges_from_build(self):
-        fake_change = yield self.db.changes.getChangeFromSSid(ssid=144)
+        fake_change = yield self.db.changes.getChangeFromSSid(144)
 
         mockGetChangeById = mock.Mock(
             spec=self.db.changes.getChangesForBuild, return_value=[fake_change]
@@ -125,7 +129,7 @@ class ChangesEndpoint(endpoint.EndpointMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_getChanges_from_builder(self):
-        fake_change = yield self.db.changes.getChangeFromSSid(ssid=144)
+        fake_change = yield self.db.changes.getChangeFromSSid(144)
         mockGetChangeById = mock.Mock(
             spec=self.db.changes.getChangesForBuild, return_value=[fake_change]
         )
@@ -146,7 +150,7 @@ class ChangesEndpoint(endpoint.EndpointMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_getChangesOtherOrder(self):
-        resultSpec = resultspec.ResultSpec(limit=1, order=('-when_time_stamp',))
+        resultSpec = resultspec.ResultSpec(limit=1, order=('-when_timestamp',))
         changes = yield self.callGet(('changes',), resultSpec=resultSpec)
 
         self.assertEqual(len(changes), 1)
@@ -189,11 +193,16 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
         # uid
     }
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantMq=True, wantDb=True, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantMq=True, wantDb=True, wantData=True)
         self.rtype = changes.Change(self.master)
 
+        yield self.master.db.insert_test_data([
+            fakedb.SourceStamp(id=99),  # force minimum ID in tests below
+        ])
+
     def test_signature_addChange(self):
         @self.assertArgSpecMatches(
             self.master.data.updates.addChange,  # fake
@@ -233,12 +242,15 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             (expectedRoutingKey, expectedMessage),
         ])
         # and that the correct data was inserted into the db
-        self.master.db.changes.assertChange(500, expectedRow)
-        self.master.db.changes.assertChangeUsers(500, expectedChangeUsers)
+        change = yield self.master.db.changes.getChange(500)
+        self.assertEqual(change, expectedRow)
+        change_users = yield self.master.db.changes.getChangeUids(500)
+        self.assertEqual(change_users, expectedChangeUsers)
 
     def test_addChange(self):
         # src and codebase are default here
         kwargs = {
+            "_test_changeid": 500,
             "author": 'warner',
             "committer": 'david',
             "branch": 'warnerdb',
@@ -254,7 +266,7 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
         }
         expectedRoutingKey = ('changes', '500', 'new')
         expectedMessage = self.changeEvent
-        expectedRow = fakedb.Change(
+        expectedRow = ChangeModel(
             changeid=500,
             author='warner',
             committer='david',
@@ -262,21 +274,28 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             branch='warnerdb',
             revision='0e92a098b',
             revlink='http://warner/0e92a098b',
-            when_timestamp=256738404,
+            when_timestamp=epoch2datetime(256738404),
             category='devel',
             repository='git://warner',
             codebase='',
             project='Buildbot',
             sourcestampid=100,
+            files=['master/buildbot/__init__.py'],
+            properties={'foo': (20, 'Change')},
         )
         return self.do_test_addChange(kwargs, expectedRoutingKey, expectedMessage, expectedRow)
 
     @defer.inlineCallbacks
     def test_addChange_src_codebase(self):
+        yield self.master.db.insert_test_data([
+            fakedb.User(uid=123),
+        ])
+
         createUserObject = mock.Mock(spec=users.createUserObject)
         createUserObject.return_value = defer.succeed(123)
         self.patch(users, 'createUserObject', createUserObject)
         kwargs = {
+            "_test_changeid": 500,
             "author": 'warner',
             "committer": 'david',
             "branch": 'warnerdb',
@@ -321,7 +340,7 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             },
             # uid
         }
-        expectedRow = fakedb.Change(
+        expectedRow = ChangeModel(
             changeid=500,
             author='warner',
             committer='david',
@@ -329,12 +348,14 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             branch='warnerdb',
             revision='0e92a098b',
             revlink='http://warner/0e92a098b',
-            when_timestamp=256738404,
+            when_timestamp=epoch2datetime(256738404),
             category='devel',
             repository='git://warner',
             codebase='cb',
             project='Buildbot',
             sourcestampid=100,
+            files=['master/buildbot/__init__.py'],
+            properties={'foo': (20, 'Change')},
         )
         yield self.do_test_addChange(
             kwargs, expectedRoutingKey, expectedMessage, expectedRow, expectedChangeUsers=[123]
@@ -350,6 +371,7 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
         self.master.config.preChangeGenerator = preChangeGenerator
         self.master.config.codebaseGenerator = lambda change: f"cb-{(change['category'])}"
         kwargs = {
+            "_test_changeid": 500,
             "author": 'warner',
             "committer": 'david',
             "branch": 'warnerdb',
@@ -392,7 +414,7 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             },
             # uid
         }
-        expectedRow = fakedb.Change(
+        expectedRow = ChangeModel(
             changeid=500,
             author='warner',
             committer='david',
@@ -400,12 +422,14 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             branch='warnerdb',
             revision='0e92a098b',
             revlink='http://warner/0e92a098b',
-            when_timestamp=256738404,
+            when_timestamp=epoch2datetime(256738404),
             category='devel',
             repository='git://warner',
             codebase='cb-devel',
             project='Buildbot',
             sourcestampid=100,
+            files=['master/buildbot/__init__.py'],
+            properties={'foo': (20, 'Change')},
         )
         return self.do_test_addChange(kwargs, expectedRoutingKey, expectedMessage, expectedRow)
 
@@ -414,6 +438,7 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
         self.master.config.revlink = lambda rev, repo: f'foo{repo}bar{rev}baz'
         # revlink is default here
         kwargs = {
+            "_test_changeid": 500,
             "author": 'warner',
             "committer": 'david',
             "branch": 'warnerdb',
@@ -459,7 +484,7 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             },
             # uid
         }
-        expectedRow = fakedb.Change(
+        expectedRow = ChangeModel(
             changeid=500,
             author='warner',
             committer='david',
@@ -467,11 +492,13 @@ class Change(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
             branch='warnerdb',
             revision='0e92a098b',
             revlink='foogit://warnerbar0e92a098bbaz',
-            when_timestamp=256738404,
+            when_timestamp=epoch2datetime(256738404),
             category='devel',
             repository='git://warner',
             codebase='',
             project='Buildbot',
             sourcestampid=100,
+            files=['master/buildbot/__init__.py'],
+            properties={'foo': (20, 'Change')},
         )
         return self.do_test_addChange(kwargs, expectedRoutingKey, expectedMessage, expectedRow)
