@@ -30,9 +30,10 @@ class TestResultSetEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     endpointClass = test_result_sets.TestResultSetEndpoint
     resourceTypeClass = test_result_sets.TestResultSet
 
+    @defer.inlineCallbacks
     def setUp(self):
-        self.setUpEndpoint()
-        self.db.insert_test_data([
+        yield self.setUpEndpoint()
+        yield self.db.insert_test_data([
             fakedb.Worker(id=47, name='linux'),
             fakedb.Buildset(id=20),
             fakedb.Builder(id=88, name='b1'),
@@ -54,9 +55,6 @@ class TestResultSetEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             ),
         ])
 
-    def tearDown(self):
-        self.tearDownEndpoint()
-
     @defer.inlineCallbacks
     def test_get_existing_result_set(self):
         result = yield self.callGet(('test_result_sets', 13))
@@ -87,9 +85,10 @@ class TestResultSetsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
     endpointClass = test_result_sets.TestResultSetsEndpoint
     resourceTypeClass = test_result_sets.TestResultSet
 
+    @defer.inlineCallbacks
     def setUp(self):
-        self.setUpEndpoint()
-        self.db.insert_test_data([
+        yield self.setUpEndpoint()
+        yield self.db.insert_test_data([
             fakedb.Worker(id=47, name='linux'),
             fakedb.Buildset(id=20),
             fakedb.Builder(id=88, name='b1'),
@@ -121,8 +120,12 @@ class TestResultSetsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
             ),
         ])
 
-    def tearDown(self):
-        self.tearDownEndpoint()
+    @defer.inlineCallbacks
+    def test_get_result_sets_all(self):
+        results = yield self.callGet(('test_result_sets',))
+        for result in results:
+            self.validateData(result)
+        self.assertEqual([r['test_result_setid'] for r in results], [13, 14])
 
     @defer.inlineCallbacks
     def test_get_result_sets_builders_builderid(self):
@@ -154,9 +157,35 @@ class TestResultSetsEndpoint(endpoint.EndpointMixin, unittest.TestCase):
 
 
 class TestResultSet(TestReactorMixin, interfaces.InterfaceTests, unittest.TestCase):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantMq=True, wantDb=True, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantMq=True, wantDb=True, wantData=True)
+        yield self.master.db.insert_test_data([
+            fakedb.Master(id=1),
+            fakedb.Worker(id=1, name='example-worker'),
+            fakedb.Builder(id=1),
+            fakedb.Buildset(id=1),
+            fakedb.BuildRequest(
+                id=1,
+                buildsetid=1,
+                builderid=1,
+            ),
+            fakedb.Build(
+                id=2,
+                number=1,
+                buildrequestid=1,
+                builderid=1,
+                workerid=1,
+                masterid=1,
+            ),
+            fakedb.Step(
+                id=3,
+                number=1,
+                name='step1',
+                buildid=2,
+            ),
+        ])
         self.rtype = test_result_sets.TestResultSet(self.master)
 
     def test_signature_add_test_result_set(self):
