@@ -118,9 +118,6 @@ class TestBuildStep(
         self.setup_test_reactor()
         return self.setup_test_build_step()
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     # support
 
     def _setupWaterfallTest(self, hideStepIf, expect, expectedResult=SUCCESS):
@@ -184,8 +181,7 @@ class TestBuildStep(
         updateBuildSummaryPolicy raise ConfigError in case of bad type
         """
         with self.assertRaisesConfigError(
-            "BuildStep updateBuildSummaryPolicy must be "
-            "a list of result ids or boolean but it is 2"
+            "BuildStep updateBuildSummaryPolicy must be a list of result ids or boolean but it is 2"
         ):
             buildstep.BuildStep(updateBuildSummaryPolicy=FAILURE)
 
@@ -738,6 +734,7 @@ class TestBuildStep(
         step.setStatistic('ba', 0.298)
         self.assertEqual(step.getStatistics(), {'rbi': 13, 'ba': 0.298})
 
+    @defer.inlineCallbacks
     def setup_summary_test(self):
         self.patch(NewStyleStep, 'getCurrentSummary', lambda self: defer.succeed({'step': 'C'}))
         self.patch(
@@ -746,59 +743,66 @@ class TestBuildStep(
             lambda self: defer.succeed({'step': 'CS', 'build': 'CB'}),
         )
         step = create_step_from_step_or_factory(NewStyleStep())
-        step.master = fakemaster.make_master(self, wantData=True, wantDb=True)
+        step.master = yield fakemaster.make_master(self, wantData=True, wantDb=True)
         step.stepid = 13
         step.build = fakebuild.FakeBuild()
         return step
 
+    @defer.inlineCallbacks
     def test_updateSummary_running(self):
-        step = self.setup_summary_test()
+        step = yield self.setup_summary_test()
         step._running = True
         step.updateSummary()
         self.reactor.advance(1)
         self.assertEqual(step.master.data.updates.stepStateString[13], 'C')
 
+    @defer.inlineCallbacks
     def test_updateSummary_running_empty_dict(self):
-        step = self.setup_summary_test()
+        step = yield self.setup_summary_test()
         step.getCurrentSummary = lambda: {}
         step._running = True
         step.updateSummary()
         self.reactor.advance(1)
         self.assertEqual(step.master.data.updates.stepStateString[13], 'finished')
 
+    @defer.inlineCallbacks
     def test_updateSummary_running_not_unicode(self):
-        step = self.setup_summary_test()
+        step = yield self.setup_summary_test()
         step.getCurrentSummary = lambda: {'step': b'bytestring'}
         step._running = True
         step.updateSummary()
         self.reactor.advance(1)
         self.assertEqual(len(self.flushLoggedErrors(TypeError)), 1)
 
+    @defer.inlineCallbacks
     def test_updateSummary_running_not_dict(self):
-        step = self.setup_summary_test()
+        step = yield self.setup_summary_test()
         step.getCurrentSummary = lambda: 'foo!'
         step._running = True
         step.updateSummary()
         self.reactor.advance(1)
         self.assertEqual(len(self.flushLoggedErrors(TypeError)), 1)
 
+    @defer.inlineCallbacks
     def test_updateSummary_finished(self):
-        step = self.setup_summary_test()
+        step = yield self.setup_summary_test()
         step._running = False
         step.updateSummary()
         self.reactor.advance(1)
         self.assertEqual(step.master.data.updates.stepStateString[13], 'CS')
 
+    @defer.inlineCallbacks
     def test_updateSummary_finished_empty_dict(self):
-        step = self.setup_summary_test()
+        step = yield self.setup_summary_test()
         step.getResultSummary = lambda: {}
         step._running = False
         step.updateSummary()
         self.reactor.advance(1)
         self.assertEqual(step.master.data.updates.stepStateString[13], 'finished')
 
+    @defer.inlineCallbacks
     def test_updateSummary_finished_not_dict(self):
-        step = self.setup_summary_test()
+        step = yield self.setup_summary_test()
         step.getResultSummary = lambda: 'foo!'
         step._running = False
         step.updateSummary()
@@ -1080,9 +1084,10 @@ class InterfaceTests(interfaces.InterfaceTests):
 
 
 class TestFakeItfc(unittest.TestCase, TestBuildStepMixin, TestReactorMixin, InterfaceTests):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.setup_test_build_step()
+        yield self.setup_test_build_step()
         self.setup_step(buildstep.BuildStep())
 
 
@@ -1109,9 +1114,6 @@ class TestCommandMixin(TestBuildStepMixin, TestReactorMixin, unittest.TestCase):
         yield self.setup_test_build_step()
         self.setup_step(CommandMixinExample())
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     @defer.inlineCallbacks
     def test_runRmdir(self):
         self.get_nth_step(0).testMethod = lambda: self.get_nth_step(0).runRmdir('/some/path')
@@ -1225,9 +1227,6 @@ class TestShellMixin(
         self.setup_test_reactor()
         yield self.setup_test_build_step(with_secrets={"s3cr3t": "really_safe_string"})
 
-    def tearDown(self):
-        return self.tear_down_test_build_step()
-
     def test_setupShellMixin_bad_arg(self):
         mixin = SimpleShellCommand()
         with self.assertRaisesConfigError("invalid SimpleShellCommand argument invarg"):
