@@ -43,9 +43,10 @@ class MyLogObserver(logobserver.LogObserver):
 
 
 class TestLogObserver(TestReactorMixin, unittest.TestCase):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantData=True)
 
     @defer.inlineCallbacks
     def test_sequence(self):
@@ -93,9 +94,10 @@ class MyLogLineObserver(logobserver.LogLineObserver):
 
 
 class TestLineConsumerLogObesrver(TestReactorMixin, unittest.TestCase):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantData=True)
 
     @defer.inlineCallbacks
     def do_test_sequence(self, consumer):
@@ -165,9 +167,10 @@ class TestLineConsumerLogObesrver(TestReactorMixin, unittest.TestCase):
 
 
 class TestLogLineObserver(TestReactorMixin, unittest.TestCase):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantData=True)
 
     @defer.inlineCallbacks
     def test_sequence(self):
@@ -204,9 +207,10 @@ class TestLogLineObserver(TestReactorMixin, unittest.TestCase):
 
 
 class TestOutputProgressObserver(TestReactorMixin, unittest.TestCase):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantData=True)
 
     @defer.inlineCallbacks
     def test_sequence(self):
@@ -223,9 +227,10 @@ class TestOutputProgressObserver(TestReactorMixin, unittest.TestCase):
 
 
 class TestBufferObserver(TestReactorMixin, unittest.TestCase):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantData=True)
 
     @defer.inlineCallbacks
     def do_test_sequence(self, lo):
