@@ -13,9 +13,12 @@
 #
 # Copyright Buildbot Team Members
 
+import copy
+
 from twisted.internet import defer
 from twisted.trial import unittest
 
+from buildbot.db.users import UserModel
 from buildbot.process.users import users
 from buildbot.test import fakedb
 from buildbot.test.fake import fakemaster
@@ -23,115 +26,124 @@ from buildbot.test.reactor import TestReactorMixin
 
 
 class UsersTests(TestReactorMixin, unittest.TestCase):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantDb=True)
+        self.master = yield fakemaster.make_master(self, wantDb=True)
         self.db = self.master.db
         self.test_sha = users.encrypt("cancer")
 
+    @defer.inlineCallbacks
+    def verify_users(self, users):
+        users_no_attrs = copy.deepcopy(users)
+        for user in users_no_attrs:
+            user.attributes = None
+
+        got_users = yield self.db.users.getUsers()
+        self.assertEqual(got_users, users_no_attrs)
+
+        for user in users:
+            got_user = yield self.db.users.getUser(user.uid)
+            self.assertEqual(got_user, user)
+
     @defer.inlineCallbacks
     def test_createUserObject_no_src(self):
         yield users.createUserObject(self.master, "Tyler Durden", None)
-
-        self.assertEqual(self.db.users.users, {})
-        self.assertEqual(self.db.users.users_info, {})
+        got_users = yield self.db.users.getUsers()
+        self.assertEqual(got_users, [])
 
     @defer.inlineCallbacks
     def test_createUserObject_unrecognized_src(self):
         yield users.createUserObject(self.master, "Tyler Durden", 'blah')
-
-        self.assertEqual(self.db.users.users, {})
-        self.assertEqual(self.db.users.users_info, {})
+        got_users = yield self.db.users.getUsers()
+        self.assertEqual(got_users, [])
 
     @defer.inlineCallbacks
     def test_createUserObject_git(self):
         yield users.createUserObject(self.master, "Tyler Durden <tyler@mayhem.net>", 'git')
-
-        self.assertEqual(
-            self.db.users.users,
-            {
-                1: {
-                    "identifier": 'Tyler Durden <tyler@mayhem.net>',
-                    "bb_username": None,
-                    "bb_password": None,
-                }
-            },
-        )
-        self.assertEqual(
-            self.db.users.users_info,
-            {1: [{"attr_type": "git", "attr_data": "Tyler Durden <tyler@mayhem.net>"}]},
-        )
+        yield self.verify_users([
+            UserModel(
+                uid=1,
+                identifier='Tyler Durden <tyler@mayhem.net>',
+                bb_username=None,
+                bb_password=None,
+                attributes={'git': 'Tyler Durden <tyler@mayhem.net>'},
+            )
+        ])
 
     @defer.inlineCallbacks
     def test_createUserObject_svn(self):
         yield users.createUserObject(self.master, "tdurden", 'svn')
 
-        self.assertEqual(
-            self.db.users.users,
-            {1: {"identifier": 'tdurden', "bb_username": None, "bb_password": None}},
-        )
-        self.assertEqual(
-            self.db.users.users_info, {1: [{"attr_type": "svn", "attr_data": "tdurden"}]}
-        )
+        yield self.verify_users([
+            UserModel(
+                uid=1,
+                identifier='tdurden',
+                bb_username=None,
+                bb_password=None,
+                attributes={'svn': 'tdurden'},
+            )
+        ])
 
     @defer.inlineCallbacks
     def test_createUserObject_hg(self):
         yield users.createUserObject(self.master, "Tyler Durden <tyler@mayhem.net>", 'hg')
 
-        self.assertEqual(
-            self.db.users.users,
-            {
-                1: {
-                    "identifier": 'Tyler Durden <tyler@mayhem.net>',
-                    "bb_username": None,
-                    "bb_password": None,
-                }
-            },
-        )
-        self.assertEqual(
-            self.db.users.users_info,
-            {1: [{"attr_type": "hg", "attr_data": "Tyler Durden <tyler@mayhem.net>"}]},
-        )
+        yield self.verify_users([
+            UserModel(
+                uid=1,
+                identifier='Tyler Durden <tyler@mayhem.net>',
+                bb_username=None,
+                bb_password=None,
+                attributes={'hg': 'Tyler Durden <tyler@mayhem.net>'},
+            )
+        ])
 
     @defer.inlineCallbacks
     def test_createUserObject_cvs(self):
         yield users.createUserObject(self.master, "tdurden", 'cvs')
 
-        self.assertEqual(
-            self.db.users.users,
-            {1: {"identifier": 'tdurden', "bb_username": None, "bb_password": None}},
-        )
-        self.assertEqual(
-            self.db.users.users_info, {1: [{"attr_type": "cvs", "attr_data": "tdurden"}]}
-        )
+        yield self.verify_users([
+            UserModel(
+                uid=1,
+                identifier='tdurden',
+                bb_username=None,
+                bb_password=None,
+                attributes={'cvs': 'tdurden'},
+            )
+        ])
 
     @defer.inlineCallbacks
     def test_createUserObject_darcs(self):
         yield users.createUserObject(self.master, "tyler@mayhem.net", 'darcs')
 
-        self.assertEqual(
-            self.db.users.users,
-            {1: {"identifier": 'tyler@mayhem.net', "bb_username": None, "bb_password": None}},
-        )
-        self.assertEqual(
-            self.db.users.users_info, {1: [{"attr_type": "darcs", "attr_data": "tyler@mayhem.net"}]}
-        )
+        yield self.verify_users([
+            UserModel(
+                uid=1,
+                identifier='tyler@mayhem.net',
+                bb_username=None,
+                bb_password=None,
+                attributes={'darcs': 'tyler@mayhem.net'},
+            )
+        ])
 
     @defer.inlineCallbacks
     def test_createUserObject_bzr(self):
         yield users.createUserObject(self.master, "Tyler Durden", 'bzr')
 
-        self.assertEqual(
-            self.db.users.users,
-            {1: {"identifier": 'Tyler Durden', "bb_username": None, "bb_password": None}},
-        )
-        self.assertEqual(
-            self.db.users.users_info, {1: [{"attr_type": 'bzr', "attr_data": 'Tyler Durden'}]}
-        )
+        yield self.verify_users([
+            UserModel(
+                uid=1,
+                identifier='Tyler Durden',
+                bb_username=None,
+                bb_password=None,
+                attributes={'bzr': 'Tyler Durden'},
+            )
+        ])
 
     @defer.inlineCallbacks
     def test_getUserContact_found(self):
-        self.db.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.User(uid=1, identifier='tdurden'),
             fakedb.UserInfo(uid=1, attr_type='svn', attr_data='tdurden'),
             fakedb.UserInfo(uid=1, attr_type='email', attr_data='tyler@mayhem.net'),
@@ -142,7 +154,7 @@ class UsersTests(TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_getUserContact_key_not_found(self):
-        self.db.insert_test_data([
+        yield self.db.insert_test_data([
             fakedb.User(uid=1, identifier='tdurden'),
             fakedb.UserInfo(uid=1, attr_type='svn', attr_data='tdurden'),
             fakedb.UserInfo(uid=1, attr_type='email', attr_data='tyler@mayhem.net'),
