@@ -32,10 +32,11 @@ from buildbot.test.util.reporter import ReporterTestMixin
 class TestBuildSetGeneratorBase(
     ConfigErrorsMixin, TestReactorMixin, ReporterTestMixin, unittest.TestCase
 ):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
         self.setup_reporter_test()
-        self.master = fakemaster.make_master(self, wantData=True, wantDb=True, wantMq=True)
+        self.master = yield fakemaster.make_master(self, wantData=True, wantDb=True, wantMq=True)
 
     @defer.inlineCallbacks
     def insert_build_finished_get_props(self, results, **kwargs):
