@@ -41,9 +41,11 @@ class TestGitHubStatusPush(
         # project must be in the form <owner>/<project>
         self.reporter_test_project = 'buildbot/buildbot'
 
-        self.master = fakemaster.make_master(self, wantData=True, wantDb=True, wantMq=True)
+        self.master = yield fakemaster.make_master(self, wantData=True, wantDb=True, wantMq=True)
 
         yield self.master.startService()
+        self.addCleanup(self.master.stopService)
+
         self._http = yield fakehttpclientservice.HTTPClientService.getService(
             self.master,
             self,
@@ -58,9 +60,6 @@ class TestGitHubStatusPush(
     def createService(self):
         return GitHubStatusPush(Interpolate('XXYYZZ'))
 
-    def tearDown(self):
-        return self.master.stopService()
-
     @defer.inlineCallbacks
     def test_basic(self):
         build = yield self.insert_build_new()
@@ -121,14 +120,14 @@ class TestGitHubStatusPush(
     def test_source_stamp_no_props_nightly_scheduler(self):
         # no status updates are expected
 
-        self.master.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Master(id=92),
             fakedb.Worker(id=13, name='wrk'),
             fakedb.Builder(id=79, name='Builder0'),
             fakedb.Buildset(id=98, results=SUCCESS, reason="test_reason1"),
             fakedb.BuildsetSourceStamp(buildsetid=98, sourcestampid=234),
             fakedb.SourceStamp(
-                id=234, project=None, branch=None, revision=None, repository=None, codebase=None
+                id=234, project='', branch=None, revision=None, repository='repo', codebase='cb'
             ),
             fakedb.BuildRequest(id=11, buildsetid=98, builderid=79),
             fakedb.Build(
@@ -239,7 +238,7 @@ class TestGitHubStatusPush(
 
         # note that the first sourcestamp only has revision, second only branch and only the third
         # has both
-        self.master.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Master(id=92),
             fakedb.Worker(id=13, name='wrk'),
             fakedb.Builder(id=79, name='Builder0'),
@@ -307,9 +306,11 @@ class TestGitHubStatusPushURL(TestReactorMixin, unittest.TestCase, ReporterTestM
         self.reporter_test_project = 'buildbot'
         self.reporter_test_repo = 'https://github.com/buildbot1/buildbot1.git'
 
-        self.master = fakemaster.make_master(self, wantData=True, wantDb=True, wantMq=True)
+        self.master = yield fakemaster.make_master(self, wantData=True, wantDb=True, wantMq=True)
 
         yield self.master.startService()
+        self.addCleanup(self.master.stopService)
+
         self._http = yield fakehttpclientservice.HTTPClientService.getService(
             self.master,
             self,
@@ -324,9 +325,6 @@ class TestGitHubStatusPushURL(TestReactorMixin, unittest.TestCase, ReporterTestM
     def createService(self):
         return GitHubStatusPush('XXYYZZ')
 
-    def tearDown(self):
-        return self.master.stopService()
-
     @defer.inlineCallbacks
     def test_ssh(self):
         self.reporter_test_repo = 'git@github.com:buildbot2/buildbot2.git'
@@ -518,7 +516,7 @@ class TestGitHubCommentPush(TestGitHubStatusPush):
 
         # note that the first sourcestamp only has revision, second only branch and only the third
         # has both
-        self.master.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Master(id=92),
             fakedb.Worker(id=13, name='wrk'),
             fakedb.Builder(id=79, name='Builder0'),
