@@ -385,16 +385,14 @@ class TestOldBuildCanceller(TestReactorMixin, unittest.TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantMq=True, wantData=True, wantDb=True)
+        self.master = yield fakemaster.make_master(self, wantMq=True, wantData=True, wantDb=True)
         self.master.mq.verifyMessages = False
 
-        self.insert_test_data()
+        yield self.insert_test_data()
         self._cancelled_build_ids = []
 
         yield self.master.startService()
-
-    def tearDown(self):
-        return self.master.stopService()
+        self.addCleanup(self.master.stopService)
 
     def create_ss_dict(self, project, codebase, repository, branch):
         # Changes have the same structure for the attributes that we're using, so we reuse this
@@ -406,8 +404,9 @@ class TestOldBuildCanceller(TestReactorMixin, unittest.TestCase):
             'branch': branch,
         }
 
+    @defer.inlineCallbacks
     def insert_test_data(self):
-        self.master.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Master(id=92),
             fakedb.Worker(id=13, name='wrk'),
             fakedb.Builder(id=79, name='builder1'),
@@ -513,9 +512,9 @@ class TestOldBuildCanceller(TestReactorMixin, unittest.TestCase):
 
         ss_dict = self.create_ss_dict('project1', 'codebase1', 'repository1', None)
 
-        self.master.db.insert_test_data([
-            fakedb.Buildset(id=99, results=None, reason='reason99'),
-            fakedb.BuildsetSourceStamp(buildsetid=99, sourcestampid=240),
+        yield self.master.db.insert_test_data([
+            fakedb.Buildset(id=199, results=None, reason='reason99'),
+            fakedb.BuildsetSourceStamp(buildsetid=199, sourcestampid=240),
             fakedb.SourceStamp(
                 id=240,
                 revision='revision1',
@@ -524,13 +523,13 @@ class TestOldBuildCanceller(TestReactorMixin, unittest.TestCase):
                 repository='repository1',
                 branch=None,
             ),
-            fakedb.BuildRequest(id=14, buildsetid=99, builderid=79),
+            fakedb.BuildRequest(id=14, buildsetid=199, builderid=79),
         ])
 
         self.master.mq.callConsumer(('changes', '123', 'new'), ss_dict)
         self.master.mq.callConsumer(
             ('buildrequests', '14', 'new'),
-            {'buildrequestid': 14, 'builderid': 79, 'buildsetid': 99},
+            {'buildrequestid': 14, 'builderid': 79, 'buildsetid': 199},
         )
         self.assert_cancelled([])
 
@@ -542,47 +541,47 @@ class TestOldBuildCanceller(TestReactorMixin, unittest.TestCase):
 
         ss_dict = self.create_ss_dict('project1', 'codebase1', 'repository1', 'branch1')
 
-        self.master.db.insert_test_data([
-            fakedb.Buildset(id=99, results=None, reason='reason99'),
-            fakedb.BuildsetSourceStamp(buildsetid=99, sourcestampid=240),
+        yield self.master.db.insert_test_data([
+            fakedb.Buildset(id=199, results=None, reason='reason99'),
+            fakedb.BuildsetSourceStamp(buildsetid=199, sourcestampid=240),
             fakedb.SourceStamp(
                 id=240,
-                revision='revision1',
+                revision='revision240',
                 project='project1',
                 codebase='codebase1',
                 repository='repository1',
                 branch='branch1',
             ),
-            fakedb.BuildRequest(id=14, buildsetid=99, builderid=79),
+            fakedb.BuildRequest(id=14, buildsetid=199, builderid=79),
         ])
 
         self.master.mq.callConsumer(('changes', '123', 'new'), ss_dict)
         self.master.mq.callConsumer(
             ('buildrequests', '14', 'new'),
-            {'buildrequestid': 14, 'builderid': 79, 'buildsetid': 99},
+            {'buildrequestid': 14, 'builderid': 79, 'buildsetid': 199},
         )
         self.assert_cancelled([10])
 
         self.reactor.advance(1)
 
-        self.master.db.insert_test_data([
-            fakedb.Buildset(id=100, results=None, reason='reason100'),
-            fakedb.BuildsetSourceStamp(buildsetid=100, sourcestampid=241),
+        yield self.master.db.insert_test_data([
+            fakedb.Buildset(id=200, results=None, reason='reason100'),
+            fakedb.BuildsetSourceStamp(buildsetid=200, sourcestampid=241),
             fakedb.SourceStamp(
                 id=241,
-                revision='revision1',
+                revision='revision241',
                 project='project1',
                 codebase='codebase1',
                 repository='repository1',
                 branch='branch1',
             ),
-            fakedb.BuildRequest(id=15, buildsetid=100, builderid=79),
+            fakedb.BuildRequest(id=15, buildsetid=200, builderid=79),
         ])
 
         self.master.mq.callConsumer(('changes', '124', 'new'), ss_dict)
         self.master.mq.callConsumer(
             ('buildrequests', '15', 'new'),
-            {'buildrequestid': 15, 'builderid': 79, 'buildsetid': 100},
+            {'buildrequestid': 15, 'builderid': 79, 'buildsetid': 200},
         )
         self.assert_cancelled([14])
 
@@ -606,46 +605,46 @@ class TestOldBuildCanceller(TestReactorMixin, unittest.TestCase):
         ss_dict = self.create_ss_dict(
             'project2', 'codebase2', 'repository2', 'refs/changes/10/12310/3'
         )
-        self.master.db.insert_test_data([
-            fakedb.Buildset(id=99, results=None, reason='reason99'),
-            fakedb.BuildsetSourceStamp(buildsetid=99, sourcestampid=240),
+        yield self.master.db.insert_test_data([
+            fakedb.Buildset(id=199, results=None, reason='reason99'),
+            fakedb.BuildsetSourceStamp(buildsetid=199, sourcestampid=240),
             fakedb.SourceStamp(
                 id=240,
-                revision='revision2',
+                revision='revision240',
                 project='project2',
                 codebase='codebase2',
                 repository='repository2',
                 branch='refs/changes/10/12310/3',
             ),
-            fakedb.BuildRequest(id=14, buildsetid=99, builderid=81),
+            fakedb.BuildRequest(id=14, buildsetid=199, builderid=81),
         ])
 
         self.master.mq.callConsumer(('changes', '123', 'new'), ss_dict)
         self.master.mq.callConsumer(
             ('buildrequests', '14', 'new'),
-            {'buildrequestid': 14, 'builderid': 81, 'buildsetid': 99},
+            {'buildrequestid': 14, 'builderid': 81, 'buildsetid': 199},
         )
         self.assert_cancelled([12])
 
         self.reactor.advance(1)
 
-        self.master.db.insert_test_data([
-            fakedb.Buildset(id=100, results=None, reason='reason100'),
-            fakedb.BuildsetSourceStamp(buildsetid=100, sourcestampid=241),
+        yield self.master.db.insert_test_data([
+            fakedb.Buildset(id=200, results=None, reason='reason100'),
+            fakedb.BuildsetSourceStamp(buildsetid=200, sourcestampid=241),
             fakedb.SourceStamp(
                 id=241,
-                revision='revision2',
+                revision='revision241',
                 project='project2',
                 codebase='codebase2',
                 repository='repository2',
                 branch='refs/changes/10/12310/3',
             ),
-            fakedb.BuildRequest(id=15, buildsetid=100, builderid=81),
+            fakedb.BuildRequest(id=15, buildsetid=200, builderid=81),
         ])
         self.master.mq.callConsumer(('changes', '124', 'new'), ss_dict)
         self.master.mq.callConsumer(
             ('buildrequests', '15', 'new'),
-            {'buildrequestid': 15, 'builderid': 81, 'buildsetid': 100},
+            {'buildrequestid': 15, 'builderid': 81, 'buildsetid': 200},
         )
         self.assert_cancelled([14])
 
@@ -671,46 +670,46 @@ class TestOldBuildCanceller(TestReactorMixin, unittest.TestCase):
 
         yield self.canceller.reconfigService('canceller', [])
 
-        self.master.db.insert_test_data([
-            fakedb.Buildset(id=99, results=None, reason='reason99'),
-            fakedb.BuildsetSourceStamp(buildsetid=99, sourcestampid=235),
+        yield self.master.db.insert_test_data([
+            fakedb.Buildset(id=199, results=None, reason='reason99'),
+            fakedb.BuildsetSourceStamp(buildsetid=199, sourcestampid=242),
             fakedb.SourceStamp(
-                id=235,
-                revision='revision1',
+                id=242,
+                revision='revision242',
                 project='project1',
                 codebase='codebase1',
                 repository='repository1',
                 branch='branch1',
             ),
-            fakedb.BuildRequest(id=14, buildsetid=99, builderid=79),
+            fakedb.BuildRequest(id=14, buildsetid=199, builderid=79),
         ])
 
         self.master.mq.callConsumer(('changes', '123', 'new'), ss_dict)
         self.master.mq.callConsumer(
             ('buildrequests', '14', 'new'),
-            {'buildrequestid': 14, 'builderid': 79, 'buildsetid': 99},
+            {'buildrequestid': 14, 'builderid': 79, 'buildsetid': 199},
         )
         self.assert_cancelled([10])
 
         self.reactor.advance(1)
 
-        self.master.db.insert_test_data([
-            fakedb.Buildset(id=100, results=None, reason='reason100'),
-            fakedb.BuildsetSourceStamp(buildsetid=100, sourcestampid=240),
+        yield self.master.db.insert_test_data([
+            fakedb.Buildset(id=200, results=None, reason='reason100'),
+            fakedb.BuildsetSourceStamp(buildsetid=200, sourcestampid=240),
             fakedb.SourceStamp(
                 id=240,
-                revision='revision1',
+                revision='revision240',
                 project='project1',
                 codebase='codebase1',
                 repository='repository1',
                 branch='branch1',
             ),
-            fakedb.BuildRequest(id=15, buildsetid=100, builderid=79),
+            fakedb.BuildRequest(id=15, buildsetid=200, builderid=79),
         ])
         self.master.mq.callConsumer(('changes', '124', 'new'), ss_dict)
         self.master.mq.callConsumer(
             ('buildrequests', '15', 'new'),
-            {'buildrequestid': 15, 'builderid': 79, 'buildsetid': 100},
+            {'buildrequestid': 15, 'builderid': 79, 'buildsetid': 200},
         )
         self.assert_cancelled([])
 
