@@ -25,9 +25,10 @@ from buildbot.schedulers import timed
 from buildbot.test import fakedb
 from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util import scheduler
+from buildbot.test.util.state import StateTestMixin
 
 
-class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
+class Nightly(scheduler.SchedulerMixin, TestReactorMixin, StateTestMixin, unittest.TestCase):
     OBJECTID = 132
     SCHEDULERID = 32
 
@@ -43,12 +44,13 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
     long_ago_time = 86400
 
+    @defer.inlineCallbacks
     def makeScheduler(self, **kwargs):
-        sched = self.attachScheduler(
+        sched = yield self.attachScheduler(
             timed.Nightly(**kwargs), self.OBJECTID, self.SCHEDULERID, overrideBuildsetMethods=True
         )
 
-        self.master.db.insert_test_data([
+        yield self.master.db.insert_test_data([
             fakedb.Builder(name=bname) for bname in kwargs.get("builderNames", [])
         ])
 
@@ -100,6 +102,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         ss.update(kwargs)
         return ss
 
+    @defer.inlineCallbacks
     def mkch(self, **kwargs):
         # create changeset and insert in database.
         chd = {"branch": 'master', "project": '', "repository": ''}
@@ -108,33 +111,37 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         # fakedb.Change requires changeid instead of number
         chd['changeid'] = chd['number']
         del chd['number']
-        self.db.insert_test_data([fakedb.Change(**chd)])
+        yield self.db.insert_test_data([
+            fakedb.Change(**chd),
+            fakedb.SourceStamp(id=92),
+        ])
         return ch
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.setUpScheduler()
-
-    def tearDown(self):
-        self.tearDownScheduler()
+        yield self.setUpScheduler()
 
     def assertConsumingChanges(self, **kwargs):
         self.assertEqual(self.consumingChanges, kwargs)
 
     # Tests
 
+    @defer.inlineCallbacks
     def test_constructor_no_reason(self):
-        sched = self.makeScheduler(name='test', builderNames=['test'], branch='default')
+        sched = yield self.makeScheduler(name='test', builderNames=['test'], branch='default')
         self.assertEqual(sched.reason, "The Nightly scheduler named 'test' triggered this build")
 
+    @defer.inlineCallbacks
     def test_constructor_reason(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='default', reason="hourly"
         )
         self.assertEqual(sched.reason, "hourly")
 
+    @defer.inlineCallbacks
     def test_constructor_change_filter(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='test',
             builderNames=['test'],
             branch=None,
@@ -142,32 +149,40 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         )
         assert sched.change_filter
 
+    @defer.inlineCallbacks
     def test_constructor_month(self):
-        sched = self.makeScheduler(name='test', builderNames=['test'], branch='default', month='1')
+        sched = yield self.makeScheduler(
+            name='test', builderNames=['test'], branch='default', month='1'
+        )
         self.assertEqual(sched.month, "1")
 
+    @defer.inlineCallbacks
     def test_constructor_priority_none(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='default', priority=None
         )
         self.assertEqual(sched.priority, None)
 
+    @defer.inlineCallbacks
     def test_constructor_priority_int(self):
-        sched = self.makeScheduler(name='test', builderNames=['test'], branch='default', priority=8)
+        sched = yield self.makeScheduler(
+            name='test', builderNames=['test'], branch='default', priority=8
+        )
         self.assertEqual(sched.priority, 8)
 
+    @defer.inlineCallbacks
     def test_constructor_priority_function(self):
         def sched_priority(builderNames, changesByCodebase):
             return 0
 
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='default', priority=sched_priority
         )
         self.assertEqual(sched.priority, sched_priority)
 
     @defer.inlineCallbacks
     def test_enabled_callback(self):
-        sched = self.makeScheduler(name='test', builderNames=['test'], branch='default')
+        sched = yield self.makeScheduler(name='test', builderNames=['test'], branch='default')
         expectedValue = not sched.enabled
         yield sched._enabledCallback(None, {'enabled': not sched.enabled})
         self.assertEqual(sched.enabled, expectedValue)
@@ -177,7 +192,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_disabled_activate(self):
-        sched = self.makeScheduler(name='test', builderNames=['test'], branch='default')
+        sched = yield self.makeScheduler(name='test', builderNames=['test'], branch='default')
         yield sched._enabledCallback(None, {'enabled': not sched.enabled})
         self.assertEqual(sched.enabled, False)
         r = yield sched.activate()
@@ -185,7 +200,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_disabled_deactivate(self):
-        sched = self.makeScheduler(name='test', builderNames=['test'], branch='default')
+        sched = yield self.makeScheduler(name='test', builderNames=['test'], branch='default')
         yield sched._enabledCallback(None, {'enabled': not sched.enabled})
         self.assertEqual(sched.enabled, False)
         r = yield sched.deactivate()
@@ -193,7 +208,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_disabled_start_build(self):
-        sched = self.makeScheduler(name='test', builderNames=['test'], branch='default')
+        sched = yield self.makeScheduler(name='test', builderNames=['test'], branch='default')
         yield sched._enabledCallback(None, {'enabled': not sched.enabled})
         self.assertEqual(sched.enabled, False)
         r = yield sched.startBuild()
@@ -207,18 +222,19 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         # starts at midnight UTC, so be careful not to use times that are
         # timezone dependent -- stick to minutes-past-the-half-hour, as some
         # timezones are multiples of 30 minutes off from UTC
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch=None, minute=[10, 20, 21, 40, 50, 51]
         )
+        yield self.mkch(number=19)
 
         # add a change classification
-        self.db.schedulers.fakeClassifications(self.SCHEDULERID, {19: True})
+        yield self.db.schedulers.classifyChanges(self.SCHEDULERID, {19: True})
 
         yield sched.activate()
 
         # check that the classification has been flushed, since this
         # invocation has not requested onlyIfChanged
-        self.db.schedulers.assertClassifications(self.SCHEDULERID, {})
+        yield self.assert_classifications(self.SCHEDULERID, {})
 
         self.reactor.advance(0)
         while self.reactor.seconds() < self.time_offset + 30 * 60:
@@ -262,13 +278,14 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 ),
             ],
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1260 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1260 + self.time_offset)
 
         yield sched.deactivate()
 
+    @defer.inlineCallbacks
     def test_iterations_simple_with_branch(self):
         # see timezone warning above
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='test', builderNames=['test'], branch='master', minute=[5, 35]
         )
 
@@ -294,16 +311,16 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=300 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=300 + self.time_offset)
 
-        d = sched.deactivate()
-        return d
+        yield sched.deactivate()
 
+    @defer.inlineCallbacks
     def do_test_iterations_onlyIfChanged(
         self, changes_at, last_only_if_changed, is_new_scheduler=False, **kwargs
     ):
         fII = mock.Mock(name='fII')
-        self.makeScheduler(
+        yield self.makeScheduler(
             name='test',
             builderNames=['test'],
             branch=None,
@@ -314,12 +331,12 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         )
 
         if not is_new_scheduler:
-            self.db.state.set_fake_state(self.sched, 'last_build', self.long_ago_time)
+            yield self.set_fake_state(self.sched, 'last_build', self.long_ago_time)
 
         if last_only_if_changed is not None:
-            self.db.state.set_fake_state(self.sched, 'last_only_if_changed', last_only_if_changed)
+            yield self.set_fake_state(self.sched, 'last_only_if_changed', last_only_if_changed)
 
-        return self.do_test_iterations_onlyIfChanged_test(fII, changes_at)
+        return (yield self.do_test_iterations_onlyIfChanged_test(fII, changes_at))
 
     @defer.inlineCallbacks
     def do_test_iterations_onlyIfChanged_test(self, fII, changes_at):
@@ -335,7 +352,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
             # inject any new changes..
             while changes_at and self.reactor.seconds() >= self.time_offset + changes_at[0][0]:
                 _, newchange, important = changes_at.pop(0)
-                self.db.changes.fakeAddChangeInstance(newchange)
+                newchange = yield self.addFakeChange(newchange)
                 yield self.sched.gotChange(newchange, important).addErrback(log.err)
             # and advance the clock by a minute
             self.reactor.advance(60)
@@ -361,14 +378,14 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
     def test_iterations_onlyIfChanged_no_changes_existing_scheduler(self):
         yield self.do_test_iterations_onlyIfChanged([], last_only_if_changed=True)
         self.assertEqual(self.addBuildsetCalls, [])
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
@@ -398,7 +415,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
@@ -408,7 +425,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         yield self.do_test_iterations_onlyIfChanged([], last_only_if_changed=None)
         self.assertEqual(self.addBuildsetCallTimes, [])
         self.assertEqual(self.addBuildsetCalls, [])
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
@@ -434,15 +451,15 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
     def test_iterations_onlyIfChanged_unimp_changes_calls_for_new_scheduler(self):
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (60, mock.Mock(), False),
-                (600, mock.Mock(), False),
+                (60, self.makeFakeChange(number=500, branch=None), False),
+                (600, self.makeFakeChange(number=501, branch=None), False),
             ],
             last_only_if_changed=None,
             is_new_scheduler=True,
@@ -452,28 +469,29 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
             self.addBuildsetCalls,
             [
                 (
-                    'addBuildsetForSourceStampsWithDefaults',
+                    'addBuildsetForChanges',
                     {
                         'builderNames': None,
+                        'changeids': [500],
+                        'external_idstring': None,
                         'priority': None,
                         'properties': None,
                         'reason': "The Nightly scheduler named 'test' triggered this build",
-                        'sourcestamps': [{'codebase': ''}],
                         'waited_for': False,
                     },
                 )
             ],
         )
 
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
     def test_iterations_onlyIfChanged_unimp_changes_existing_sched_changed_only_if_changed(self):
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (60, mock.Mock(), False),
-                (600, mock.Mock(), False),
+                (60, self.makeFakeChange(number=500, branch=None), False),
+                (600, self.makeFakeChange(number=501, branch=None), False),
             ],
             last_only_if_changed=False,
         )
@@ -495,22 +513,22 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
             ],
         )
 
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
     def test_iterations_onlyIfChanged_unimp_changes_existing_sched_same_only_if_changed(self):
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (60, mock.Mock(), False),
-                (600, mock.Mock(), False),
+                (60, self.makeFakeChange(number=500, branch=None), False),
+                (600, self.makeFakeChange(number=501, branch=None), False),
             ],
             last_only_if_changed=True,
         )
 
         self.assertEqual(self.addBuildsetCalls, [])
 
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
@@ -519,9 +537,9 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         # separately
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (120, self.makeFakeChange(number=1, branch=None), False),
-                (1200, self.makeFakeChange(number=2, branch=None), True),
-                (1201, self.makeFakeChange(number=3, branch=None), False),
+                (120, self.makeFakeChange(number=500, branch=None), False),
+                (1200, self.makeFakeChange(number=501, branch=None), True),
+                (1201, self.makeFakeChange(number=502, branch=None), False),
             ],
             last_only_if_changed=None,
         )
@@ -536,7 +554,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                         'waited_for': False,
                         'reason': "The Nightly scheduler named 'test' triggered this build",
                         'external_idstring': None,
-                        'changeids': [1, 2, 3],
+                        'changeids': [500, 501, 502],
                         'priority': None,
                         'properties': None,
                         'builderNames': None,
@@ -544,15 +562,15 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 ),
             ],
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
     def test_iterations_onlyIfChanged_unimp_changes_force_at(self):
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (60, self.makeFakeChange(number=1, branch=None), False),
-                (600, self.makeFakeChange(number=2, branch=None), False),
+                (60, self.makeFakeChange(number=500, branch=None), False),
+                (600, self.makeFakeChange(number=501, branch=None), False),
             ],
             last_only_if_changed=True,
             force_at_minute=[23, 25, 27],
@@ -566,7 +584,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                     'addBuildsetForChanges',
                     {
                         'builderNames': None,
-                        'changeids': [1, 2],
+                        'changeids': [500, 501],
                         'external_idstring': None,
                         'priority': None,
                         'properties': None,
@@ -576,32 +594,32 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
     def test_iterations_onlyIfChanged_off_branch_changes(self):
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (60, self.makeFakeChange(number=1, branch='testing'), True),
-                (1700, self.makeFakeChange(number=2, branch='staging'), True),
+                (60, self.makeFakeChange(number=500, branch='testing'), True),
+                (1700, self.makeFakeChange(number=501, branch='staging'), True),
             ],
             last_only_if_changed=True,
         )
 
         self.assertEqual(self.addBuildsetCalls, [])
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
     def test_iterations_onlyIfChanged_mixed_changes(self):
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (120, self.makeFakeChange(number=3, branch=None), False),
-                (130, self.makeFakeChange(number=4, branch='offbranch'), True),
-                (1200, self.makeFakeChange(number=5, branch=None), True),
-                (1201, self.makeFakeChange(number=6, branch=None), False),
-                (1202, self.makeFakeChange(number=7, branch='offbranch'), True),
+                (120, self.makeFakeChange(number=500, branch=None), False),
+                (130, self.makeFakeChange(number=501, branch='offbranch'), True),
+                (1200, self.makeFakeChange(number=502, branch=None), True),
+                (1201, self.makeFakeChange(number=503, branch=None), False),
+                (1202, self.makeFakeChange(number=504, branch='offbranch'), True),
             ],
             last_only_if_changed=True,
         )
@@ -617,7 +635,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                     'addBuildsetForChanges',
                     {
                         'builderNames': None,
-                        'changeids': [3, 5, 6],
+                        'changeids': [500, 502, 503],
                         'external_idstring': None,
                         'priority': None,
                         'properties': None,
@@ -627,7 +645,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         yield self.sched.deactivate()
 
     @defer.inlineCallbacks
@@ -636,7 +654,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         # changed
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (120, self.makeFakeChange(number=3, codebase='a', revision='2345:bcd'), True),
+                (120, self.makeFakeChange(number=500, codebase='a', revision='2345:bcd'), True),
             ],
             codebases={
                 'a': {'repository': "", 'branch': 'master'},
@@ -645,7 +663,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
             createAbsoluteSourceStamps=True,
             last_only_if_changed=True,
         )
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         # addBuildsetForChanges calls getCodebase, so this isn't too
         # interesting
         self.assertEqual(self.addBuildsetCallTimes, [300])
@@ -656,7 +674,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                     'addBuildsetForChanges',
                     {
                         'builderNames': None,
-                        'changeids': [3],
+                        'changeids': [500],
                         'external_idstring': None,
                         'priority': None,
                         'properties': None,
@@ -666,11 +684,11 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass(
+        yield self.assert_state_by_class(
             'test',
             'Nightly',
             lastCodebases={
-                'a': {"revision": '2345:bcd', "branch": None, "repository": '', "lastChange": 3}
+                'a': {"revision": '2345:bcd', "branch": None, "repository": '', "lastChange": 500}
             },
         )
         yield self.sched.deactivate()
@@ -680,7 +698,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         # Test createAbsoluteSourceStamps=True when only one codebase has changed,
         # but the other was previously changed
         fII = mock.Mock(name='fII')
-        self.makeScheduler(
+        yield self.makeScheduler(
             name='test',
             builderNames=['test'],
             branch=None,
@@ -694,21 +712,28 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
             createAbsoluteSourceStamps=True,
         )
 
-        self.db.state.set_fake_state(self.sched, 'last_only_if_changed', True)
-        self.db.state.set_fake_state(
+        yield self.set_fake_state(self.sched, 'last_only_if_changed', True)
+        yield self.set_fake_state(
             self.sched,
             'lastCodebases',
-            {'b': {'branch': 'master', 'repository': 'B', 'revision': '1234:abc', 'lastChange': 2}},
+            {
+                'b': {
+                    'branch': 'master',
+                    'repository': 'B',
+                    'revision': '1234:abc',
+                    'lastChange': 499,
+                }
+            },
         )
 
         yield self.do_test_iterations_onlyIfChanged_test(
             fII,
             [
-                (120, self.makeFakeChange(number=3, codebase='a', revision='2345:bcd'), True),
+                (120, self.makeFakeChange(number=500, codebase='a', revision='2345:bcd'), True),
             ],
         )
 
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         # addBuildsetForChanges calls getCodebase, so this isn't too
         # interesting
         self.assertEqual(self.addBuildsetCallTimes, [300])
@@ -719,7 +744,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                     'addBuildsetForChanges',
                     {
                         'builderNames': None,
-                        'changeids': [3],
+                        'changeids': [500],
                         'external_idstring': None,
                         'priority': None,
                         'properties': None,
@@ -729,16 +754,16 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass(
+        yield self.assert_state_by_class(
             'test',
             'Nightly',
             lastCodebases={
-                'a': {"revision": '2345:bcd', "branch": None, "repository": '', "lastChange": 3},
+                'a': {"revision": '2345:bcd', "branch": None, "repository": '', "lastChange": 500},
                 'b': {
                     "revision": '1234:abc',
                     "branch": "master",
                     "repository": 'B',
-                    "lastChange": 2,
+                    "lastChange": 499,
                 },
             },
         )
@@ -749,8 +774,8 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         # Test createAbsoluteSourceStamps=True when both codebases have changed
         yield self.do_test_iterations_onlyIfChanged(
             [
-                (120, self.makeFakeChange(number=3, codebase='a', revision='2345:bcd'), True),
-                (122, self.makeFakeChange(number=4, codebase='b', revision='1234:abc'), True),
+                (120, self.makeFakeChange(number=500, codebase='a', revision='2345:bcd'), True),
+                (122, self.makeFakeChange(number=501, codebase='b', revision='1234:abc'), True),
             ],
             codebases={
                 'a': {'repository': "", 'branch': 'master'},
@@ -760,7 +785,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
             createAbsoluteSourceStamps=True,
         )
 
-        self.db.state.assertStateByClass('test', 'Nightly', last_build=1500 + self.time_offset)
+        yield self.assert_state_by_class('test', 'Nightly', last_build=1500 + self.time_offset)
         # addBuildsetForChanges calls getCodebase, so this isn't too
         # interesting
         self.assertEqual(self.addBuildsetCallTimes, [300])
@@ -771,7 +796,7 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                     'addBuildsetForChanges',
                     {
                         'builderNames': None,
-                        'changeids': [3, 4],
+                        'changeids': [500, 501],
                         'external_idstring': None,
                         'priority': None,
                         'properties': None,
@@ -781,12 +806,12 @@ class Nightly(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
                 )
             ],
         )
-        self.db.state.assertStateByClass(
+        yield self.assert_state_by_class(
             'test',
             'Nightly',
             lastCodebases={
-                'a': {"revision": '2345:bcd', "branch": None, "repository": '', "lastChange": 3},
-                'b': {"revision": '1234:abc', "branch": None, "repository": '', "lastChange": 4},
+                'a': {"revision": '2345:bcd', "branch": None, "repository": '', "lastChange": 500},
+                'b': {"revision": '1234:abc', "branch": None, "repository": '', "lastChange": 501},
             },
         )
         yield self.sched.deactivate()
