@@ -16,11 +16,9 @@
 import json
 import os
 import shutil
-import sys
 from io import StringIO
 from unittest import mock
 
-import twisted
 from twisted.internet import defer
 from twisted.protocols import basic
 from twisted.trial import unittest
@@ -35,12 +33,10 @@ class TryBase(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
     OBJECTID = 26
     SCHEDULERID = 6
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.setUpScheduler()
-
-    def tearDown(self):
-        self.tearDownScheduler()
+        yield self.setUpScheduler()
 
     def makeScheduler(self, **kwargs):
         return self.attachScheduler(
@@ -61,7 +57,7 @@ class TryBase(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_enabled_callback(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='tsched', builderNames=['a'], port='tcp:9999', userpass=[('fred', 'derf')]
         )
         expectedValue = not sched.enabled
@@ -73,7 +69,7 @@ class TryBase(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_disabled_activate(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='tsched', builderNames=['a'], port='tcp:9999', userpass=[('fred', 'derf')]
         )
         yield sched._enabledCallback(None, {'enabled': not sched.enabled})
@@ -83,7 +79,7 @@ class TryBase(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
     @defer.inlineCallbacks
     def test_disabled_deactivate(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='tsched', builderNames=['a'], port='tcp:9999', userpass=[('fred', 'derf')]
         )
         yield sched._enabledCallback(None, {'enabled': not sched.enabled})
@@ -100,9 +96,6 @@ class JobdirService(dirs.DirsMixin, unittest.TestCase):
         self.tmpdir = os.path.join(self.jobdir, 'tmp')
         self.setUpDirs(self.jobdir, self.newdir, self.curdir, self.tmpdir)
 
-    def tearDown(self):
-        self.tearDownDirs()
-
     def test_messageReceived(self):
         # stub out svc.scheduler.handleJobFile and .jobdir
         scheduler = mock.Mock()
@@ -129,18 +122,19 @@ class Try_Jobdir(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
     OBJECTID = 23
     SCHEDULERID = 3
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.setUpScheduler()
+        yield self.setUpScheduler()
         self.jobdir = None
 
     def tearDown(self):
-        self.tearDownScheduler()
         if self.jobdir:
             shutil.rmtree(self.jobdir)
 
     # tests
 
+    @defer.inlineCallbacks
     def setup_test_startService(self, jobdir, exp_jobdir):
         # set up jobdir
         self.jobdir = os.path.abspath('jobdir')
@@ -150,7 +144,7 @@ class Try_Jobdir(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
         # build scheduler
         kwargs = {"name": 'tsched', "builderNames": ['a'], "jobdir": self.jobdir}
-        sched = self.attachScheduler(
+        sched = yield self.attachScheduler(
             trysched.Try_Jobdir(**kwargs),
             self.OBJECTID,
             self.SCHEDULERID,
@@ -176,22 +170,25 @@ class Try_Jobdir(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         self.assertEqual(1, self.sched.watcher.startService.call_count)
         self.assertEqual(1, self.sched.watcher.stopService.call_count)
 
+    @defer.inlineCallbacks
     def test_startService_reldir(self):
-        self.setup_test_startService('jobdir', os.path.abspath('basedir/jobdir'))
-        return self.do_test_startService()
+        yield self.setup_test_startService('jobdir', os.path.abspath('basedir/jobdir'))
+        yield self.do_test_startService()
 
+    @defer.inlineCallbacks
     def test_startService_reldir_subdir(self):
-        self.setup_test_startService('jobdir', os.path.abspath('basedir/jobdir/cur'))
-        return self.do_test_startService()
+        yield self.setup_test_startService('jobdir', os.path.abspath('basedir/jobdir/cur'))
+        yield self.do_test_startService()
 
+    @defer.inlineCallbacks
     def test_startService_absdir(self):
-        self.setup_test_startService(os.path.abspath('jobdir'), os.path.abspath('jobdir'))
-        return self.do_test_startService()
+        yield self.setup_test_startService(os.path.abspath('jobdir'), os.path.abspath('jobdir'))
+        yield self.do_test_startService()
 
     @defer.inlineCallbacks
     def do_test_startService_but_not_active(self, jobdir, exp_jobdir):
         """Same as do_test_startService, but the master wont activate this service"""
-        self.setup_test_startService('jobdir', os.path.abspath('basedir/jobdir'))
+        yield self.setup_test_startService('jobdir', os.path.abspath('basedir/jobdir'))
 
         self.setSchedulerToMaster(self.OTHER_MASTER_ID)
 
@@ -709,8 +706,9 @@ class Try_Jobdir(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
 
     # handleJobFile
 
+    @defer.inlineCallbacks
     def call_handleJobFile(self, parseJob):
-        sched = self.attachScheduler(
+        sched = yield self.attachScheduler(
             trysched.Try_Jobdir(name='tsched', builderNames=['buildera', 'builderb'], jobdir='foo'),
             self.OBJECTID,
             self.SCHEDULERID,
@@ -724,7 +722,7 @@ class Try_Jobdir(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
             return parseJob(f)
 
         sched.parseJob = parseJob_
-        return defer.maybeDeferred(sched.handleJobFile, 'fakefile', fakefile)
+        yield sched.handleJobFile('fakefile', fakefile)
 
     def makeSampleParsedJob(self, **overrides):
         pj = {
@@ -786,11 +784,6 @@ class Try_Jobdir(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
         self.assertEqual(self.addBuildsetCalls, [])
         self.assertEqual(1, len(self.flushLoggedErrors(trysched.BadJobfile)))
 
-    if twisted.version.major <= 9 and sys.version_info[:2] >= (2, 7):
-        test_handleJobFile_exception.skip = (
-            "flushLoggedErrors does not work correctly on 9.0.0 and earlier with Python-2.7"
-        )
-
     @defer.inlineCallbacks
     def test_handleJobFile_bad_builders(self):
         yield self.call_handleJobFile(lambda f: self.makeSampleParsedJob(builderNames=['xxx']))
@@ -863,21 +856,22 @@ class Try_Jobdir(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
             ],
         )
 
+    @defer.inlineCallbacks
     def test_handleJobFile_with_invalid_try_properties(self):
-        d = self.call_handleJobFile(lambda f: self.makeSampleParsedJob(properties=['foo', 'bar']))
-        return self.assertFailure(d, AttributeError)
+        with self.assertRaises(AttributeError):
+            yield self.call_handleJobFile(
+                lambda f: self.makeSampleParsedJob(properties=['foo', 'bar'])
+            )
 
 
 class Try_Userpass_Perspective(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase):
     OBJECTID = 26
     SCHEDULERID = 6
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.setUpScheduler()
-
-    def tearDown(self):
-        self.tearDownScheduler()
+        yield self.setUpScheduler()
 
     def makeScheduler(self, **kwargs):
         return self.attachScheduler(
@@ -890,7 +884,7 @@ class Try_Userpass_Perspective(scheduler.SchedulerMixin, TestReactorMixin, unitt
 
     @defer.inlineCallbacks
     def call_perspective_try(self, *args, **kwargs):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='tsched',
             builderNames=['a', 'b'],
             port='xxx',
@@ -1035,7 +1029,7 @@ class Try_Userpass_Perspective(scheduler.SchedulerMixin, TestReactorMixin, unitt
 
     @defer.inlineCallbacks
     def test_getAvailableBuilderNames(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='tsched', builderNames=['a', 'b'], port='xxx', userpass=[('a', 'b')]
         )
         persp = trysched.Try_Userpass_Perspective(sched, 'a')
@@ -1048,22 +1042,21 @@ class Try_Userpass(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase
     OBJECTID = 25
     SCHEDULERID = 5
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.setUpScheduler()
-
-    def tearDown(self):
-        self.tearDownScheduler()
+        yield self.setUpScheduler()
 
+    @defer.inlineCallbacks
     def makeScheduler(self, **kwargs):
-        sched = self.attachScheduler(
+        sched = yield self.attachScheduler(
             trysched.Try_Userpass(**kwargs), self.OBJECTID, self.SCHEDULERID
         )
         return sched
 
     @defer.inlineCallbacks
     def test_service(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='tsched', builderNames=['a'], port='tcp:9999', userpass=[('fred', 'derf')]
         )
         # patch out the pbmanager's 'register' command both to be sure
@@ -1088,7 +1081,7 @@ class Try_Userpass(scheduler.SchedulerMixin, TestReactorMixin, unittest.TestCase
 
     @defer.inlineCallbacks
     def test_service_but_not_active(self):
-        sched = self.makeScheduler(
+        sched = yield self.makeScheduler(
             name='tsched', builderNames=['a'], port='tcp:9999', userpass=[('fred', 'derf')]
         )
 
