@@ -40,9 +40,6 @@ class TestCVS(sourcesteps.SourceStepMixin, TestReactorMixin, unittest.TestCase):
         self.setup_test_reactor()
         return self.setUpSourceStep()
 
-    def tearDown(self):
-        return self.tearDownSourceStep()
-
     def setup_step(self, step, *args, **kwargs):
         super().setup_step(step, *args, **kwargs)
 
