@@ -36,9 +36,6 @@ class TestDarcs(sourcesteps.SourceStepMixin, TestReactorMixin, unittest.TestCase
         self.setup_test_reactor()
         return self.setUpSourceStep()
 
-    def tearDown(self):
-        return self.tearDownSourceStep()
-
     def test_no_empty_step_config(self):
         with self.assertRaises(config.ConfigErrors):
             darcs.Darcs()
