@@ -44,9 +44,6 @@ class TestMonotone(
         self.setup_test_reactor()
         return self.setUpSourceStep()
 
-    def tearDown(self):
-        return self.tearDownSourceStep()
-
     def test_mode_full_clean(self):
         self.setup_step(
             mtn.Monotone(
