@@ -65,9 +65,6 @@ class TestRepo(sourcesteps.SourceStepMixin, TestReactorMixin, unittest.TestCase)
         self.logEnviron = True
         return self.setUpSourceStep()
 
-    def tearDown(self):
-        return self.tearDownSourceStep()
-
     def shouldLogEnviron(self):
         r = self.logEnviron
         self.logEnviron = False
