@@ -1,4 +1,3 @@
-# coding: utf-8
 # This file is part of Buildbot.  Buildbot is free software: you can
 # redistribute it and/or modify it under the terms of the GNU General Public
 # License as published by the Free Software Foundation, version 2.
@@ -31,10 +30,14 @@ from buildbot.config.master import FileLoader
 from buildbot.config.master import MasterConfig
 from buildbot.db import exceptions
 from buildbot.interfaces import IConfigLoader
+from buildbot.process.properties import Interpolate
+from buildbot.secrets.manager import SecretManager
 from buildbot.test import fakedb
 from buildbot.test.fake import fakedata
+from buildbot.test.fake import fakemaster
 from buildbot.test.fake import fakemq
 from buildbot.test.fake.botmaster import FakeBotMaster
+from buildbot.test.fake.secrets import FakeSecretStorage
 from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util import dirs
 from buildbot.test.util import logging
@@ -49,7 +52,10 @@ class FailingLoader:
 @implementer(IConfigLoader)
 class DefaultLoader:
     def loadConfig(self):
-        return MasterConfig()
+        master_cfg = MasterConfig()
+        master_cfg.db['db_url'] = Interpolate('sqlite:///path-to-%(secret:db_pwd)s-db-file')
+        master_cfg.secretsProviders = [FakeSecretStorage(secretdict={'db_pwd': 's3cr3t'})]
+        return master_cfg
 
 
 class InitTests(unittest.SynchronousTestCase):
@@ -91,16 +97,24 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
         )
         self.master.sendBuildbotNetUsageData = mock.Mock()
         self.master.botmaster = FakeBotMaster()
-        self.db = self.master.db = fakedb.FakeDBConnector(self)
-        yield self.db.setServiceParent(self.master)
+        self.master.caches = fakemaster.FakeCaches()
+        self.secrets_manager = self.master.secrets_manager = SecretManager()
+        yield self.secrets_manager.setServiceParent(self.master)
+        self.db = self.master.db = fakedb.FakeDBConnector(self.basedir, self, auto_upgrade=True)
+        yield self.db.set_master(self.master)
+
+        @defer.inlineCallbacks
+        def cleanup():
+            if self.db.pool is not None:
+                yield self.db.pool.stop()
+
+        self.addCleanup(cleanup)
+
         self.mq = self.master.mq = fakemq.FakeMQConnector(self)
         yield self.mq.setServiceParent(self.master)
         self.data = self.master.data = fakedata.FakeDataConnector(self.master, self)
         yield self.data.setServiceParent(self.master)
 
-    def tearDown(self):
-        return self.tearDownDirs()
-
     # tests
     @defer.inlineCallbacks
     def test_startup_bad_config(self):
@@ -143,6 +157,11 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
     def test_startup_ok(self):
         yield self.master.startService()
 
+        self.assertEqual(
+            self.master.db.configured_url,
+            'sqlite:///path-to-s3cr3t-db-file',
+        )
+
         self.assertTrue(self.master.data.updates.thisMasterActive)
         d = self.master.stopService()
         self.assertTrue(d.called)
@@ -207,11 +226,16 @@ class StartupAndReconfig(dirs.DirsMixin, logging.LoggingMixin, TestReactorMixin,
     @defer.inlineCallbacks
     def test_reconfigService_db_url_changed(self):
         old = self.master.config = MasterConfig()
-        old.db['db_url'] = 'aaaa'
+        old.db['db_url'] = Interpolate('sqlite:///%(secret:db_pwd)s')
+        old.secretsProviders = [FakeSecretStorage(secretdict={'db_pwd': 's3cr3t'})]
+        yield self.master.secrets_manager.setup()
+        yield self.master.db.setup()
         yield self.master.reconfigServiceWithBuildbotConfig(old)
+        self.assertEqual(self.master.db.configured_url, 'sqlite:///s3cr3t')
 
         new = MasterConfig()
-        new.db['db_url'] = 'bbbb'
+        new.db['db_url'] = old.db['db_url']
+        new.secretsProviders = [FakeSecretStorage(secretdict={'db_pwd': 'other-s3cr3t'})]
 
         with self.assertRaises(config.ConfigErrors):
-            self.master.reconfigServiceWithBuildbotConfig(new)
+            yield self.master.reconfigServiceWithBuildbotConfig(new)
