@@ -30,9 +30,10 @@ class TestLocalWorker(TestReactorMixin, unittest.TestCase):
     except ImportError:
         skip = "buildbot-worker package is not installed"
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakemaster.make_master(self, wantDb=True, wantData=True)
+        self.master = yield fakemaster.make_master(self, wantDb=True, wantData=True)
         self.botmaster = self.master.botmaster
         self.workers = self.master.workers
 
