@@ -52,7 +52,7 @@ class TestDispatcher(BaseDispatcher):
         return port
 
 
-class TestPort():
+class TestPort:
     def __init__(self, test):
         self.test = test
 
@@ -65,7 +65,6 @@ class TestManagerClass(BaseManager):
 
 
 class TestBaseManager(unittest.TestCase):
-
     @defer.inlineCallbacks
     def setUp(self):
         self.manager = TestManagerClass('test_base_manager')
@@ -82,16 +81,18 @@ class TestBaseManager(unittest.TestCase):
     @defer.inlineCallbacks
     def test_repr(self):
         reg = yield self.manager.register('tcp:port', 'x', 'y', 'pf')
-        self.assertEqual(repr(self.manager.dispatchers['tcp:port']),
-                         '<base.BaseDispatcher for x on tcp:port>')
+        self.assertEqual(
+            repr(self.manager.dispatchers['tcp:port']), '<base.BaseDispatcher for x on tcp:port>'
+        )
         self.assertEqual(repr(reg), '<base.Registration for x on tcp:port>')
 
     @defer.inlineCallbacks
     def test_register_before_start_service(self):
         yield self.manager.register('tcp:port', 'user', 'pass', 'pf')
 
-        self.assert_equal_registration(self.manager.dispatchers,
-                                       {'tcp:port': {'user': ('pass', 'pf')}})
+        self.assert_equal_registration(
+            self.manager.dispatchers, {'tcp:port': {'user': ('pass', 'pf')}}
+        )
 
         disp = self.manager.dispatchers['tcp:port']
         self.assert_start_stop_listening_counts(disp, 0, 0)
@@ -109,8 +110,9 @@ class TestBaseManager(unittest.TestCase):
         yield self.manager.register('tcp:port', 'user', 'pass', 'pf')
 
         # one registration is ok
-        self.assert_equal_registration(self.manager.dispatchers,
-                                       {'tcp:port': {'user': ('pass', 'pf')}})
+        self.assert_equal_registration(
+            self.manager.dispatchers, {'tcp:port': {'user': ('pass', 'pf')}}
+        )
         self.assertEqual(len(self.manager.services), 1)
 
         disp = self.manager.dispatchers['tcp:port']
@@ -127,8 +129,9 @@ class TestBaseManager(unittest.TestCase):
     def test_register_unregister_register(self):
         yield self.manager.startService()
         reg = yield self.manager.register('tcp:port', 'user', 'pass', 'pf')
-        self.assert_equal_registration(self.manager.dispatchers,
-                                       {'tcp:port': {'user': ('pass', 'pf')}})
+        self.assert_equal_registration(
+            self.manager.dispatchers, {'tcp:port': {'user': ('pass', 'pf')}}
+        )
 
         disp = self.manager.dispatchers['tcp:port']
         self.assert_start_stop_listening_counts(disp, 1, 0)
@@ -139,8 +142,9 @@ class TestBaseManager(unittest.TestCase):
         # allow registering same user again
         yield self.manager.register('tcp:port', 'user', 'pass', 'pf')
 
-        self.assert_equal_registration(self.manager.dispatchers,
-                                       {'tcp:port': {'user': ('pass', 'pf')}})
+        self.assert_equal_registration(
+            self.manager.dispatchers, {'tcp:port': {'user': ('pass', 'pf')}}
+        )
 
         yield self.manager.stopService()
         self.assert_start_stop_listening_counts(disp, 1, 1)
@@ -181,26 +185,29 @@ class TestBaseManager(unittest.TestCase):
         disp3 = self.manager.dispatchers['tcp:port3']
         self.assert_start_stop_listening_counts(disp3, 1, 0)
 
-        self.assert_equal_registration(self.manager.dispatchers, {
-            'tcp:port1': {'user': ('pass', 'pf')},
-            'tcp:port2': {'user': ('pass', 'pf')},
-            'tcp:port3': {'user': ('pass', 'pf')}
-        })
+        self.assert_equal_registration(
+            self.manager.dispatchers,
+            {
+                'tcp:port1': {'user': ('pass', 'pf')},
+                'tcp:port2': {'user': ('pass', 'pf')},
+                'tcp:port3': {'user': ('pass', 'pf')},
+            },
+        )
         self.assertEqual(len(self.manager.services), 3)
 
         yield reg1.unregister()
-        self.assert_equal_registration(self.manager.dispatchers, {
-            'tcp:port2': {'user': ('pass', 'pf')},
-            'tcp:port3': {'user': ('pass', 'pf')}
-        })
+        self.assert_equal_registration(
+            self.manager.dispatchers,
+            {'tcp:port2': {'user': ('pass', 'pf')}, 'tcp:port3': {'user': ('pass', 'pf')}},
+        )
         self.assertEqual(reg1.username, None)
         self.assertEqual(len(self.manager.services), 2)
         self.assert_start_stop_listening_counts(disp1, 1, 1)
 
         yield reg2.unregister()
-        self.assert_equal_registration(self.manager.dispatchers, {
-            'tcp:port3': {'user': ('pass', 'pf')}
-        })
+        self.assert_equal_registration(
+            self.manager.dispatchers, {'tcp:port3': {'user': ('pass', 'pf')}}
+        )
         self.assertEqual(reg2.username, None)
         self.assertEqual(len(self.manager.services), 1)
         self.assert_start_stop_listening_counts(disp2, 1, 1)
@@ -226,31 +233,30 @@ class TestBaseManager(unittest.TestCase):
         disp = self.manager.dispatchers['tcp:port']
 
         self.assertEqual(len(self.manager.services), 1)
-        self.assert_equal_registration(self.manager.dispatchers, {
-            'tcp:port': {
-                'user1': ('pass1', 'pf1'),
-                'user2': ('pass2', 'pf2'),
-                'user3': ('pass3', 'pf3')
-            }
-        })
+        self.assert_equal_registration(
+            self.manager.dispatchers,
+            {
+                'tcp:port': {
+                    'user1': ('pass1', 'pf1'),
+                    'user2': ('pass2', 'pf2'),
+                    'user3': ('pass3', 'pf3'),
+                }
+            },
+        )
         self.assertEqual(len(self.manager.services), 1)
 
         yield reg1.unregister()
-        self.assert_equal_registration(self.manager.dispatchers, {
-            'tcp:port': {
-                'user2': ('pass2', 'pf2'),
-                'user3': ('pass3', 'pf3')
-            }
-        })
+        self.assert_equal_registration(
+            self.manager.dispatchers,
+            {'tcp:port': {'user2': ('pass2', 'pf2'), 'user3': ('pass3', 'pf3')}},
+        )
         self.assertEqual(reg1.username, None)
         self.assertEqual(len(self.manager.services), 1)
 
         yield reg2.unregister()
-        self.assert_equal_registration(self.manager.dispatchers, {
-            'tcp:port': {
-                'user3': ('pass3', 'pf3')
-            }
-        })
+        self.assert_equal_registration(
+            self.manager.dispatchers, {'tcp:port': {'user3': ('pass3', 'pf3')}}
+        )
         self.assertEqual(reg2.username, None)
         self.assertEqual(len(self.manager.services), 1)
 
