@@ -1017,11 +1017,11 @@ def FakeRequestMR(content):
 
 
 class TestChangeHookConfiguredWithGitChange(unittest.TestCase, TestReactorMixin):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.changeHook = change_hook.ChangeHookResource(
-            dialects={'gitlab': True}, master=fakeMasterForHooks(self)
-        )
+        master = yield fakeMasterForHooks(self)
+        self.changeHook = change_hook.ChangeHookResource(dialects={'gitlab': True}, master=master)
 
     def check_changes_tag_event(self, r, project='', codebase=None):
         self.assertEqual(len(self.changeHook.master.data.updates.changesAdded), 2)
@@ -1246,9 +1246,10 @@ class TestChangeHookConfiguredWithGitChange(unittest.TestCase, TestReactorMixin)
 class TestChangeHookConfiguredWithSecret(unittest.TestCase, TestReactorMixin):
     _SECRET = 'thesecret'
 
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
-        self.master = fakeMasterForHooks(self)
+        self.master = yield fakeMasterForHooks(self)
 
         fakeStorageService = FakeSecretStorage()
         fakeStorageService.reconfigService(secretdict={"secret_key": self._SECRET})
