@@ -62,12 +62,12 @@ gitJsonPayload = b"""
 
 
 class TestChangeHookConfiguredWithGitChange(unittest.TestCase, TestReactorMixin):
+    @defer.inlineCallbacks
     def setUp(self):
         self.setup_test_reactor()
         dialects = {'gitorious': True}
-        self.changeHook = change_hook.ChangeHookResource(
-            dialects=dialects, master=fakeMasterForHooks(self)
-        )
+        master = yield fakeMasterForHooks(self)
+        self.changeHook = change_hook.ChangeHookResource(dialects=dialects, master=master)
 
     # Test 'base' hook with attributes. We should get a json string
     # representing a Change object as a dictionary. All values show be set.
