@@ -13,19 +13,14 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 # this is here for compatibility
-from collections import defaultdict
-
-assert defaultdict
+from collections import defaultdict  # noqa: F401
 
 
 class KeyedSets:
-
     def __init__(self):
-        self.d = dict()
+        self.d = {}
 
     def add(self, key, value):
         if key not in self.d:
