@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 
 def matchTuple(routingKey, filter):
     if len(filter) != len(routingKey):
