@@ -13,12 +13,15 @@
 #
 # Portions Copyright Buildbot Team Members
 # Portions Copyright Canonical Ltd. 2009
+from __future__ import annotations
 
 import enum
 import random
 import string
+from typing import Any
 
 from twisted.internet import defer
+from twisted.internet.base import DelayedCall
 from twisted.python import failure
 from twisted.python import log
 from zope.interface import implementer
@@ -28,7 +31,6 @@ from buildbot.interfaces import ILatentWorker
 from buildbot.interfaces import LatentWorkerFailedToSubstantiate
 from buildbot.interfaces import LatentWorkerSubstantiatiationCancelled
 from buildbot.util import Notifier
-from buildbot.warnings import warn_deprecated
 from buildbot.worker.base import AbstractWorker
 
 
@@ -69,7 +71,6 @@ class States(enum.Enum):
 
 @implementer(ILatentWorker)
 class AbstractLatentWorker(AbstractWorker):
-
     """A worker that will start up a worker instance when needed.
 
     To use, subclass and implement start_instance and stop_instance.
@@ -82,8 +83,8 @@ class AbstractLatentWorker(AbstractWorker):
     See ec2.py for a concrete example.
     """
 
-    substantiation_build = None
-    build_wait_timer = None
+    substantiation_build: Any = None
+    build_wait_timer: DelayedCall | None = None
     start_missing_on_startup = False
 
     # override if the latent worker may connect without substantiate. Most
@@ -114,7 +115,7 @@ class AbstractLatentWorker(AbstractWorker):
 
     state = States.NOT_SUBSTANTIATED
 
-    '''
+    """
     state transitions:
 
     substantiate(): either of
@@ -156,24 +157,22 @@ class AbstractLatentWorker(AbstractWorker):
 
     stopService():
         NOT_SUBSTANTIATED -> SHUT_DOWN
-    '''
+    """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
-        self._substantiation_notifier = Notifier()
+        self._substantiation_notifier: Notifier[bool] = Notifier()
         self._start_stop_lock = defer.DeferredLock()
         self._check_instance_timer = None
 
-    def checkConfig(self, name, password,
-                    build_wait_timeout=60 * 10,
-                    check_instance_interval=10,
-                    **kwargs):
+    def checkConfig(
+        self, name, password, build_wait_timeout=60 * 10, check_instance_interval=10, **kwargs
+    ):
         super().checkConfig(name, password, **kwargs)
 
-    def reconfigService(self, name, password,
-                        build_wait_timeout=60 * 10,
-                        check_instance_interval=10,
-                        **kwargs):
+    def reconfigService(
+        self, name, password, build_wait_timeout=60 * 10, check_instance_interval=10, **kwargs
+    ):
         self.build_wait_timeout = build_wait_timeout
         self.check_instance_interval = check_instance_interval
         return super().reconfigService(name, password, **kwargs)
@@ -195,46 +194,53 @@ class AbstractLatentWorker(AbstractWorker):
                 return self.password
 
             # pragma: no cover
-            log.err('{}: could not reuse password of substantiated worker (password == None)',
-                    repr(self))
+            log.err(
+                '{}: could not reuse password of substantiated worker (password == None)',
+                repr(self),
+            )
 
         return self._generate_random_password()
 
     @property
     def building(self):
         # A LatentWorkerForBuilder will only be busy if it is building.
-        return {wfb for wfb in self.workerforbuilders.values()
-                if wfb.isBusy()}
+        return {wfb for wfb in self.workerforbuilders.values() if wfb.isBusy()}
 
     def failed_to_start(self, instance_id, instance_state):
-        log.msg(f'{self.__class__.__name__} {self.workername} failed to start instance '
-                f'{instance_id} ({instance_state})')
+        log.msg(
+            f'{self.__class__.__name__} {self.workername} failed to start instance '
+            f'{instance_id} ({instance_state})'
+        )
         raise LatentWorkerFailedToSubstantiate(instance_id, instance_state)
 
     def _log_start_stop_locked(self, action_str):
         if self._start_stop_lock.locked:
-            log.msg(('while {} worker {}: waiting until previous ' +
-                     'start_instance/stop_instance finishes').format(action_str, self))
+            log.msg(
+                (
+                    'while {} worker {}: waiting until previous '
+                    + 'start_instance/stop_instance finishes'
+                ).format(action_str, self)
+            )
 
-    def start_instance(self, build):
+    def start_instance(self, build) -> defer.Deferred[bool]:
         # responsible for starting instance that will try to connect with this
         # master.  Should return deferred with either True (instance started)
         # or False (instance not started, so don't run a build here).  Problems
         # should use an errback.
         raise NotImplementedError
 
-    def stop_instance(self, fast=False):
+    def stop_instance(self, fast=False) -> defer.Deferred[bool]:
         # responsible for shutting down instance.
         raise NotImplementedError
 
-    def check_instance(self):
+    def check_instance(self) -> tuple[bool, str]:
         return (True, "")
 
     @property
-    def substantiated(self):
+    def substantiated(self) -> bool:
         return self.state == States.SUBSTANTIATED and self.conn is not None
 
-    def substantiate(self, wfb, build):
+    def substantiate(self, wfb: Any, build: Any) -> defer.Deferred[bool]:
         log.msg(f"substantiating worker {wfb}")
 
         if self.state == States.SHUT_DOWN:
@@ -243,9 +249,11 @@ class AbstractLatentWorker(AbstractWorker):
         if self.state == States.SUBSTANTIATED and self.conn is not None:
             return defer.succeed(True)
 
-        if self.state in [States.SUBSTANTIATING,
-                          States.SUBSTANTIATING_STARTING,
-                          States.INSUBSTANTIATING_SUBSTANTIATING]:
+        if self.state in [
+            States.SUBSTANTIATING,
+            States.SUBSTANTIATING_STARTING,
+            States.INSUBSTANTIATING_SUBSTANTIATING,
+        ]:
             return self._substantiation_notifier.wait()
 
         self.startMissingTimer()
@@ -261,8 +269,7 @@ class AbstractLatentWorker(AbstractWorker):
             d_ins.addErrback(log.err, 'while insubstantiating')
             return d
 
-        assert self.state in [States.NOT_SUBSTANTIATED,
-                              States.INSUBSTANTIATING]
+        assert self.state in [States.NOT_SUBSTANTIATED, States.INSUBSTANTIATING]
 
         if self.state == States.NOT_SUBSTANTIATED:
             self.state = States.SUBSTANTIATING
@@ -279,8 +286,7 @@ class AbstractLatentWorker(AbstractWorker):
             # if build_wait_timeout is negative we don't ever disconnect the
             # worker ourselves, so we don't need to wait for it to attach
             # to declare it as substantiated.
-            dont_wait_to_attach = \
-                self.build_wait_timeout < 0 and self.conn is not None
+            dont_wait_to_attach = self.build_wait_timeout < 0 and self.conn is not None
 
             start_success = True
             if ILatentMachine.providedBy(self.machine):
@@ -302,9 +308,11 @@ class AbstractLatentWorker(AbstractWorker):
                 msg = "Worker does not want to substantiate at this time"
                 raise LatentWorkerFailedToSubstantiate(self.name, msg)
 
-            if dont_wait_to_attach and \
-                    self.state == States.SUBSTANTIATING_STARTING and \
-                    self.conn is not None:
+            if (
+                dont_wait_to_attach
+                and self.state == States.SUBSTANTIATING_STARTING
+                and self.conn is not None
+            ):
                 log.msg(f"Worker {self.name} substantiated (already attached)")
                 self.state = States.SUBSTANTIATED
                 self._fireSubstantiationNotifier(True)
@@ -316,7 +324,7 @@ class AbstractLatentWorker(AbstractWorker):
             self._substantiation_failed(failure.Failure(e))
             # swallow the failure as it is notified
 
-    def _fireSubstantiationNotifier(self, result):
+    def _fireSubstantiationNotifier(self, result: bool | failure.Failure) -> None:
         if not self._substantiation_notifier:
             log.msg(f"No substantiation deferred for {self.name}")
             return
@@ -330,10 +338,11 @@ class AbstractLatentWorker(AbstractWorker):
     def attached(self, conn):
         self._stop_check_instance_timer()
 
-        if self.state != States.SUBSTANTIATING_STARTING and \
-                self.build_wait_timeout >= 0:
-            msg = (f'Worker {self.name} received connection while not trying to substantiate.'
-                   'Disconnecting.')
+        if self.state != States.SUBSTANTIATING_STARTING and self.build_wait_timeout >= 0:
+            msg = (
+                f'Worker {self.name} received connection while not trying to substantiate.'
+                'Disconnecting.'
+            )
             log.msg(msg)
             self._deferwaiter.add(self._disconnect(conn))
             raise RuntimeError(msg)
@@ -352,8 +361,7 @@ class AbstractLatentWorker(AbstractWorker):
         # without master seeing this condition.
         #
         # When build_wait_timeout is not negative, we throw an error (see above)
-        if self.state in [States.SUBSTANTIATING,
-                          States.SUBSTANTIATING_STARTING]:
+        if self.state in [States.SUBSTANTIATING, States.SUBSTANTIATING_STARTING]:
             self.state = States.SUBSTANTIATED
         self._fireSubstantiationNotifier(True)
 
@@ -365,9 +373,8 @@ class AbstractLatentWorker(AbstractWorker):
         self.missing_timer = None
         return self._substantiation_failed(defer.TimeoutError())
 
-    def _substantiation_failed(self, failure):
-        if self.state in [States.SUBSTANTIATING,
-                          States.SUBSTANTIATING_STARTING]:
+    def _substantiation_failed(self, failure: failure.Failure) -> defer.Deferred | None:
+        if self.state in [States.SUBSTANTIATING, States.SUBSTANTIATING_STARTING]:
             self._fireSubstantiationNotifier(failure)
 
         d = self.insubstantiate()
@@ -382,7 +389,7 @@ class AbstractLatentWorker(AbstractWorker):
             workerid=self.workerid,
             masterid=self.master.masterid,
             last_connection="Latent worker never connected",
-            notify=self.notify_on_missing
+            notify=self.notify_on_missing,
         )
 
     def canStartBuild(self):
@@ -428,7 +435,8 @@ class AbstractLatentWorker(AbstractWorker):
         if self.build_wait_timeout <= 0:
             return
         self.build_wait_timer = self.master.reactor.callLater(
-            self.build_wait_timeout, self._soft_disconnect)
+            self.build_wait_timeout, self._soft_disconnect
+        )
 
     def _stop_check_instance_timer(self):
         if self._check_instance_timer is not None:
@@ -463,15 +471,8 @@ class AbstractLatentWorker(AbstractWorker):
             yield self._start_stop_lock.acquire()
             message = "latent worker crashed before connecting"
             try:
-                value = yield self.check_instance()
-                if isinstance(value, bool):
-                    is_good = value
-                    warn_deprecated("3.10.0", "check_instance() must return a two element tuple "
-                                    "with second element containing error message, if any")
-
-                else:
-                    is_good, message_append = value
-                    message += ": " + message_append
+                is_good, message_append = yield self.check_instance()
+                message += ": " + message_append
             except Exception as e:
                 message += ": " + str(e)
                 is_good = False
@@ -501,14 +502,17 @@ class AbstractLatentWorker(AbstractWorker):
             self.state = States.INSUBSTANTIATING
             self.substantiation_build = None
             self._fireSubstantiationNotifier(
-                failure.Failure(LatentWorkerSubstantiatiationCancelled()))
+                failure.Failure(LatentWorkerSubstantiatiationCancelled())
+            )
 
         try:
             self._log_start_stop_locked('insubstantiating')
             yield self._start_stop_lock.acquire()
 
-            assert self.state not in [States.INSUBSTANTIATING,
-                                      States.INSUBSTANTIATING_SUBSTANTIATING]
+            assert self.state not in [
+                States.INSUBSTANTIATING,
+                States.INSUBSTANTIATING_SUBSTANTIATING,
+            ]
 
             if self.state in [States.NOT_SUBSTANTIATED, States.SHUT_DOWN]:
                 return
@@ -523,7 +527,8 @@ class AbstractLatentWorker(AbstractWorker):
 
             if prev_state in [States.SUBSTANTIATING, States.SUBSTANTIATING_STARTING]:
                 self._fireSubstantiationNotifier(
-                    failure.Failure(LatentWorkerSubstantiatiationCancelled()))
+                    failure.Failure(LatentWorkerSubstantiatiationCancelled())
+                )
 
             self._clearBuildWaitTimer()
             self._stop_check_instance_timer()
@@ -538,11 +543,11 @@ class AbstractLatentWorker(AbstractWorker):
                     # reliability to the backend driver
                     log.err(e, "while insubstantiating")
 
-            assert self.state in [States.INSUBSTANTIATING,
-                                  States.INSUBSTANTIATING_SUBSTANTIATING]
+            assert self.state in [States.INSUBSTANTIATING, States.INSUBSTANTIATING_SUBSTANTIATING]
 
             if self.state == States.INSUBSTANTIATING_SUBSTANTIATING:
-                build, self.substantiation_build = self.substantiation_build, None
+                build = self.substantiation_build
+                self.substantiation_build = None
                 self.state = States.SUBSTANTIATING
                 self._substantiate(build)
             else:  # self.state == States.INSUBSTANTIATING:
@@ -565,10 +570,14 @@ class AbstractLatentWorker(AbstractWorker):
 
         # we add the Deferreds to DeferWaiter because we don't wait for a Deferred if
         # the other Deferred errbacks
-        yield defer.DeferredList([
-            self._deferwaiter.add(super().disconnect()),
-            self._deferwaiter.add(self.insubstantiate(fast))
-        ], consumeErrors=True, fireOnOneErrback=True)
+        yield defer.DeferredList(
+            [
+                self._deferwaiter.add(super().disconnect()),
+                self._deferwaiter.add(self.insubstantiate(fast)),
+            ],
+            consumeErrors=True,
+            fireOnOneErrback=True,
+        )
 
     def disconnect(self):
         self._deferwaiter.add(self._soft_disconnect())
@@ -581,16 +590,20 @@ class AbstractLatentWorker(AbstractWorker):
         # stops the service. Waits for any pending substantiations, insubstantiations or builds
         # that are running or about to start to complete.
         while self.state not in [States.NOT_SUBSTANTIATED, States.SHUT_DOWN]:
-            if self.state in [States.INSUBSTANTIATING,
-                              States.INSUBSTANTIATING_SUBSTANTIATING,
-                              States.SUBSTANTIATING,
-                              States.SUBSTANTIATING_STARTING]:
+            if self.state in [
+                States.INSUBSTANTIATING,
+                States.INSUBSTANTIATING_SUBSTANTIATING,
+                States.SUBSTANTIATING,
+                States.SUBSTANTIATING_STARTING,
+            ]:
                 self._log_start_stop_locked('stopService')
                 yield self._start_stop_lock.acquire()
                 self._start_stop_lock.release()
 
-            if self.conn is not None or self.state in [States.SUBSTANTIATED,
-                                                       States.SUBSTANTIATING_STARTING]:
+            if self.conn is not None or self.state in [
+                States.SUBSTANTIATED,
+                States.SUBSTANTIATING_STARTING,
+            ]:
                 yield self._soft_disconnect(stopping_service=True)
 
             yield self._deferwaiter.wait()
@@ -623,12 +636,11 @@ class LocalLatentWorker(AbstractLatentWorker):
     A worker that can be suspended by shutting down or suspending the hardware
     it runs on. It is intended to be used with LatentMachines.
     """
+
     starts_without_substantiate = True
 
     def checkConfig(self, name, password, **kwargs):
-        super().checkConfig(self, name, password, build_wait_timeout=-1,
-                            **kwargs)
+        super().checkConfig(self, name, password, build_wait_timeout=-1, **kwargs)
 
     def reconfigService(self, name, password, **kwargs):
-        return super().reconfigService(name, password, build_wait_timeout=-1,
-                                       **kwargs)
+        return super().reconfigService(name, password, build_wait_timeout=-1, **kwargs)
