@@ -18,6 +18,8 @@ import re
 from abc import ABCMeta
 from abc import abstractmethod
 
+import twisted
+from packaging.version import parse as parse_version
 from twisted.cred.checkers import FilePasswordDB
 from twisted.cred.checkers import ICredentialsChecker
 from twisted.cred.checkers import InMemoryUsernamePasswordDatabaseDontUse
@@ -40,7 +42,6 @@ from buildbot.www import resource
 
 
 class AuthRootResource(resource.Resource):
-
     def getChild(self, path, request):
         # return dynamically generated resources
         if path == b'login':
@@ -51,7 +52,6 @@ class AuthRootResource(resource.Resource):
 
 
 class AuthBase(config.ConfiguredMixin):
-
     def __init__(self, userInfoProvider=None):
         self.userInfoProvider = userInfoProvider
 
@@ -87,7 +87,6 @@ class UserInfoProviderBase(config.ConfiguredMixin):
 
 
 class LoginResource(resource.Resource):
-
     def render_GET(self, request):
         return self.asyncRenderHelper(request, self.renderLogin)
 
@@ -102,7 +101,7 @@ class NoAuth(AuthBase):
 
 class RemoteUserAuth(AuthBase):
     header = b"REMOTE_USER"
-    headerRegex = re.compile(br"(?P<username>[^ @]+)@(?P<realm>[^ @]+)")
+    headerRegex = re.compile(rb"(?P<username>[^ @]+)@(?P<realm>[^ @]+)")
 
     def __init__(self, header=None, headerRegex=None, **kwargs):
         super().__init__(**kwargs)
@@ -113,6 +112,17 @@ class RemoteUserAuth(AuthBase):
         if headerRegex is not None:
             self.headerRegex = re.compile(unicode2bytes(headerRegex))
 
+    def getLoginResource(self):
+        current_version = parse_version(twisted.__version__)
+        if current_version < parse_version("22.10.0"):
+            from twisted.web.resource import ForbiddenResource
+
+            return ForbiddenResource(message="URL is not supported for authentication")
+
+        from twisted.web.pages import forbidden
+
+        return forbidden(message="URL is not supported for authentication")
+
     @defer.inlineCallbacks
     def maybeAutoLogin(self, request):
         header = request.getHeader(self.header)
@@ -121,8 +131,12 @@ class RemoteUserAuth(AuthBase):
             raise Error(403, msg)
         res = self.headerRegex.match(header)
         if res is None:
-            msg = b'http header does not match regex! "' + header + b'" not matching ' + \
-                    self.headerRegex.pattern
+            msg = (
+                b'http header does not match regex! "'
+                + header
+                + b'" not matching '
+                + self.headerRegex.pattern
+            )
             raise Error(403, msg)
         session = request.getSession()
         user_info = {k: bytes2unicode(v) for k, v in res.groupdict().items()}
@@ -133,21 +147,17 @@ class RemoteUserAuth(AuthBase):
 
 @implementer(IRealm)
 class AuthRealm:
-
     def __init__(self, master, auth):
         self.auth = auth
         self.master = master
 
     def requestAvatar(self, avatarId, mind, *interfaces):
         if IResource in interfaces:
-            return (IResource,
-                    PreAuthenticatedLoginResource(self.master, avatarId),
-                    lambda: None)
+            return (IResource, PreAuthenticatedLoginResource(self.master, avatarId), lambda: None)
         raise NotImplementedError()
 
 
 class TwistedICredAuthBase(AuthBase):
-
     def __init__(self, credentialFactories, checkers, **kwargs):
         super().__init__(**kwargs)
         if self.userInfoProvider is None:
@@ -157,30 +167,30 @@ class TwistedICredAuthBase(AuthBase):
 
     def getLoginResource(self):
         return HTTPAuthSessionWrapper(
-            Portal(AuthRealm(self.master, self), self.checkers),
-            self.credentialFactories)
+            Portal(AuthRealm(self.master, self), self.checkers), self.credentialFactories
+        )
 
 
 class HTPasswdAuth(TwistedICredAuthBase):
-
     def __init__(self, passwdFile, **kwargs):
-        super().__init__([DigestCredentialFactory(b"MD5", b"buildbot"),
-             BasicCredentialFactory(b"buildbot")],
+        super().__init__(
+            [DigestCredentialFactory(b"MD5", b"buildbot"), BasicCredentialFactory(b"buildbot")],
             [FilePasswordDB(passwdFile)],
-            **kwargs)
+            **kwargs,
+        )
 
 
 class UserPasswordAuth(TwistedICredAuthBase):
-
     def __init__(self, users, **kwargs):
         if isinstance(users, dict):
             users = {user: unicode2bytes(pw) for user, pw in users.items()}
         elif isinstance(users, list):
             users = [(user, unicode2bytes(pw)) for user, pw in users]
-        super().__init__([DigestCredentialFactory(b"MD5", b"buildbot"),
-             BasicCredentialFactory(b"buildbot")],
+        super().__init__(
+            [DigestCredentialFactory(b"MD5", b"buildbot"), BasicCredentialFactory(b"buildbot")],
             [InMemoryUsernamePasswordDatabaseDontUse(**dict(users))],
-            **kwargs)
+            **kwargs,
+        )
 
 
 @implementer(ICredentialsChecker)
@@ -189,9 +199,7 @@ class CustomAuth(TwistedICredAuthBase):
     credentialInterfaces = [IUsernamePassword]
 
     def __init__(self, **kwargs):
-        super().__init__([BasicCredentialFactory(b"buildbot")],
-            [self],
-            **kwargs)
+        super().__init__([BasicCredentialFactory(b"buildbot")], [self], **kwargs)
 
     def requestAvatarId(self, cred):
         if self.check_credentials(cred.username, cred.password):
@@ -199,7 +207,7 @@ class CustomAuth(TwistedICredAuthBase):
         return defer.fail(UnauthorizedLogin())
 
     @abstractmethod
-    def check_credentials(username, password):  # noqa pylint: disable=no-self-argument
+    def check_credentials(self, username, password):
         return False
 
 
@@ -220,13 +228,12 @@ class PreAuthenticatedLoginResource(LoginResource):
     @defer.inlineCallbacks
     def renderLogin(self, request):
         session = request.getSession()
-        session.user_info = dict(username=bytes2unicode(self.username))
+        session.user_info = {"username": bytes2unicode(self.username)}
         yield self.master.www.auth.updateUserInfo(request)
         raise _redirect(self.master, request)
 
 
 class LogoutResource(resource.Resource):
-
     def render_GET(self, request):
         session = request.getSession()
         session.expire()
