@@ -43,18 +43,23 @@ except ImportError:
 class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
     name = 'ldap'
 
-    def __init__(self, uri, bindUser, bindPw,
-                 accountBase,
-                 accountPattern,
-                 accountFullName,
-                 accountEmail,
-                 groupBase=None,
-                 groupMemberPattern=None,
-                 groupName=None,
-                 avatarPattern=None,
-                 avatarData=None,
-                 accountExtraFields=None,
-                 tls=None):
+    def __init__(
+        self,
+        uri,
+        bindUser,
+        bindPw,
+        accountBase,
+        accountPattern,
+        accountFullName,
+        accountEmail,
+        groupBase=None,
+        groupMemberPattern=None,
+        groupName=None,
+        avatarPattern=None,
+        avatarData=None,
+        accountExtraFields=None,
+        tls=None,
+    ):
         # Throw import error now that this is being used
         if not ldap3:
             importlib.import_module('ldap3')
@@ -65,13 +70,13 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
         self.accountEmail = accountEmail
         self.accountPattern = accountPattern
         self.accountFullName = accountFullName
-        group_params = [p for p in (groupName, groupMemberPattern, groupBase)
-                        if p is not None]
+        group_params = [p for p in (groupName, groupMemberPattern, groupBase) if p is not None]
         if len(group_params) not in (0, 3):
             raise ValueError(
                 "Incomplete LDAP groups configuration. "
                 "To use Ldap groups, you need to specify the three "
-                "parameters (groupName, groupMemberPattern and groupBase). ")
+                "parameters (groupName, groupMemberPattern and groupBase). "
+            )
 
         self.groupName = groupName
         self.groupMemberPattern = groupMemberPattern
@@ -88,16 +93,26 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
         server = urlparse(self.uri)
         netloc = server.netloc.split(":")
         # define the server and the connection
-        s = ldap3.Server(netloc[0], port=int(netloc[1]), use_ssl=server.scheme == 'ldaps',
-                         get_info=ldap3.ALL, tls=self.tls)
+        s = ldap3.Server(
+            netloc[0],
+            port=int(netloc[1]),
+            use_ssl=server.scheme == 'ldaps',
+            get_info=ldap3.ALL,
+            tls=self.tls,
+        )
 
         auth = ldap3.SIMPLE
         if self.bindUser is None and self.bindPw is None:
             auth = ldap3.ANONYMOUS
 
-        c = ldap3.Connection(s, auto_bind=True, client_strategy=ldap3.SYNC,
-                             user=self.bindUser, password=self.bindPw,
-                             authentication=auth)
+        c = ldap3.Connection(
+            s,
+            auto_bind=True,
+            client_strategy=ldap3.SYNC,
+            user=self.bindUser,
+            password=self.bindPw,
+            authentication=auth,
+        )
         return c
 
     def search(self, c, base, filterstr='f', attributes=None):
@@ -111,10 +126,12 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
             c = self.connectLdap()
             infos = {'username': username}
             pattern = self.accountPattern % {"username": username}
-            res = self.search(c, self.accountBase, pattern,
-                              attributes=[
-                                  self.accountEmail, self.accountFullName] +
-                              self.accountExtraFields)
+            res = self.search(
+                c,
+                self.accountBase,
+                pattern,
+                attributes=[self.accountEmail, self.accountFullName, *self.accountExtraFields],
+            )
             if len(res) != 1:
                 raise KeyError(f"ldap search \"{pattern}\" returned {len(res)} results")
             dn, ldap_infos = res[0]['dn'], res[0]['attributes']
@@ -136,12 +153,13 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
 
             # needs double quoting of backslashing
             pattern = self.groupMemberPattern % {"dn": ldap3.utils.conv.escape_filter_chars(dn)}
-            res = self.search(c, self.groupBase, pattern,
-                              attributes=[self.groupName])
-            infos['groups'] = flatten([group_infos['attributes'][self.groupName]
-                                      for group_infos in res])
+            res = self.search(c, self.groupBase, pattern, attributes=[self.groupName])
+            infos['groups'] = flatten([
+                group_infos['attributes'][self.groupName] for group_infos in res
+            ])
 
             return infos
+
         return threads.deferToThread(thd)
 
     def findAvatarMime(self, data):
@@ -169,13 +187,13 @@ class LdapUserInfo(avatar.AvatarBase, auth.UserInfoProviderBase):
                 pattern = self.avatarPattern % {"email": email}
             else:
                 return None
-            res = self.search(c, self.accountBase, pattern,
-                              attributes=[self.avatarData])
+            res = self.search(c, self.accountBase, pattern, attributes=[self.avatarData])
             if not res:
                 return None
             ldap_infos = res[0]['raw_attributes']
-            if self.avatarData in ldap_infos and ldap_infos[self.avatarData]:
+            if ldap_infos.get(self.avatarData):
                 data = ldap_infos[self.avatarData][0]
                 return self.findAvatarMime(data)
             return None
+
         return threads.deferToThread(thd)
