@@ -66,7 +66,7 @@ class WsProtocol(WebSocketServerProtocol):
         presence of _id or type attributes.
         """
         if self.debug:
-            log.msg("FRAME {}".format(frame))
+            log.msg(f"FRAME {frame}")
 
         frame = json.loads(bytes2unicode(frame))
         _id = frame.get("_id")
@@ -92,35 +92,26 @@ class WsProtocol(WebSocketServerProtocol):
                 self.is_graphql = False
             elif self.is_graphql:
                 return self.send_error(
-                    error="missing 'type' in websocket frame when"
-                    " already started using graphql",
+                    error="missing 'type' in websocket frame when already started using graphql",
                     code=400,
                     _id=None,
                 )
             self.is_graphql = False
             cmd = frame.pop("cmd", None)
             if cmd is None:
-                return self.send_error(
-                    error="no 'cmd' in websocket frame", code=400, _id=None
-                )
+                return self.send_error(error="no 'cmd' in websocket frame", code=400, _id=None)
             cmdmeth = "cmd_" + cmd
 
         meth = getattr(self, cmdmeth, None)
         if meth is None:
-            return self.send_error(
-                error="no such command type '{}'".format(cmd), code=404, _id=_id
-            )
+            return self.send_error(error=f"no such command type '{cmd}'", code=404, _id=_id)
         try:
             return meth(**frame)
         except TypeError as e:
-            return self.send_error(
-                error="Invalid method argument '{}'".format(str(e)), code=400, _id=_id
-            )
+            return self.send_error(error=f"Invalid method argument '{e!s}'", code=400, _id=_id)
         except Exception as e:
-            log.err(e, "while calling command {}".format(cmdmeth))
-            return self.send_error(
-                error="Internal Error '{}'".format(str(e)), code=500, _id=_id
-            )
+            log.err(e, f"while calling command {cmdmeth}")
+            return self.send_error(error=f"Internal Error '{e!s}'", code=500, _id=_id)
 
     # legacy protocol methods
 
@@ -129,7 +120,7 @@ class WsProtocol(WebSocketServerProtocol):
 
     def parsePath(self, path):
         path = path.split("/")
-        return tuple([str(p) if p != "*" else None for p in path])
+        return tuple(str(p) if p != "*" else None for p in path)
 
     def isPath(self, path):
         if not isinstance(path, str):
@@ -139,9 +130,7 @@ class WsProtocol(WebSocketServerProtocol):
     @defer.inlineCallbacks
     def cmd_startConsuming(self, path, _id):
         if not self.isPath(path):
-            yield self.send_json_message(
-                error="invalid path format '{}'".format(str(path)), code=400, _id=_id
-            )
+            yield self.send_json_message(error=f"invalid path format '{path!s}'", code=400, _id=_id)
             return
 
         # if it's already subscribed, don't leak a subscription
@@ -167,9 +156,7 @@ class WsProtocol(WebSocketServerProtocol):
     @defer.inlineCallbacks
     def cmd_stopConsuming(self, path, _id):
         if not self.isPath(path):
-            yield self.send_json_message(
-                error="invalid path format '{}'".format(str(path)), code=400, _id=_id
-            )
+            yield self.send_json_message(error=f"invalid path format '{path!s}'", code=400, _id=_id)
             return
 
         # only succeed if path has been started
@@ -178,9 +165,7 @@ class WsProtocol(WebSocketServerProtocol):
             yield qref.stopConsuming()
             yield self.ack(_id=_id)
             return
-        yield self.send_json_message(
-            error="path was not consumed '{}'".format(str(path)), code=400, _id=_id
-        )
+        yield self.send_json_message(error=f"path was not consumed '{path!s}'", code=400, _id=_id)
 
     def cmd_ping(self, _id):
         self.send_json_message(msg="pong", code=200, _id=_id)
@@ -214,13 +199,11 @@ class WsProtocol(WebSocketServerProtocol):
         errors = None
         if res.errors:
             errors = [e.formatted for e in res.errors]
-        data = self.to_json(
-            {
-                "type": "data",
-                "payload": {"data": res.data, "errors": errors},
-                "id": sub.id,
-            }
-        )
+        data = self.to_json({
+            "type": "data",
+            "payload": {"data": res.data, "errors": errors},
+            "id": sub.id,
+        })
         cksum = hashlib.blake2b(data).digest()
         if cksum != sub.last_value_chksum:
             sub.last_value_chksum = cksum
@@ -242,9 +225,7 @@ class WsProtocol(WebSocketServerProtocol):
         if id in self.graphql_subs:
             del self.graphql_subs[id]
         else:
-            return self.send_error(
-                error="stopping unknown subscription", code=400, _id=id
-            )
+            return self.send_error(error="stopping unknown subscription", code=400, _id=id)
         if not self.graphql_subs and self.graphql_consumer:
             self.graphql_consumer.stopConsuming()
             self.graphql_consumer = None
