@@ -135,6 +135,7 @@ setup_args = {
         'Programming Language :: Python :: 3.10',
         'Programming Language :: Python :: 3.11',
         'Programming Language :: Python :: 3.12',
+        'Programming Language :: Python :: 3.13',
     ],
     'packages': [
         "buildbot",
@@ -147,6 +148,7 @@ setup_args = {
         "buildbot.config",
         "buildbot.data",
         "buildbot.db",
+        "buildbot.db.compression",
         "buildbot.db.migrations",
         "buildbot.db.migrations.versions",
         "buildbot.db.types",
@@ -295,6 +297,10 @@ setup_args = {
                 [
                     ('buildbot.process.buildstep', ['BuildStep']),
                     ('buildbot.steps.cmake', ['CMake']),
+                    (
+                        'buildbot.steps.configurable',
+                        ['BuildbotTestCiTrigger', 'BuildbotCiSetupSteps'],
+                    ),
                     ('buildbot.steps.cppcheck', ['Cppcheck']),
                     ('buildbot.steps.gitdiffinfo', ['GitDiffInfo']),
                     (
@@ -564,6 +570,10 @@ setup_args = {
                         ],
                     ),
                     ('buildbot.steps.shellsequence', ['ShellArg']),
+                    (
+                        'buildbot.util.git_credential',
+                        ['GitCredentialInputRenderer', 'GitCredentialOptions'],
+                    ),
                     (
                         'buildbot.util.kubeclientservice',
                         [
@@ -642,7 +652,7 @@ py_38 = sys.version_info[0] > 3 or (sys.version_info[0] == 3 and sys.version_inf
 if not py_38:
     raise RuntimeError("Buildbot master requires at least Python-3.8")
 
-twisted_ver = ">= 18.7.0"
+twisted_ver = ">= 22.1.0"
 
 bundle_version = version.split("-")[0]
 
@@ -650,13 +660,14 @@ bundle_version = version.split("-")[0]
 setup_args['install_requires'] = [
     'setuptools >= 8.0',
     'Twisted ' + twisted_ver,
+    'treq >= 20.9',
     'Jinja2 >= 2.1',
     'msgpack >= 0.6.0',
     "croniter >= 1.3.0",
     'importlib-resources >= 5; python_version < "3.9"',
     # required for tests, but Twisted requires this anyway
     'zope.interface >= 4.1.1',
-    'sqlalchemy >= 1.4.0, < 1.5',
+    'sqlalchemy >= 1.4.0',
     'alembic >= 1.6.0',
     'python-dateutil>=1.5',
     "txaio >= 2.2.2",
@@ -695,14 +706,7 @@ if sys.platform != 'win32':
 setup_args['tests_require'] = test_deps
 
 setup_args['extras_require'] = {
-    'test': [
-        'setuptools_trial',
-        'ruff',
-        # spellcheck introduced in version 1.4.0
-        'pylint<1.7.0',
-        'pyenchant',
-    ]
-    + test_deps,
+    'test': ["setuptools_trial", "ruff", *test_deps],
     'bundle': [
         f"buildbot-www=={bundle_version}",
         f"buildbot-worker=={bundle_version}",
@@ -729,6 +733,15 @@ setup_args['extras_require'] = {
         'sphinx-jinja',
         'towncrier',
     ],
+    'brotli': [
+        'Brotli>=1.1.0',
+    ],
+    'zstd': [
+        'zstandard>=0.23.0',
+    ],
+    'configurable': [
+        'evalidate >= 2.0.0',
+    ],
 }
 
 if '--help-commands' in sys.argv or 'trial' in sys.argv or 'test' in sys.argv:
