@@ -21,20 +21,21 @@ from buildbot_worker.test.fake.reactor import NonThreadPool
 from buildbot_worker.test.fake.reactor import TestReactor
 
 
-class TestReactorMixin(object):
-
+class TestReactorMixin:
     """
     Mix this in to get TestReactor as self.reactor which is correctly cleaned up
     at the end
     """
-    def setup_test_reactor(self):
 
+    def setup_test_reactor(self):
         self.patch(threadpool, 'ThreadPool', NonThreadPool)
         self.reactor = TestReactor()
 
         def deferToThread(f, *args, **kwargs):
-            return threads.deferToThreadPool(self.reactor, self.reactor.getThreadPool(),
-                                             f, *args, **kwargs)
+            return threads.deferToThreadPool(
+                self.reactor, self.reactor.getThreadPool(), f, *args, **kwargs
+            )
+
         self.patch(threads, 'deferToThread', deferToThread)
 
         self.addCleanup(self.reactor.stop)
