@@ -34,9 +34,6 @@ class TestRemoveDirectory(CommandTestMixin, unittest.TestCase):
     def setUp(self):
         self.setUpCommand()
 
-    def tearDown(self):
-        self.tearDownCommand()
-
     @defer.inlineCallbacks
     def test_simple_real(self):
         file_path = os.path.join(self.basedir, 'workdir')
@@ -176,9 +173,6 @@ class TestCopyDirectory(CommandTestMixin, unittest.TestCase):
     def setUp(self):
         self.setUpCommand()
 
-    def tearDown(self):
-        self.tearDownCommand()
-
     @defer.inlineCallbacks
     def test_simple(self):
         from_path = os.path.join(self.basedir, 'workdir')
@@ -215,9 +209,6 @@ class TestMakeDirectory(CommandTestMixin, unittest.TestCase):
     def setUp(self):
         self.setUpCommand()
 
-    def tearDown(self):
-        self.tearDownCommand()
-
     @defer.inlineCallbacks
     def test_empty_paths(self):
         self.make_command(fs.MakeDirectory, {'paths': []}, True)
@@ -270,9 +261,6 @@ class TestStatFile(CommandTestMixin, unittest.TestCase):
     def setUp(self):
         self.setUpCommand()
 
-    def tearDown(self):
-        self.tearDownCommand()
-
     @defer.inlineCallbacks
     def test_non_existent(self):
         path = os.path.join(self.basedir, 'no-such-file')
@@ -321,9 +309,6 @@ class TestGlobPath(CommandTestMixin, unittest.TestCase):
     def setUp(self):
         self.setUpCommand()
 
-    def tearDown(self):
-        self.tearDownCommand()
-
     @defer.inlineCallbacks
     def test_non_existent(self):
         self.make_command(fs.GlobPath, {'path': os.path.join(self.basedir, 'no-*-file')}, True)
@@ -358,15 +343,12 @@ class TestGlobPath(CommandTestMixin, unittest.TestCase):
             pass
 
         yield self.run_command()
-        if sys.version_info[:] >= (3, 5):
-            if sys.platform == 'win32':
-                filename = 'test\\testdir\\test.txt'
-            else:
-                filename = 'test/testdir/test.txt'
-
-            self.assertEqual(self.get_updates()[0][1], [os.path.join(self.basedir, filename)])
+        if sys.platform == 'win32':
+            filename = 'test\\testdir\\test.txt'
         else:
-            self.assertEqual(self.get_updates()[0][1], [])
+            filename = 'test/testdir/test.txt'
+
+        self.assertEqual(self.get_updates()[0][1], [os.path.join(self.basedir, filename)])
         self.assertIn(('rc', 0), self.get_updates(), self.protocol_command.show())
 
 
@@ -374,9 +356,6 @@ class TestListDir(CommandTestMixin, unittest.TestCase):
     def setUp(self):
         self.setUpCommand()
 
-    def tearDown(self):
-        self.tearDownCommand()
-
     @defer.inlineCallbacks
     def test_non_existent(self):
         path = os.path.join(self.basedir, 'no-such-dir')
@@ -418,9 +397,6 @@ class TestRemoveFile(CommandTestMixin, unittest.TestCase):
     def setUp(self):
         self.setUpCommand()
 
-    def tearDown(self):
-        self.tearDownCommand()
-
     @defer.inlineCallbacks
     def test_simple(self):
         workdir = os.path.join(self.basedir, 'workdir')
