@@ -15,7 +15,6 @@
 
 import base64
 import os
-import sys
 import time
 
 from parameterized import parameterized
@@ -33,22 +32,19 @@ from buildbot_worker.test.util import command
 try:
     from unittest import mock
 except ImportError:
-    import mock
+    from unittest import mock
 
-if sys.version_info >= (3, 6):
-    import msgpack
+import msgpack
 
-    # pylint: disable=ungrouped-imports
-    from buildbot_worker.msgpack import BuildbotWebSocketClientProtocol
-    from buildbot_worker.msgpack import decode_http_authorization_header
-    from buildbot_worker.msgpack import encode_http_authorization_header
-    from buildbot_worker.pb import BotMsgpack  # pylint: disable=ungrouped-imports
+# pylint: disable=ungrouped-imports
+from buildbot_worker.msgpack import BuildbotWebSocketClientProtocol
+from buildbot_worker.msgpack import decode_http_authorization_header
+from buildbot_worker.msgpack import encode_http_authorization_header
+from buildbot_worker.pb import BotMsgpack
 
 
 class TestHttpAuthorization(unittest.TestCase):
     maxDiff = None
-    if sys.version_info < (3, 6):
-        skip = "Not python 3.6 or newer"
 
     def test_encode(self):
         result = encode_http_authorization_header(b'name', b'pass')
@@ -94,7 +90,7 @@ class TestException(Exception):
     pass
 
 
-class FakeStep(object):
+class FakeStep:
     "A fake master-side BuildStep that records its activities."
 
     def __init__(self):
@@ -121,8 +117,6 @@ class FakeBot(base.BotBase):
 
 class TestBuildbotWebSocketClientProtocol(command.CommandTestMixin, unittest.TestCase):
     maxDiff = None
-    if sys.version_info < (3, 6):
-        skip = "Not python 3"
 
     def setUp(self):
         self.protocol = BuildbotWebSocketClientProtocol()
@@ -206,7 +200,7 @@ class TestBuildbotWebSocketClientProtocol(command.CommandTestMixin, unittest.Tes
         # if msg does not have 'sep_number' or 'op', response sendMessage should not be called
         with mock.patch('twisted.python.log.msg') as mock_log:
             yield self.send_message(msg)
-            mock_log.assert_any_call('Invalid message from master: {}'.format(msg))
+            mock_log.assert_any_call(f'Invalid message from master: {msg}')
 
         self.assert_sent_messages([])
 
@@ -263,9 +257,7 @@ class TestBuildbotWebSocketClientProtocol(command.CommandTestMixin, unittest.Tes
             {
                 'op': 'response',
                 'seq_number': 1,
-                'result': '\'message did not contain obligatory "{0}" key\''.format(
-                    missing_parameter
-                ),
+                'result': f'\'message did not contain obligatory "{missing_parameter}" key\'',
                 'is_exception': True,
             }
         ])
@@ -351,7 +343,7 @@ class TestBuildbotWebSocketClientProtocol(command.CommandTestMixin, unittest.Tes
                 'args': [
                     ['rc', 1],
                     ['elapsed', 0],
-                    ['header', ['mkdir: test_error: {}\n'.format(path), [35], [123.0]]],
+                    ['header', [f'mkdir: test_error: {path}\n', [35], [123.0]]],
                 ],
                 'command_id': '123',
                 'seq_number': 0,
@@ -510,9 +502,7 @@ class TestBuildbotWebSocketClientProtocol(command.CommandTestMixin, unittest.Tes
                 'command_id': '123',
                 'why': 'test_reason',
             })
-            mock_log.assert_any_call(
-                'asked to interrupt current command: {0}'.format('test_reason')
-            )
+            mock_log.assert_any_call('asked to interrupt current command: {}'.format('test_reason'))
             mock_log.assert_any_call(' .. but none was running')
 
         self.protocol.factory.command.doInterrupt.assert_not_called()
