@@ -35,9 +35,7 @@ class TestIsWorkerDir(misc.FileIOMixin, misc.StdoutAssertionsMixin, unittest.Tes
         self.tac_file_path = os.path.join("testdir", "buildbot.tac")
 
     def assertReadErrorMessage(self, strerror):
-        expected_message = "error reading '{0}': {1}\ninvalid worker directory 'testdir'\n".format(
-            self.tac_file_path, strerror
-        )
+        expected_message = f"error reading '{self.tac_file_path}': {strerror}\ninvalid worker directory 'testdir'\n"
         self.assertEqual(
             self.mocked_stdout.getvalue(), expected_message, "unexpected error message on stdout"
         )
@@ -84,7 +82,7 @@ class TestIsWorkerDir(misc.FileIOMixin, misc.StdoutAssertionsMixin, unittest.Tes
         # check that correct error message was printed to stdout
         self.assertEqual(
             self.mocked_stdout.getvalue(),
-            "unexpected content in '{0}'\n".format(self.tac_file_path)
+            f"unexpected content in '{self.tac_file_path}'\n"
             + "invalid worker directory 'testdir'\n",
             "unexpected error message on stdout",
         )
