@@ -13,52 +13,30 @@
 #
 # Copyright Buildbot Team Members
 
-# We cannot use the builtins module here from Python-Future.
-# We need to use the native __builtin__ module on Python 2,
-# and builtins module on Python 3, because we need to override
-# the actual native open method.
-
-from __future__ import absolute_import
-from __future__ import print_function
-from future.utils import PY3
-from future.utils import string_types
-
+import builtins
 import errno
 import os
 import re
 import shutil
 import sys
-from io import BytesIO
 from io import StringIO
+from unittest import mock
 
 from twisted.python import log
 
 from buildbot_worker.scripts import base
 
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
-try:
-    # Python 2
-    import __builtin__ as builtins
-except ImportError:
-    # Python 3
-    import builtins
-
 
 def nl(s):
     """Convert the given string to the native newline format, assuming it is
     already in normal UNIX newline format (\n).  Use this to create the
     appropriate expectation in an assertEqual"""
-    if not isinstance(s, string_types):
+    if not isinstance(s, str):
         return s
     return s.replace('\n', os.linesep)
 
 
-class BasedirMixin(object):
-
+class BasedirMixin:
     """Mix this in and call setUpBasedir and tearDownBasedir to set up
     a clean basedir with a name given in self.basedir."""
 
@@ -72,8 +50,7 @@ class BasedirMixin(object):
             shutil.rmtree(self.basedir)
 
 
-class IsWorkerDirMixin(object):
-
+class IsWorkerDirMixin:
     """
     Mixin for setting up mocked base.isWorkerDir() function
     """
@@ -83,8 +60,7 @@ class IsWorkerDirMixin(object):
         self.patch(base, "isWorkerDir", self.isWorkerDir)
 
 
-class PatcherMixin(object):
-
+class PatcherMixin:
     """
     Mix this in to get a few special-cased patching methods
     """
@@ -95,14 +71,15 @@ class PatcherMixin(object):
         if hasattr(os, 'uname'):
             self.patch(os, 'uname', replacement)
         else:
+
             def cleanup():
                 del os.uname
+
             self.addCleanup(cleanup)
             os.uname = replacement
 
 
-class FileIOMixin(object):
-
+class FileIOMixin:
     """
     Mixin for patching open(), read() and write() to simulate successful
     I/O operations and various I/O errors.
@@ -128,8 +105,7 @@ class FileIOMixin(object):
         self.open = mock.Mock(return_value=self.fileobj)
         self.patch(builtins, "open", self.open)
 
-    def setUpOpenError(self, errno=errno.ENOENT, strerror="dummy-msg",
-                       filename="dummy-file"):
+    def setUpOpenError(self, errno=errno.ENOENT, strerror="dummy-msg", filename="dummy-file"):
         """
         patch open() to raise IOError
 
@@ -143,12 +119,11 @@ class FileIOMixin(object):
 
         # Add side_effect so that calling fakeOpen() will always
         # raise an IOError.
-        fakeOpen.side_effect = IOError(errno, strerror, filename)
+        fakeOpen.side_effect = OSError(errno, strerror, filename)
         self.open = fakeOpen
         self.patch(builtins, "open", self.open)
 
-    def setUpReadError(self, errno=errno.EIO, strerror="dummy-msg",
-                       filename="dummy-file"):
+    def setUpReadError(self, errno=errno.EIO, strerror="dummy-msg", filename="dummy-file"):
         """
         patch open() to return a file object that will raise IOError on read()
 
@@ -167,14 +142,13 @@ class FileIOMixin(object):
 
         # Add side_effect so that calling read() will always
         # raise an IOError.
-        self.fileobj.read.side_effect = IOError(errno, strerror, filename)
+        self.fileobj.read.side_effect = OSError(errno, strerror, filename)
 
         # patch open() to always return our Mock file object
         self.open = mock.Mock(return_value=self.fileobj)
         self.patch(builtins, "open", self.open)
 
-    def setUpWriteError(self, errno=errno.ENOSPC, strerror="dummy-msg",
-                        filename="dummy-file"):
+    def setUpWriteError(self, errno=errno.ENOSPC, strerror="dummy-msg", filename="dummy-file"):
         """
         patch open() to return a file object that will raise IOError on write()
 
@@ -192,15 +166,14 @@ class FileIOMixin(object):
 
         # Add side_effect so that calling write() will always
         # raise an IOError.
-        self.fileobj.write.side_effect = IOError(errno, strerror, filename)
+        self.fileobj.write.side_effect = OSError(errno, strerror, filename)
 
         # patch open() to always return our Mock file object
         self.open = mock.Mock(return_value=self.fileobj)
         self.patch(builtins, "open", self.open)
 
 
-class LoggingMixin(object):
-
+class LoggingMixin:
     def setUpLogging(self):
         self._logEvents = []
         log.addObserver(self._logEvents.append)
@@ -213,30 +186,19 @@ class LoggingMixin(object):
                 msg = log.textFromEventDict(event)
                 if msg is not None and r.search(msg):
                     return
-            self.fail(
-                "{0!r} not matched in log output.\n{1} ".format(regexp, self._logEvents))
+            self.fail(f"{regexp!r} not matched in log output.\n{self._logEvents} ")
 
     def assertWasQuiet(self):
         self.assertEqual(self._logEvents, [])
 
 
-class StdoutAssertionsMixin(object):
-
+class StdoutAssertionsMixin:
     """
     Mix this in to be able to assert on stdout during the test
     """
 
     def setUpStdoutAssertions(self):
-        #
-        # sys.stdout is implemented differently
-        # in Python 2 and Python 3, so we need to
-        # override it differently.
-        # In Python 2, sys.stdout is a byte stream.
-        # In Python 3, sys.stdout is a text stream.
-        if PY3:
-            self.stdout = StringIO()
-        else:
-            self.stdout = BytesIO()
+        self.stdout = StringIO()
         self.patch(sys, 'stdout', self.stdout)
 
     def assertWasQuiet(self):
