@@ -54,8 +54,11 @@ export default defineConfig({
         },
       },
     },
-    target: ['es2015'],
+    target: ['es2020'],
     outDir: outDir,
     emptyOutDir: true,
   },
+  test: {
+    environment: "jsdom"
+  },
 });
