@@ -15,35 +15,29 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 try:
     from buildbot_pkg import setup_www_plugin
 except ImportError:
     import sys
-    print('Please install buildbot_pkg module in order to install that '
-          'package, or use the pre-build .whl modules available on pypi',
-          file=sys.stderr)
+
+    print(
+        'Please install buildbot_pkg module in order to install that '
+        'package, or use the pre-build .whl modules available on pypi',
+        file=sys.stderr,
+    )
     sys.exit(1)
 
 setup_www_plugin(
     name='buildbot-grid-view',
     description='Buildbot Grid View plugin',
-    author=u'Robin Jarry',
-    author_email=u'robin.jarry@6wind.com',
+    author='Robin Jarry',
+    author_email='robin.jarry@6wind.com',
     url='http://buildbot.net/',
-    license='GNU GPL',
     packages=['buildbot_grid_view'],
-    package_data={
-        '': [
-            'VERSION',
-            'static/*'
-        ]
-    },
+    package_data={'': ['VERSION', 'static/*', 'static/assets/*']},
     entry_points="""
         [buildbot.www]
         grid_view = buildbot_grid_view:ep
     """,
+    classifiers=['License :: OSI Approved :: GNU General Public License v2 (GPLv2)'],
 )
